<?php
namespace EcafeAddons;
use Elementor\Utils;
use Elementor\Core\Settings\Manager as SettingsManager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

final class EcafeElementLoad {
	
	private static $_instance;

	
	private $_modules_manager;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
	
	
	private function includes() {
		
		require_once ECAFE_CLASSES_URL .'class-helper.php';
		
		$defaultOnLoad='ecafedefaultoptions';
		$value='1';
		if ( is_admin() && get_option( $defaultOnLoad ) !== false ) {
		} else if( is_admin() ){
			$defaultLoad=get_option( 'ecafe_widgets' );
			if ( $defaultLoad !== false && $defaultLoad!='') {
				$defaultNull = null;
				$onLoadAuto = 'no';
				add_option( $defaultOnLoad,$value,$defaultNull,$onLoadAuto );
			}else{
				$widgetsPage=get_option( 'ecafe_widgets' );
				$widgetsPage['widgetsload']= array('ecafe-accordion','ecafe-adv-text-block','ecafe-business-hours','ecafe-button','ecafe-changelog','ecafe-chart','ecafe-image-hover-effect','ecafe-infobox','ecafe-social-icons','ecafe-title','ecafe-grid-post-listing','ecafe-lottie','ecafe-marketing-link','ecafe-tabs');
				
				$defaultNull = null;
				$onLoadAuto = 'no';
				add_option( 'ecafe_widgets',$widgetsPage, $defaultNull, $onLoadAuto );
				add_option( $defaultOnLoad,$value,$defaultNull,$onLoadAuto );
			}
		}	
			
		require ECAFE_CLASSES_URL.'class-panel-options.php';	
		
	}
	
	/**
	* Carry widgets
	*/
	public function carryWidgets() {			
		require_once ECAFE_CLASSES_URL.'widgets-passing-lists.php';		
	}
	
	/**
	* Editor load style
	*/
	public function afterEnqueueStylesEditor(){
		wp_enqueue_style( 'ecafe-elementor', ECAFE_ASSETS_PATH .'css/admin/ecafe-elementor.css', array(),ECAFE_VERSION,false );
		
		$ui_theme = SettingsManager::get_settings_managers( 'editorPreferences' )->get_model()->get_settings( 'ui_theme' );
		if(!empty($ui_theme) && $ui_theme=='dark'){
			wp_enqueue_style( 'ecafe-dark-elementor',ECAFE_ASSETS_PATH .'css/admin/ecafe-dark-elementor.css', array(),ECAFE_VERSION,false);
		}
	}
	
	/**
	* Admin load style
	*/
	public function ecafeElementorAdminCss(){
		wp_enqueue_style('ecafe-elementor',ECAFE_ASSETS_PATH .'css/admin/ecafe-elementor.css', array(),ECAFE_VERSION,false);
		wp_enqueue_script('ecafe-backuser',ECAFE_ASSETS_PATH .'js/admin/ecafe-admin.js', array(),ECAFE_VERSION,false);
	}
	
	/**
	* Category for elementor
	*/
	public function categoryForElementor() {			
		$EI = \Elementor\Plugin::$instance;	
		$EI->elements_manager->add_category('essential',['title' => esc_html__( 'Essential', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecacf',['title' => esc_html__( 'EC ACF', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('eccfs',['title' => esc_html__( 'EC CFS', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecjetengine',['title' => esc_html__( 'EC JetEngine', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecmetabox',['title' => esc_html__( 'EC Metabox', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecpods',['title' => esc_html__( 'EC Pods', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ectoolset',['title' => esc_html__( 'EC Toolset', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecwck',['title' => esc_html__( 'EC WCK', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecwoocommerce',['title' => esc_html__( 'EC WooCommerce', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecforms',['title' => esc_html__( 'EC Forms', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
		$EI->elements_manager->add_category('ecembed',['title' => esc_html__( 'EC Embed', 'essential-classy-addons-for-elementor' ),'icon' => 'ecaddons',],1);
	}
	
	/**
	* Settings links
	*/	
	function ecafeSettingsLinks($settingsLinks) {
		$settingsLinksArray = array(
				'<a href="'.admin_url('admin.php?page=ecafe_widgets').'">'.esc_html__("Settings","essential-classy-addons-for-elementor").'</a> | <a href="https://www.facebook.com/groups/340597333894907" target="_blank" style="color:#4fb560; font-weight: bold;">' . __('Join/Contact US', 'essential-classy-addons-for-elementor') . '</a>',
			);
		return array_merge( $settingsLinks, $settingsLinksArray );	
	}
	
	public function ecafeEnqueueStyles() {
		
		wp_register_style('font-awesome-5-all',ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/all.min.css',false,ECAFE_VERSION
		);
		
		wp_register_style('ecafe-accordion', ECAFE_ASSETS_PATH . 'css/custom/ecafe-accordion.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-accordion', ECAFE_ASSETS_PATH . 'js/custom/ecafe-accordion.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-advanced-text-block', ECAFE_ASSETS_PATH . 'css/custom/ecafe-advanced-text-block.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-back-to-top', ECAFE_ASSETS_PATH . 'css/custom/ecafe-back-to-top.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-back-to-top', ECAFE_ASSETS_PATH . 'js/custom/ecafe-back-to-top.min.js', array('jquery'),ECAFE_VERSION,false );
		
		
		wp_register_style('ecafe-business-hours', ECAFE_ASSETS_PATH . 'css/custom/ecafe-business-hours.min.css', false, ECAFE_VERSION );
		wp_register_style('ecafe-button', ECAFE_ASSETS_PATH . 'css/custom/ecafe-button.min.css', false, ECAFE_VERSION );
		
		wp_register_script('ecafe-chart-3rd',ECAFE_ASSETS_PATH .'js/baharni/chart.js', array(),ECAFE_VERSION,false);
		wp_register_script('ecafe-chart', ECAFE_ASSETS_PATH . 'js/custom/ecafe-chart.min.js', array('ecafe-chart-3rd'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-changelog', ECAFE_ASSETS_PATH . 'css/custom/ecafe-changelog.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-changelog', ECAFE_ASSETS_PATH . 'js/custom/ecafe-changelog.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-contact-form-7', ECAFE_ASSETS_PATH . 'css/custom/ecafe-contact-form-7.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-wpforms', ECAFE_ASSETS_PATH . 'css/custom/ecafe-wpforms.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-gravity-forms', ECAFE_ASSETS_PATH . 'css/custom/ecafe-gravity-forms.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-woocommerce-cart', ECAFE_ASSETS_PATH . 'css/custom/ecafe-woocommerce-cart.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-woocommerce-checkout', ECAFE_ASSETS_PATH . 'css/custom/ecafe-woocommerce-checkout.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-woocommerce-myaccount', ECAFE_ASSETS_PATH . 'css/custom/ecafe-woocommerce-myaccount.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-woocommerce-ordertrack', ECAFE_ASSETS_PATH . 'css/custom/ecafe-woocommerce-ordertrack.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-dropcap', ECAFE_ASSETS_PATH . 'css/custom/ecafe-dropcap.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-infobox', ECAFE_ASSETS_PATH . 'css/custom/ecafe-infobox.min.css', false, ECAFE_VERSION );
		wp_register_style('ecafe-social-icons', ECAFE_ASSETS_PATH . 'css/custom/ecafe-social-icons.min.css', false, ECAFE_VERSION );
		wp_register_style('ecafe-title', ECAFE_ASSETS_PATH . 'css/custom/ecafe-title.min.css', false, ECAFE_VERSION );
		wp_register_style('ecafe-post-listing', ECAFE_ASSETS_PATH . 'css/custom/ecafe-post-listing.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-tabs', ECAFE_ASSETS_PATH . 'css/custom/ecafe-tabs.min.css', false, ECAFE_VERSION );
		
		
		wp_register_script('ecafe-lax',ECAFE_ASSETS_PATH .'js/baharni/lax.min.js', array(),ECAFE_VERSION,false);
		wp_register_script('ecafe-min-js', ECAFE_ASSETS_PATH . 'js/custom/ecafe.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_script('ecafe-isotope',ECAFE_ASSETS_PATH .'js/baharni/isotope.pkgd.min.js', array(),ECAFE_VERSION,false);
		wp_register_script('ecafe-imagesloaded',ECAFE_ASSETS_PATH .'js/baharni/imagesloaded.pkgd.min.js', array(),ECAFE_VERSION,false);
		wp_register_script('ecafe-post-listing', ECAFE_ASSETS_PATH . 'js/custom/ecafe-post-listing.min.js', array('ecafe-isotope','ecafe-imagesloaded'),ECAFE_VERSION,false );
		
		wp_register_script('ecafe-tabs', ECAFE_ASSETS_PATH . 'js/custom/ecafe-tabs.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-whatsapp', ECAFE_ASSETS_PATH . 'css/custom/ecafe-whatsapp.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-whatsapp', ECAFE_ASSETS_PATH . 'js/custom/ecafe-whatsapp.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-countdown', ECAFE_ASSETS_PATH . 'css/custom/ecafe-countdown.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-countdown', ECAFE_ASSETS_PATH . 'js/custom/ecafe-countdown.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-image-hover-effect', ECAFE_ASSETS_PATH . 'css/custom/ecafe-image-hover-effect.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-lottie', ECAFE_ASSETS_PATH . 'css/custom/ecafe-lottie.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-lottie-3rd',ECAFE_ASSETS_PATH .'js/baharni/lottie.min.js', array(),ECAFE_VERSION,false);
		wp_register_script('ecafe-lottie', ECAFE_ASSETS_PATH . 'js/custom/ecafe-lottie.min.js', array('ecafe-lottie-3rd'),ECAFE_VERSION,false );
		
		wp_register_style('ecafe-marketing-link', ECAFE_ASSETS_PATH . 'css/custom/ecafe-marketing-link.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-marketing-link',ECAFE_ASSETS_PATH .'js/custom/ecafe-marketing-link.min.js', array(),ECAFE_VERSION,false);
		
		wp_register_style('ecafe-scroll-progress', ECAFE_ASSETS_PATH . 'css/custom/ecafe-scroll-progress.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-scroll-progress', ECAFE_ASSETS_PATH . 'js/custom/ecafe-scroll-progress.min.js', array('jquery'),ECAFE_VERSION,false );
		
		wp_register_script('ecafe-image-scroll', ECAFE_ASSETS_PATH . 'js/custom/ecafe-image-scroll.min.js', array('jquery'),ECAFE_VERSION,false );

		wp_register_style('ecafe-image-accordion', ECAFE_ASSETS_PATH . 'css/custom/ecafe-image-accordion.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-image-accordion', ECAFE_ASSETS_PATH . 'js/custom/ecafe-image-accordion.min.js', array('jquery'),ECAFE_VERSION,false );

		wp_register_style('ecafe-hover-background', ECAFE_ASSETS_PATH . 'css/custom/ecafe-hover-background.min.css', false, ECAFE_VERSION );
		wp_register_script('ecafe-hover-background', ECAFE_ASSETS_PATH . 'js/custom/ecafe-hover-background.min.js', array('jquery'),ECAFE_VERSION,false );

		wp_register_style('ecafe-service-lists', ECAFE_ASSETS_PATH . 'css/custom/ecafe-service-lists.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-text-background', ECAFE_ASSETS_PATH . 'css/custom/ecafe-text-background.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-acf-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-acf-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-cfs-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-cfs-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-jet-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-jet-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-meta-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-meta-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-pods-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-pods-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-toolset-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-toolset-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-wck-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-wck-general.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-acf-oembed', ECAFE_ASSETS_PATH . 'css/custom/ecafe-acf-oembed.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-pods-oembed', ECAFE_ASSETS_PATH . 'css/custom/ecafe-pods-oembed.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-toolset-oembed', ECAFE_ASSETS_PATH . 'css/custom/ecafe-toolset-oembed.min.css', false, ECAFE_VERSION );
		
		wp_register_style('ecafe-social-embeded-general', ECAFE_ASSETS_PATH . 'css/custom/ecafe-social-embeded-general.min.css', false, ECAFE_VERSION );
		
		wp_localize_script(
			'jquery', 'ecafe_data', array(
				'eca_ajax_url' => admin_url('admin-ajax.php'),
			)
		);
	}
	
	/**
	* Hooks
	*/
	private function hooks() {		
		add_action('elementor/init',[$this,'categoryForElementor']);
		
		// Register Widget Styles & Script
		add_action( 'wp_enqueue_scripts', [ $this, 'ecafeEnqueueStyles' ] );
		
		add_action('elementor/editor/after_enqueue_styles',[$this,'afterEnqueueStylesEditor']);		
		add_action('admin_enqueue_scripts', [ $this,'ecafeElementorAdminCss']);
		add_filter('plugin_action_links_'.ECAFE_BASE_NAME,[$this, 'ecafeSettingsLinks']);		
	}	
	
	/**
	* Constructor
	*/
	private function __construct() {
		$this->includes();
		$this->hooks();			
		$this->carryWidgets();		
		ecafeWidgetsPassed();
	}
}

EcafeElementLoad::instance();