<?php	
use Elementor\Plugin;
if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly

/**
* Plugin options
*/
class EcafePluginOptions {
        
    private $key = 'ecafe_widgets';
    protected $metaboxOptions = array();
    protected $title = '';
    protected $optionsPage = '';
    protected $optionsPages = array();
	
	/**
	* Constructor
	*/
    public function __construct() {
      
		$this->title = esc_html__('Essential Classy', 'essential-classy-addons-for-elementor');		
               
        $this->fields = array();
		$this->ecafeWidgetList();
		add_action( 'admin_post_ecafe_widgets_options_save', array( $this,'widgetsSaveFire') );
		add_action( 'admin_post_ecafe_extension_options_save', array( $this,'extraListSaveOptions') );
		add_action( 'admin_post_ecafe_wp_performance_options_save', array( $this,'wpPerformanceSaveOptions') );
		add_action('ecafeWhiteLabelFree', array( $this,'ecafeWhiteLabel'));
		
		
		$ecafe_extension = get_option( 'ecafe_extension' );
		
		if(!empty($ecafe_extension) && isset($ecafe_extension['extrasList']) && !empty($ecafe_extension['extrasList'])){
			if(in_array('ecafe-live-copy',$ecafe_extension['extrasList'])){
				require ECAFE_LIVECOPY_PATH.'ec-live-copy.php';
			}			
		}
		
		$wpPerf = get_option( 'ecafe_wp_performance' );
		
		if(!empty($wpPerf) && isset($wpPerf['wpperformanceList']) && !empty($wpPerf['wpperformanceList'])){
			
			//emoji_scripts
			if(in_array('emoji_scripts',$wpPerf['wpperformanceList'])){
				add_action( 'init', 'ec_emoji_scripts' );
				function ec_emoji_scripts() {
					remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
					remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
					remove_action( 'wp_print_styles', 'print_emoji_styles' );
					remove_action( 'admin_print_styles', 'print_emoji_styles' ); 
					remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
					remove_filter( 'comment_text_rss', 'wp_staticize_emoji' ); 
					remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
					
					add_filter('tiny_mce_plugins', function ($plugins) {
						if (is_array($plugins)) {
							return array_diff($plugins, array('wpemoji'));
						} else {
							return array();
						}
					});

					add_filter('wp_resource_hints', function ($urls, $relation_type) {
						if ('dns-prefetch' === $relation_type) {							
							$emoji_svg_url = apply_filters('emoji_svg_url', 'https://s.w.org/images/core/emoji/2/svg/');

							$urls = array_diff($urls, array($emoji_svg_url));
						}

						return $urls;
					}, 10, 2);
				}
			}
			
			//disable_embeds
			if(in_array('disable_embeds',$wpPerf['wpperformanceList'])){
				add_action('init', 'ec_disable_embeds', 9999);
				function ec_disable_embeds(){
					global $wp;
					$wp->public_query_vars = array_diff($wp->public_query_vars, array('embed'));
					add_filter('embed_oembed_discover', '__return_false');
					remove_filter('oembed_dataparse', 'wp_filter_oembed_result', 10);
					remove_action('wp_head', 'wp_oembed_add_discovery_links');
					remove_action('wp_head', 'wp_oembed_add_host_js');
					add_filter('tiny_mce_plugins', function( $plugins ) {
						return array_diff($plugins, array('wpembed'));
					});
					add_filter('rewrite_rules_array', function($rules) {
						foreach($rules as $rule => $rewrite) {
							if(false !== strpos($rewrite, 'embed=true')) {
								unset($rules[$rule]);
							}
						}
						return $rules;
					});
					remove_filter('pre_oembed_result', 'wp_filter_pre_oembed_result', 10);
				}
			}
			
			//pass_str_mtr
			if(in_array('pass_str_mtr',$wpPerf['wpperformanceList'])){
				add_action('wp_print_scripts', function(){				
				if( is_admin() ) {
					return;
				}				
				
				if( ( isset($GLOBALS['pagenow']) && $GLOBALS['pagenow'] === 'wp-login.php' ) || ( isset($_GET['action']) && in_array($_GET['action'], array('register','rp', 'lostpassword' )) ) ) {
					return;
				}
				
				if( class_exists('WooCommerce') && (is_account_page() || is_checkout()) ) {
					return;
				}
				
				wp_dequeue_script('password-strength-meter');
				wp_deregister_script('password-strength-meter');

				wp_dequeue_script('wc-password-strength-meter');
				wp_deregister_script('wc-password-strength-meter');
				
				wp_dequeue_script('zxcvbn-async');
				wp_deregister_script('zxcvbn-async');
				
			}, 100);
			}
			
			//xml_rpc
			if(in_array('xml_rpc',$wpPerf['wpperformanceList'])){
				add_filter('xmlrpc_enabled', '__return_false');
				add_filter('wp_headers', 'removeXPingback');
				add_filter('pings_open', '__return_false', 9999);
				function removeXPingback($headers) {
					unset($headers['X-Pingback'], $headers['x-pingback']);
					return $headers;
				}
			}
			
			//disable_dashicons
			if(in_array('disable_dashicons',$wpPerf['wpperformanceList'])){
				add_action('wp_enqueue_scripts', 'ec_disable_dashicons');
				function ec_disable_dashicons(){
					if(!is_user_logged_in()) {
						wp_dequeue_style('dashicons');
						wp_deregister_style('dashicons');
					}
				}
			}
			
			//rsd_link
			if(in_array('rsd_link',$wpPerf['wpperformanceList'])){
				remove_action('wp_head', 'rsd_link');
			}
			
			//shortlink
			if(in_array('shortlink',$wpPerf['wpperformanceList'])){
				remove_action('wp_head', 'wp_shortlink_wp_head');
				remove_action ('template_redirect', 'wp_shortlink_header', 11, 0);
			}
			
			//wlwmanifest_link
			if(in_array('wlwmanifest_link',$wpPerf['wpperformanceList'])){
				remove_action('wp_head', 'wlwmanifest_link');
			}
			
			//self_pingbacks
			if(in_array('self_pingbacks',$wpPerf['wpperformanceList'])){
				add_action('pre_ping', 'selfPingbacks');
				function selfPingbacks( &$links ){
					$home = home_url();
					foreach($links as $l => $link) {
						if(strpos($link, $home) === 0) {
							unset($links[$l]);
						}
					}
				}
			}
			
			//wp_version
			if(in_array('wp_version',$wpPerf['wpperformanceList'])){
				remove_action('wp_head', 'wp_generator');
				add_filter('the_generator', function(){
					return '';
				});
			}
			
			//rss_feeds
			if(in_array('rss_feeds',$wpPerf['wpperformanceList'])){
				add_action('template_redirect', 'ecRssFeeds', 1);
				function ecRssFeeds() {
					if(!is_feed() || is_404()) {
						return;
					}
					
					global $wp_rewrite;
					global $wp_query;

					if(isset($_GET['feed'])) {
						wp_redirect(esc_url_raw(remove_query_arg('feed')), 301);
						exit;
					}

					if(get_query_var('feed') !== 'old') {
						set_query_var('feed', '');
					}
					
					redirect_canonical();

					wp_die(sprintf(__("No feed available, go to <a href='%s'>Home Page</a>!",'essential-classy-addons-for-elementor'), esc_url(home_url('/'))));
				}
			}
			
			//rss_feed_link
			if(in_array('rss_feed_link',$wpPerf['wpperformanceList'])){
				remove_action('wp_head', 'feed_links_extra', 3);
				remove_action('wp_head', 'feed_links', 2);
			}
			
		}
    }
    
    /**
	* Hooks
	*/
    public function hooks() {
        add_action('admin_init', array($this,'init'));
        add_action('admin_menu', array($this,'optionsPageAppend'));
    }    
    
	/**
	* Init
	*/
    public function init() {        
        $optionTabs = self::fieldsOption();
        foreach ($optionTabs as $index => $optionTab) {
            register_setting($optionTab['id'], $optionTab['id']);
        }
    }
	
	/**
	* White Label
	*/
	public function ecafeWhiteLabel(){
		echo '<div class="ecafe-cs"><img src="'.ECAFE_URL.'assets/images/cs.gif" /></div>';
	}
	
	/**
	* Widget save and fire action
	*/
	public function widgetsSaveFire() {
		$actionPage = 'ecafe_widgets';
		if(isset($_POST["submit-key"]) && !empty($_POST["submit-key"]) && $_POST["submit-key"]=='Save'){
			$nonce = isset( $_POST['nonce_ecafe_widgets'] ) ? sanitize_text_field(wp_unslash($_POST['nonce_ecafe_widgets'])) : '';
			if ( ! isset( $nonce ) || ! wp_verify_nonce( $nonce, 'nonce_ecafe_widgets_action' ) ) {
			   wp_redirect(admin_url('admin.php?page='.$actionPage));
			} else {
				if (get_option($actionPage) === FALSE){
					$defaultValue = array('widgetsload' => '');
					add_option($actionPage,$defaultValue);
					wp_redirect(admin_url('admin.php?page=ecafe_widgets'));
				}else{
					$updateValue=[];
					$widgetsload = isset( $_POST['widgetsload'] ) ? array_map( 'sanitize_text_field',wp_unslash($_POST['widgetsload'])) : [];
					if( isset( $widgetsload ) && !empty( $widgetsload ) ){
						$updateValue['widgetsload'] = $widgetsload;						
					}else if(empty($widgetsload)){
						$updateValue['widgetsload'] = '';					
					}					
					update_option( $actionPage, $updateValue );
					wp_redirect(admin_url('admin.php?page='.$actionPage));					
				}
			}
			
		}else{
			wp_redirect(admin_url('admin.php?page='.$actionPage));
		}
	}
	
	/**
	* Extras List Save Options
	*/
	public function extraListSaveOptions() {
		$actionPage = 'ecafe_extension';
		if(isset($_POST["submit-key"]) && !empty($_POST["submit-key"]) && $_POST["submit-key"]=='Save'){
			$nonce = isset( $_POST['nonce_ecafe_extension'] ) ? sanitize_text_field(wp_unslash($_POST['nonce_ecafe_extension'])) : '';
			if ( ! isset( $nonce ) || ! wp_verify_nonce( $nonce, 'nonce_ecafe_extension_action' ) ) {
			   wp_redirect(admin_url('admin.php?page='.$actionPage));
			} else {
				if (get_option($actionPage) === FALSE){
					$defaultValue = array('extrasList' => '');
					add_option($actionPage,$defaultValue);
					wp_redirect(admin_url('admin.php?page='.$actionPage));
				}else{
					$updateValue=[];
					$extrasList = isset( $_POST['extrasList'] ) ? array_map( 'sanitize_text_field',wp_unslash($_POST['extrasList'])) : [];
					if( isset( $extrasList ) && !empty( $extrasList ) ){
						$updateValue['extrasList'] = $extrasList;						
					}else if(empty($extrasList)){
						$updateValue['extrasList'] = '';					
					}					
					update_option( $actionPage, $updateValue );
					wp_redirect(admin_url('admin.php?page='.$actionPage));					
				}
			}
			
		}else{
			wp_redirect(admin_url('admin.php?page='.$actionPage));
		}
	}
	
	
	/**
	* WP Performance Save Options
	*/
	public function wpPerformanceSaveOptions() {
		$actionPage = 'ecafe_wp_performance';
		if(isset($_POST["submit-key"]) && !empty($_POST["submit-key"]) && $_POST["submit-key"]=='Save'){
			$nonce = isset( $_POST['nonce_ecafe_wp_performance'] ) ? sanitize_text_field(wp_unslash($_POST['nonce_ecafe_wp_performance'])) : '';
			if ( ! isset( $nonce ) || ! wp_verify_nonce( $nonce, 'nonce_ecafe_wp_performance_action' ) ) {
			   wp_redirect(admin_url('admin.php?page='.$actionPage));
			} else {
				if (get_option($actionPage) === FALSE){
					$defaultValue = array('wpperformanceList' => '');
					add_option($actionPage,$defaultValue);
					wp_redirect(admin_url('admin.php?page='.$actionPage));
				}else{
					$updateValue=[];
					$wpperformanceList = isset( $_POST['wpperformanceList'] ) ? array_map( 'sanitize_text_field',wp_unslash($_POST['wpperformanceList'])) : [];
					if( isset( $wpperformanceList ) && !empty( $wpperformanceList ) ){
						$updateValue['wpperformanceList'] = $wpperformanceList;						
					}else if(empty($wpperformanceList)){
						$updateValue['wpperformanceList'] = '';					
					}
					update_option( $actionPage, $updateValue );
					wp_redirect(admin_url('admin.php?page='.$actionPage));					
				}
			}
			
		}else{
			wp_redirect(admin_url('admin.php?page='.$actionPage));
		}
	}
	
	/**
	* Widget lists
	*/
	public function ecafeWidgetList(){
		$this->widget_lists = [
			'ecafe-accordion' => [
				'label' => esc_html__('Accordion','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-adv-text-block' => [
				'label' => esc_html__('Advanced Text Block','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-back-to-top' => [
				'label' => esc_html__('Back to Top','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-business-hours' => [
				'label' => esc_html__('Business Hours','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-button' => [
				'label' => esc_html__('Button','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-changelog' => [
				'label' => esc_html__('Changelog','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-chart' => [
				'label' => esc_html__('Chart','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-contact-form-7' => [
				'label' => esc_html__('Contact Form 7','essential-classy-addons-for-elementor'),
				'catlist' => 'forms',
			],
			'ecafe-count-down' => [
				'label' => esc_html__('Countdown','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-darkmode-styling' => [
				'label' => esc_html__('Dark Mode Styling','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-dropcap' => [
				'label' => esc_html__('Dropcap','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-gravity-forms' => [
				'label' => esc_html__('Gravity Forms','essential-classy-addons-for-elementor'),
				'catlist' => 'forms',
			],
			'ecafe-grid-post-listing' => [
				'label' => esc_html__('Grid Post Listing','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-hover-background' => [
				'label' => esc_html__('Hover Background','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-image-accordion' => [
				'label' => esc_html__('Image Accordion','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-image-hover-effect' => [
				'label' => esc_html__('Image Hover Effect','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-image-scroll' => [
				'label' => esc_html__('Image Scroll','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-infobox' => [
				'label' => esc_html__('Info Box','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-lottie' => [
				'label' => esc_html__('Lottie','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-marketing-link' => [
				'label' => esc_html__('Marketing Link','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-scroll-progress' => [
				'label' => esc_html__('Scroll Progress','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-service-lists' => [
				'label' => esc_html__('Service Lists','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-social-icons' => [
				'label' => esc_html__('Social Icons','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-title' => [
				'label' => esc_html__('Title','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],			
			'ecafe-tabs' => [
				'label' => esc_html__('Tabs','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-text-background' => [
				'label' => esc_html__('Text Background','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-whatsapp' => [
				'label' => esc_html__('Whatsapp','essential-classy-addons-for-elementor'),
				'catlist' => 'essential',
			],
			'ecafe-wpforms' => [
				'label' => esc_html__('WPForms','essential-classy-addons-for-elementor'),
				'catlist' => 'forms',
			],
			'ecafe-woocommerce-cart' => [
				'label' => esc_html__('WooCommerce Cart','essential-classy-addons-for-elementor'),
				'catlist' => 'woocommerce',
			],
			'ecafe-woocommerce-checkout' => [
				'label' => esc_html__('WooCommerce Checkout','essential-classy-addons-for-elementor'),
				'catlist' => 'woocommerce',
			],
			'ecafe-woocommerce-myaccount' => [
				'label' => esc_html__('WooCommerce MyAccount','essential-classy-addons-for-elementor'),
				'catlist' => 'woocommerce',
			],
			'ecafe-woocommerce-ordertrack' => [
				'label' => esc_html__('WooCommerce Order Track','essential-classy-addons-for-elementor'),
				'catlist' => 'woocommerce',
			],
			'ecafe-facebook-embed' => [
				'label' => esc_html__('Facebook Embed','essential-classy-addons-for-elementor'),
				'catlist' => 'embed',
			],
			'ecafe-googlemap-embed' => [
				'label' => esc_html__('Google Map Embed','essential-classy-addons-for-elementor'),
				'catlist' => 'embed',
			],
			'ecafe-acf-text' => [
				'label' => esc_html__('ACF : Text','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-text-area' => [
				'label' => esc_html__('ACF : Text Area','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-wysiwyg-editor' => [
				'label' => esc_html__('ACF : Wysiwyg Editor','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-url' => [
				'label' => esc_html__('ACF : Url','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-email' => [
				'label' => esc_html__('ACF : Email','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-number' => [
				'label' => esc_html__('ACF : Number','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-image' => [
				'label' => esc_html__('ACF : Image','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-date' => [
				'label' => esc_html__('ACF : Date','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-time' => [
				'label' => esc_html__('ACF : Time','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-date-time' => [
				'label' => esc_html__('ACF : Date Time','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-acf-oembed' => [
				'label' => esc_html__('ACF : oEmbed','essential-classy-addons-for-elementor'),
				'catlist' => 'acf',
			],
			'ecafe-cfs-text' => [
				'label' => esc_html__('Custom Field Suite : Text','essential-classy-addons-for-elementor'),
				'catlist' => 'cfs',
			],
			'ecafe-cfs-textarea' => [
				'label' => esc_html__('Custom Field Suite : Text Area','essential-classy-addons-for-elementor'),
				'catlist' => 'cfs',
			],
			'ecafe-cfs-wysiwyg' => [
				'label' => esc_html__('Custom Field Suite : Wysiwyg','essential-classy-addons-for-elementor'),
				'catlist' => 'cfs',
			],
			'ecafe-cfs-hyperlink' => [
				'label' => esc_html__('Custom Field Suite : Hyperlink','essential-classy-addons-for-elementor'),
				'catlist' => 'cfs',
			],
			'ecafe-cfs-date' => [
				'label' => esc_html__('Custom Field Suite : Date','essential-classy-addons-for-elementor'),
				'catlist' => 'cfs',
			],
			'ecafe-cfs-image' => [
				'label' => esc_html__('Custom Field Suite : Image','essential-classy-addons-for-elementor'),
				'catlist' => 'cfs',
			],
			'ecafe-jetengine-text' => [
				'label' => esc_html__('JetEngine : Text','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-date' => [
				'label' => esc_html__('JetEngine : Date','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-time' => [
				'label' => esc_html__('JetEngine : Time','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-datetime' => [
				'label' => esc_html__('JetEngine : Date Time','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-textarea' => [
				'label' => esc_html__('JetEngine : Text Area','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-wysiwyg' => [
				'label' => esc_html__('JetEngine : Wysiwyg','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-media' => [
				'label' => esc_html__('JetEngine : Media','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-jetengine-number' => [
				'label' => esc_html__('JetEngine : Number','essential-classy-addons-for-elementor'),
				'catlist' => 'jet',
			],
			'ecafe-metabox-text' => [
				'label' => esc_html__('Meta Box : Text','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-textarea' => [
				'label' => esc_html__('Meta Box : Text Area','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-wysiwyg' => [
				'label' => esc_html__('Meta Box : Wysiwyg','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-email' => [
				'label' => esc_html__('Meta Box : Email','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-number' => [
				'label' => esc_html__('Meta Box : Number','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-url' => [
				'label' => esc_html__('Meta Box : Url','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-imageadvanced' => [
				'label' => esc_html__('Meta Box : Image Advanced','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-video' => [
				'label' => esc_html__('Meta Box : Video','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-date' => [
				'label' => esc_html__('Meta Box : Date','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-datetime' => [
				'label' => esc_html__('Meta Box : Datetime','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-metabox-time' => [
				'label' => esc_html__('Meta Box : Time','essential-classy-addons-for-elementor'),
				'catlist' => 'metabox',
			],
			'ecafe-pods-plaintext' => [
				'label' => esc_html__('Pods : Plain Text','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-website' => [
				'label' => esc_html__('Pods : Website','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-phone' => [
				'label' => esc_html__('Pods : Phone','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-email' => [
				'label' => esc_html__('Pods : Email','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-plain-paragraph-text' => [
				'label' => esc_html__('Pods : Plain Paragraph Text','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-wysywyg' => [
				'label' => esc_html__('Pods : WYSIWYG (Visual Editor)','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-date-time' => [
				'label' => esc_html__('Pods : Date / Time','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-date' => [
				'label' => esc_html__('Pods : Date','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-time' => [
				'label' => esc_html__('Pods : Time','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-plain-number' => [
				'label' => esc_html__('Pods : Plain Number','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-currency' => [
				'label' => esc_html__('Pods : Currency','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-image' => [
				'label' => esc_html__('Pods : Image','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-video' => [
				'label' => esc_html__('Pods : Video','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-pods-oembed' => [
				'label' => esc_html__('Pods : oEmbed','essential-classy-addons-for-elementor'),
				'catlist' => 'pods',
			],
			'ecafe-toolset-single-line' => [
				'label' => esc_html__('Toolset : Single Line','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-multiple-lines' => [
				'label' => esc_html__('Toolset : Multiple Lines','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-wysiwyg' => [
				'label' => esc_html__('Toolset : WYSIWYG','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-image' => [
				'label' => esc_html__('Toolset : Image','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-video' => [
				'label' => esc_html__('Toolset : Video','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-embedded-media' => [
				'label' => esc_html__('Toolset : Embedded Media','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-email' => [
				'label' => esc_html__('Toolset : Email','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-url' => [
				'label' => esc_html__('Toolset : URL','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-number' => [
				'label' => esc_html__('Toolset : Number','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-phone' => [
				'label' => esc_html__('Toolset : Phone','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-skype' => [
				'label' => esc_html__('Toolset : Skype','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-toolset-date' => [
				'label' => esc_html__('Toolset : Date','essential-classy-addons-for-elementor'),
				'catlist' => 'toolset',
			],
			'ecafe-wck-text' => [
				'label' => esc_html__('WCK : Text','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-textarea' => [
				'label' => esc_html__('WCK : Text Area','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-wysiwyg-editor' => [
				'label' => esc_html__('WCK : Wysiwyg Editor','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-currency-select' => [
				'label' => esc_html__('WCK : Currency Select','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-phone' => [
				'label' => esc_html__('WCK : Phone','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-timepicker' => [
				'label' => esc_html__('WCK : Timepicker','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-number' => [
				'label' => esc_html__('WCK : Number','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-upload-image' => [
				'label' => esc_html__('WCK : Image Upload','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
			'ecafe-wck-upload-video' => [
				'label' => esc_html__('WCK : Video Upload','essential-classy-addons-for-elementor'),
				'catlist' => 'wck',
			],
		];
	}
	
	/**
	* Render widget lists
	*/
	private function ecafeRenderWidgetList(){
		$widgetList = $this->widget_lists;
		$show ='';
		$fetchWidgetsSave = get_option( 'ecafe_widgets' );
		$saveWidget ='';
		
		if(!empty($fetchWidgetsSave['widgetsload'])){
			$saveWidget = $fetchWidgetsSave['widgetsload'];
		}
		
		if(!empty($widgetList)){
			foreach ($widgetList as $key => $widget){							
				$show .='<div class="ecafe-panel-column ecafecate'.esc_attr($widget['catlist']).'">';
					$show .='<div class="widget-list-wrapper">';
						$show .='<div class="widget-list-inner">';
							$show .='<span class="widget-label">'.esc_html($widget['label']).'</span>';							
						$show .='</div>';											
						$checked = '';
						if(!empty($saveWidget) && in_array($key, $saveWidget)){
							$checked = 'checked="checked"';
						}
						
						$show .='<div class="widget-check-wrapper">
									<input type="checkbox" class="widget-list-checkbox" name="widgetsload[]" id="'.esc_attr($key).'" value="'.esc_attr($key).'" '.$checked.'>
									<label for="'.esc_attr($key).'"></label>
								</div>';
					$show .='</div>';
				$show .='</div>';
			}
		}
		return $show;
	}
	
	/**
	* Render Extra Options lists
	*/
	private function ecafeRenderExtraList(){
		$extraList = [			
			'ecafe-glassmorphism' => [
				'label' => esc_html__('Glassmorphism','essential-classy-addons-for-elementor'),
			],
			'ecafe-lax-scroll' => [
				'label' => esc_html__('Lax Scroll','essential-classy-addons-for-elementor'),
			],
			'ecafe-widget-link' => [
				'label' => esc_html__('Link','essential-classy-addons-for-elementor'),
			],
			'ecafe-live-copy' => [
				'label' => esc_html__('Live Copy Paste','essential-classy-addons-for-elementor'),
			]
		];
		$show ='';
		$extrasListOpt = get_option( 'ecafe_extension' );
		$saveWidget ='';
		if(!empty($extrasListOpt['extrasList'])){
			$saveWidget = $extrasListOpt['extrasList'];
		}
		
		if(!empty($extraList)){
			foreach ($extraList as $key => $widget){							
				$show .='<div class="ecafe-panel-column">';
					$show .='<div class="widget-list-wrapper">';
						$show .='<div class="widget-list-inner">';
							$show .='<span class="widget-label">'.esc_html($widget['label']).'</span>';							
						$show .='</div>';											
						$checked = '';
						if(!empty($saveWidget) && in_array($key, $saveWidget)){
							$checked = 'checked="checked"';
						}
						$show .='<div class="widget-check-wrapper">
									<input type="checkbox" class="widget-list-checkbox" name="extrasList[]" id="'.esc_attr($key).'" value="'.esc_attr($key).'" '.$checked.'>
									<label for="'.esc_attr($key).'"></label>
								</div>';
					$show .='</div>';
				$show .='</div>';
			}
		}
		return $show;
	}
	
	/**
	* Render WP Performance Options lists
	*/
	private function ecafeRenderWpPerfomanceList(){
		$wpPerfList = [						
			'disable_dashicons' => [
				'label' => esc_html__('Dashicons','essential-classy-addons-for-elementor'),				
			],
			'emoji_scripts' => [
				'label' => esc_html__('Emojis Script','essential-classy-addons-for-elementor'),				
			],
			'disable_embeds' => [
				'label' => esc_html__('Embeds','essential-classy-addons-for-elementor'),				
			],
			'pass_str_mtr' => [
				'label' => esc_html__('Password Strength Meter','essential-classy-addons-for-elementor'),				
			],
			'rsd_link' => [
				'label' => esc_html__('Remove RSD Link','essential-classy-addons-for-elementor'),				
			],
			'shortlink' => [
				'label' => esc_html__('Remove Shortlink','essential-classy-addons-for-elementor'),
			],
			'wlwmanifest_link' => [
				'label' => esc_html__('Remove wlwmanifest Link','essential-classy-addons-for-elementor'),
			],
			'rss_feeds' => [
				'label' => esc_html__('RSS Feeds','essential-classy-addons-for-elementor'),
			],
			'rss_feed_link' => [
				'label' => esc_html__('Remove RSS Feed Links','essential-classy-addons-for-elementor'),
			],
			'self_pingbacks' => [
				'label' => esc_html__('Self Pingbacks','essential-classy-addons-for-elementor'),
			],
			'xml_rpc' => [
				'label' => esc_html__('XML-RPC','essential-classy-addons-for-elementor'),				
			],
			'wp_version' => [
				'label' => esc_html__('WP Version Generator','essential-classy-addons-for-elementor'),
			],
		];
		$show ='';
		$wpPerformanceListOpt = get_option( 'ecafe_wp_performance' );
		$saveWidget ='';
		if(!empty($wpPerformanceListOpt['wpperformanceList'])){
			$saveWidget = $wpPerformanceListOpt['wpperformanceList'];
		}
		
		if(!empty($wpPerfList)){
			foreach ($wpPerfList as $key => $widget){							
				$show .='<div class="ecafe-panel-column">';
					$show .='<div class="widget-list-wrapper">';
						$show .='<div class="widget-list-inner">';
							$show .='<span class="widget-label">'.esc_html($widget['label']).'</span>';							
						$show .='</div>';											
						$checked = '';
						if(!empty($saveWidget) && in_array($key, $saveWidget)){
							$checked = 'checked="checked"';
						}
						$show .='<div class="widget-check-wrapper">
									<input type="checkbox" class="widget-list-checkbox" name="wpperformanceList[]" id="'.esc_attr($key).'" value="'.esc_attr($key).'" '.$checked.'>
									<label for="'.esc_attr($key).'"></label>
								</div>';
					$show .='</div>';					
				$show .='</div>';
			}
		}
		return $show;
	}
	/**
	* Options page append
	*/
    public function optionsPageAppend() {		
        $optionTabs = self::fieldsOption();		
		
         foreach ($optionTabs as $index => $optionTab) {
            if($index == 0) {
                $this->optionsPages[] = add_menu_page($this->title, $this->title, 'manage_options', $optionTab['id'],array($this,'displayAdminPage'),'dashicons-ecafe-settings'); 
                add_submenu_page($optionTabs[0]['id'], $this->title, $optionTab['title'], 'manage_options', $optionTab['id'], array($this,'displayAdminPage'));
            }else{
				if(isset($optionTabs)){
					$this->optionsPages[] = add_submenu_page($optionTabs[0]['id'], $this->title, $optionTab['title'], 'manage_options', $optionTab['id'], array($this,'displayAdminPage'));
				}
            }
        }
    }    
    
	/**
	* Display admin page
	*/
    public function displayAdminPage() {
        $optionTabs = self::fieldsOption();	
        $tabForms   = array();
		$show ='';		
		$show .='<div class="'.$this->key.'">';
				$show .='<div id="ecafe-setting-head-wrapper">';				
					$show .='<img src='.ECAFE_URL.'assets/images/ec-addons.gif />';
					$show .='<div class="ecafe-current-version"> '.esc_html__('Version','essential-classy-addons-for-elementor').' '.ECAFE_VERSION.'</div>';
				$show .='</div>';		
		
				$show .='<div class="ecafe-nav-tab-wrapper">';
					$show .='<div class="nav-tab-wrapper">';
						ob_start();
						foreach ($optionTabs as $optionTab):
							$tabSlug  = $optionTab['id'];
							$navigationTabClass = 'nav-tab';
							$page_key = isset($_GET['page']) ? sanitize_text_field(wp_unslash($_GET['page'])) : '';
							if ($tabSlug == $page_key) {
								$navigationTabClass .= ' nav-tab-active';
								$tabForms[] = $optionTab;
							}							
							?>
							<a class="<?php echo esc_attr($navigationTabClass); ?>" href="<?php menu_page_url($tabSlug); ?>">
								<span><?php echo esc_html($optionTab['title']); ?></span>
							</a>
							<?php
							
						endforeach;
						$show .= ob_get_clean();						
					$show .='</div>';
				$show .='</div>';
							
				$show .='<div class="ecafe-settings-form-wrapper form-'.$tabForms[0]['id'].'">';
				
					if(!empty($tabForms)){
						ob_start();
						foreach ($tabForms as $tabForm):
							if($tabForm['id']=='ecafe_welcome'){
								echo '<div class="ecafe-panel-welcome-page">';
									echo '<div class="ecafe-panel-row">';
										echo '<div class="ecafe-panel-column">';
											/*User Info*/
											echo '<div class="ecafe-welcome-col ecafe-user-info-wrapper">';
												echo '<div class="ecafe-user-info">';
													$user = wp_get_current_user();
													if (isset($user)){
														echo '<img src="'.esc_url( get_avatar_url( $user->ID ) ).'" class="ecafe-avatar-img" />';
													}
													echo '<div class="ecafe-author-name">'.esc_html__('Welcome ','essential-classy-addons-for-elementor').esc_html($user->display_name).',</div>';
													
													if ( function_exists( 'ini_get' ) ){
														echo "<div class='ecafe-info-panel'>You have <span>".size_format( wp_convert_hr_to_bytes( ini_get( 'memory_limit' ) ) )."</span> Memory.<br/> If you face spinning circle in Elementor Backend.<a href='https://kapasias.com/ultimate-troubleshooting-of-common-issues-of-elementor-page-builder/' target='_blank' rel='nofollow' class='ecafe-wel-btn' style='color:#d84242;background:unset;padding:0;margin:5px 0 0 10px;border:none'>Please have a look</a></div>";
												}
												echo '</div>';
											echo '</div>';
											/*User Info*/	
											
											/*Banner Image*/
											echo '<div class="ecafe-welcome-col ecafe-banner-wrapper">';
												echo '<a class="ecafe-banner-wrapper-link" href="https://kapasias.com/addons-features"></a>';
											echo '</div>';
											/*Banner Image*/
											
											/*Rating*/
											echo '<div class="ecafe-welcome-col ecafe-ratting-wrapper">';
												echo '<div class="ecafe-welcome-title">'.esc_html__('Rate Us 😍✨🌟','essential-classy-addons-for-elementor').'</div>';
												echo '<div class="ecafe-welcome-subtitle">'.esc_html__('Your rating motivates us to do better. And important for us. 😍','essential-classy-addons-for-elementor').'</div>';
												echo '<div class="ecafe-ratting-border"></div>';
												echo '<div class="ecafe-ratting-desc">'.esc_html__('Your reviews will help us to build better product for you. Please share your experience with other users.','essential-classy-addons-for-elementor').'</div>';
												echo '<a href="https://wordpress.org/support/plugin/essential-classy-addons-for-elementor/reviews/?rate=5#new-post" class="ecafe-wel-btn" title="'.esc_attr__('Rate on WordPress','essential-classy-addons-for-elementor').'" target="_blank">'.esc_html__('Rate on WordPress','essential-classy-addons-for-elementor').'</a>';
											echo '</div>';
											/*Rating*/
											
											/*Request New Feature*/
											echo '<div class="ecafe-welcome-col ecafe-request-wrapper">';
												echo '<div class="ecafe-welcome-title">'.esc_html__('Wish to see your favorite feature? 💬💓💌','essential-classy-addons-for-elementor').'</div>';
												echo '<div class="ecafe-welcome-subtitle">'.esc_html__('Please share your idea or some reference you want in our addons.','essential-classy-addons-for-elementor').'</div>';
												echo '<a href="https://www.facebook.com/groups/340597333894907" class="ecafe-wel-btn" title="'.esc_attr__('Share Feedback','essential-classy-addons-for-elementor').'" target="_blank">'.esc_html__('Suggest Feature','essential-classy-addons-for-elementor').'</a>';
											echo '</div>';
											/*Request New Feature*/
											
											/*Info Panel*/
											echo '<div class="ecafe-welcome-col ecafe-info-panel-wrapper">';
												echo '<div class="ecafe-welcome-title">'.esc_html__('Technical Support 👋','essential-classy-addons-for-elementor').'</div>';
												echo '<div class="ecafe-welcome-subtitle">'.esc_html__('Let’s start with queries and end with solutions.','essential-classy-addons-for-elementor').'</div>';
												echo '<a href="https://www.support.kapasias.com/" class="ecafe-wel-btn" title="'.esc_attr__('Share Feedback','essential-classy-addons-for-elementor').'" target="_blank">'.esc_html__('Helpdesk 💬🕘','essential-classy-addons-for-elementor').'</a>';
											echo '</div>';
											/*Info Panel*/
											
											/*Change Log*/
											echo '<div class="ecafe-welcome-col ecafe-changelog-wrapper">';
												echo '<b class="ecafe-changelog-head">Change Log 💬</b><br/>';
												echo '<b><u>Version 3.0</u></b><br/>';
												echo 'Added : Cross Domain Copy Paste<br/>';
												echo 'Added : Contact Form 7<br/>';
												echo 'Added : Gravity Forms<br/>';
												echo 'Added : Grid Post Listing Custom Template option<br/>';
												echo '<a href="https://wordpress.org/plugins/essential-classy-addons-for-elementor/#developers" class="ecafe-wel-btn" title="'.esc_attr__('Share Feedback','essential-classy-addons-for-elementor').'" target="_blank">'.esc_html__('Full Log','essential-classy-addons-for-elementor').'</a>';
											echo '</div>';
											/*Change Log*/
											
										echo '</div>';		
									echo '</div>';	
								echo '</div>';
							}
							
							if($tabForm['id']=='ecafe_widgets'){
								echo '<div class="ecafe-panel-widget-page">';

									echo '<div class="ecafe-panel-head">';
										echo '<div class="ecafe-panel-h-se">';
										echo '<div class="ecafe-panel-hse-edtoggle">';
											echo '<label class="ecafe-edtoggle"><span><svg xmlns="http://www.w3.org/2000/svg" width="23.532" height="20.533" viewBox="0 0 23.532 20.533">
											<path d="M6.9,15.626,0,8.73,2.228,6.5,6.9,11.064,17.729,0,20,2.388Z" transform="translate(4.307) rotate(16)"/>
										  </svg></span><input type="checkbox" id="ecafe-edtoggleId" /> '.esc_html__('Enable/Disable Widgets','essential-classy-addons-for-elementor').'</label>';
											echo '</div>';
										echo '</div>';

										echo '<div class="ecafe-panel-h-filter">';
											echo '<div class="ecafe-panel-h-filter-list">';
											echo '<a href="#" data-catlist="ecafecatall">'.esc_html__('All Widgets','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecateessential">'.esc_html__('Essential','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecateforms">'.esc_html__('Forms','essential-classy-addons-for-elementor').'</a>';											
											echo '<a href="#" data-catlist="ecafecatewoocommerce">'.esc_html__('Woocommerce','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecateembed">'.esc_html__('Embed','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecateacf">'.esc_html__('ACF','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecatecfs">'.esc_html__('CFS','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecatejet">'.esc_html__('Jet','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecatemetabox">'.esc_html__('Metabox','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecatepods">'.esc_html__('PODS','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecatetoolset">'.esc_html__('Toolset','essential-classy-addons-for-elementor').'</a>';
											echo '<a href="#" data-catlist="ecafecatewck">'.esc_html__('WCK','essential-classy-addons-for-elementor').'</a>';											
											echo '</div>';
										echo '</div>';
									echo '</div>';
									/*widget list*/
									echo '<form class="cmb-form" action="'.esc_url( admin_url('admin-post.php') ).'" method="post" id="ecafe_widgets" enctype="multipart/form-data" encoding="multipart/form-data">';
										wp_nonce_field( 'nonce_ecafe_widgets_action', 'nonce_ecafe_widgets' );
										echo '<div class="ecafe-panel-row widget-list">';
											echo $this->ecafeRenderWidgetList();
										echo '</div>';										
										echo '<input type="hidden" name="action" value="ecafe_widgets_options_save">';
										echo '<input type="submit" name="submit-key" value="Save" class="button-primary ecafe-submit-widget">';
									echo '</form>';
									/*widget list*/
								echo '</div>';
							}
							
							if($tabForm['id']=='ecafe_extension'){
								echo '<div class="ecafe-panel-widget-page">';
									/*widget list*/
									echo '<form class="cmb-form" action="'.esc_url( admin_url('admin-post.php') ).'" method="post" id="ecafe_extension" enctype="multipart/form-data" encoding="multipart/form-data">';
										wp_nonce_field( 'nonce_ecafe_extension_action', 'nonce_ecafe_extension' );
										echo '<div class="ecafe-panel-row widget-list">';
											echo $this->ecafeRenderExtraList();
										echo '</div>';										
										echo '<input type="hidden" name="action" value="ecafe_extension_options_save">';
										echo '<input type="submit" name="submit-key" value="Save" class="button-primary ecafe-submit-widget">';
									echo '</form>';
									/*widget list*/
								echo '</div>';
							}
							
							if($tabForm['id']=='ecafe_wp_performance'){
								echo '<div class="ecafe-panel-widget-page">';
									/*widget list*/
									echo '<form class="cmb-form" action="'.esc_url( admin_url('admin-post.php') ).'" method="post" id="ecafe_wp_performance" enctype="multipart/form-data" encoding="multipart/form-data">';
										wp_nonce_field( 'nonce_ecafe_wp_performance_action', 'nonce_ecafe_wp_performance' );
										echo '<div class="ecafe-panel-row widget-list">';
											echo $this->ecafeRenderWpPerfomanceList();
										echo '</div>';										
										echo '<input type="hidden" name="action" value="ecafe_wp_performance_options_save">';
										echo '<input type="submit" name="submit-key" value="Save" class="button-primary ecafe-submit-widget">';
									echo '</form>';
									/*widget list*/
								echo '</div>';
							}
							
							
							if($tabForm['id']=='ecafe_white_label'){
								do_action('ecafeWhiteLabelFree');
							}
						endforeach;
						$show .= ob_get_clean();
					}
				$show .='</div>';
					
		$show .='</div>';		
		echo wp_kses_normalize_entities($show);
    } 
	
	/**
	* Fields option
	*/
    public function fieldsOption(){
        if (!empty($this->metaboxOptions)) {
            return $this->metaboxOptions;
        }
		
		$this->metaboxOptions[] = array(
            'id' => 'ecafe_welcome',
            'title' => 'Welcome',
            'show_on' => array(
                'key' => 'option-page',
                'value' => array(
                    'ecafe_welcome'
                )
            ),
            'show_names' => true,
            'fields' => ''
        );
		
        $this->metaboxOptions[] = array(
            'id' => 'ecafe_widgets',
            'title' => 'Widgets',
            'show_on' => array(
                'key' => 'option-page',
                'value' => array(
                    'ecafe_widgets'
                )
            ),
            'show_names' => true,
            'fields' => '',
        );
				
		$this->metaboxOptions[] = array(
            'id' => 'ecafe_extension',
            'title' => 'Extension',
            'show_on' => array(
                'key' => 'option-page',
                'value' => array(
                    'ecafe_extension'
                )
            ),
            'show_names' => true,
            'fields' => '',
        );
		
		$this->metaboxOptions[] = array(
            'id' => 'ecafe_wp_performance',
            'title' => 'WP Performance',
            'show_on' => array(
                'key' => 'option-page',
                'value' => array(
                    'ecafe_wp_performance'
                )
            ),
            'show_names' => true,
            'fields' => '',
        );
		
		$this->metaboxOptions[] = array(
            'id' => 'ecafe_white_label',
            'title' => 'White Label',
            'show_on' => array(
                'key' => 'option-page',
                'value' => array(
                    'ecafe_white_label'
                )
            ),
            'show_names' => true,
            'fields' => '',
        );		
        return $this->metaboxOptions;
    }
	
	/**
	* Option key get
	*/
    public function optionKeyGet($fieldId)
    {
        $optionTabs = $this->fieldsOption();
        foreach ($optionTabs as $optionTab) { 
            foreach ($optionTab['fields'] as $field) { 
                if ($field['id'] == $fieldId) {
                    return $optionTab['id'];
                }
            }
        }
        return $this->key;
    }
    
    public function __get($field)
    {
        if (in_array($field, array('key','fields','title','optionsPage'), true)) {
            return $this->{$field};
        }
        if ('metaboxOptions' === $field) {
            return $this->fieldsOption();
        }
        
        throw new Exception('Invalid property: ' . $field);
    }
    
}

$EcafePluginOptions = new EcafePluginOptions();
$EcafePluginOptions->hooks();

function EcafeElementorGetOption($key = '')
{
    global $EcafePluginOptions;
    return cmb_get_option($EcafePluginOptions->key, $key);
}