<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Accordion extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-accordion';
	}

    public function get_title() {
        return esc_html__('Accordion', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-accordion-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'accordion','faq' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-accordion' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-accordion' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'accTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Accordion Title' , 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active' => true,],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'accContentType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'content',
				'options' => [
					'content'  => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
					'page_template' => esc_html__( 'Page Template', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$repeater->add_control(
		'accContent',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Accordion Content', 'essential-classy-addons-for-elementor' ),
				'show_label' => false,
				'dynamic' => ['active'   => true,],
				'condition'    => [
					'accContentType' => [ 'content' ],
				],
			]
		);
		$repeater->add_control(
			'accContentTemplate',
			[
				'label'       => esc_html__( 'Elementor Templates', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '0',
				'options'     => \EcafeHelper::getTemplates(),
				'label_block' => 'true',
				'condition'   => [
					'accContentType' => "page_template"
				],
			]
		);
		$repeater->add_control(
			'backendVisible',[
				'label'   => esc_html__( 'Backend Visibility', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),	
				'description' => esc_html__( 'Note : Visible in the backend.', 'essential-classy-addons-for-elementor' ),
				'separator' => 'after',
				'condition'   => [
					'accContentType' => "page_template"
				],
			]
		);
		$repeater->add_control(
			'iconFontawesome',
			[
				'label' => esc_html__( 'Icon Library', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
			]
		);
		$this->add_control(
			'accordionTabs',
			[
				'label' => '',
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'accTitle' => esc_html__( 'Accordion #1', 'essential-classy-addons-for-elementor' ),
						'accContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
					[
						'accTitle' => esc_html__( 'Accordion #2', 'essential-classy-addons-for-elementor' ),
						'accContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
				],
				'title_field' => '{{{ accTitle }}}',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'extras_section',
			[
				'label' => esc_html__( 'Extras', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'openCloseIcon',[
				'label'   => esc_html__( 'Open/Close Icon', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'openIcon',
			[
				'label' => esc_html__( 'Open Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-plus',
					'library' => 'solid',
				],
				'condition' => [
					'openCloseIcon' => 'yes',
				],	
			]
		);
		$this->add_control(
			'closeIcon',
			[
				'label' => esc_html__( 'Close Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-minus',
					'library' => 'solid',
				],
				'condition' => [
					'openCloseIcon' => 'yes',
				],
			]
		);
		$this->add_control(
			'titleTag',
			[
				'label' => esc_html__( 'Title Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => \EcafeHelper::getHtmlTag(),
				'default' => 'div',
				'separator' => 'before',
			]
		);
		$this->add_control(
			'titleAlign',
			[
				'label' => esc_html__( 'Title Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'text-left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'text-center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'text-right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'text-left',
				'label_block' => false,
				'condition' => [
					'openCloseIcon' => 'yes',
					'iconAlign' => 'left',
				],
			]
		);
		$this->add_control(
			'accActive',
			[
				'label' => esc_html__( 'Active Accordion', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => \EcafeHelper::getNumbers(1,20,'none'),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'accOnHover',[
				'label'   => esc_html__( 'On Hover', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'accMulti',[
				'label'   => esc_html__( 'Multi Open', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->end_controls_section();
		
		/*style start*/
		/*icon start*/
		$this->start_controls_section(
            'iconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'iconAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Start', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'right' => [
						'title' => esc_html__( 'End', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => is_rtl() ? 'right' : 'left',
				'toggle' => false,
				'label_block' => false,
				'condition' => [
					'openCloseIcon' => 'yes',
				],
			]
		);
		$this->add_responsive_control(
			'iconPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iconMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iconSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed svg,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsIcontyle' );
		$this->start_controls_tab(
			'tabIconNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened' => 'color: {{VALUE}};',
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed svg,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened',
			]
		);
		$this->add_responsive_control(
			'iconBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowNorm',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon .elementor-accordion-icon-opened',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-opened,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-opened' => 'color: {{VALUE}};',
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-closed svg,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-opened svg,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-closed svg,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-opened svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-opened,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-opened',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-opened,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-opened',
			]
		);
		$this->add_responsive_control(
			'iconBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-opened,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-opened' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowHover',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .elementor-accordion-icon .elementor-accordion-icon-opened,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-closed,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .elementor-accordion-icon .elementor-accordion-icon-opened',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon end*/
		
		/*title start*/
		$this->start_controls_section(
            'titleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'titlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'titleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'titleTypo',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in',				
			]
		);
		$this->add_responsive_control(
  			'svgIconSize',		
  			[		
  				'label' => esc_html__( 'Svg Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsTitletyle' );
		$this->start_controls_tab(
			'tabTitleNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in' => 'color: {{VALUE}};',
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in',
			]
		);
		$this->add_responsive_control(
			'titleBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowNorm',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title .eca-accordion-header-in',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabTitleHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in' => 'color: {{VALUE}};',
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in svg,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in',
			]
		);
		$this->add_responsive_control(
			'titleBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in,
					{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowHover',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowHover',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover .eca-accordion-header-in,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion .eca-accordion-header-in',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*title end*/
		
		/*icon-title start*/
		$this->start_controls_section(
            'iconTitleStyling',
            [
                'label' => esc_html__('Icon & Title Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'iconTitlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iconTitleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .eca-accordion-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsIconTitleStyle' );
		$this->start_controls_tab(
			'iconTitleContentNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconTitleBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .elementor-tab-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconTitleBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title',
			]
		);
		$this->add_responsive_control(
			'iconTitleBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconTitleShadowNorm',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconTitleHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconTitleBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconTitleBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion',
			]
		);
		$this->add_responsive_control(
			'iconTitleBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconTitleShadowHover',
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title:hover,
				{{WRAPPER}} .elementor-accordion .elementor-tab-title.active-accordion',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon-title end*/
		
		/*content start*/
		$this->start_controls_section(
            'contentStyling',
            [
                'label' => esc_html__('Content', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'contentAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content' => 'text-align: {{VALUE}};',
				],
				'default' => 'text-left',
				'label_block' => false,				
			]
		);
		$this->add_responsive_control(
			'contentPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'contentMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'contentTypo',
				'selector' => '{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content',				
			]
		);		
		$this->add_control(
			'contentColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'contentBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'contentBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content',
			]
		);
		$this->add_responsive_control(
			'contentBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'contentShadowNorm',
				'selector' => '{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'contentTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .eca-content-editor.norm-content',
			]
		);
		$this->end_controls_section();
		/*content end*/
		
		/*item start*/
		$this->start_controls_section(
            'itemStyling',
            [
                'label' => esc_html__('Item', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );		
		$this->add_responsive_control(
			'itemMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsItemStyle' );
		$this->start_controls_tab(
			'tabItemN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'itemBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'itemBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item',
			]
		);
		$this->add_responsive_control(
			'itemBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'itemShadowN',
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabItemActive',
			[
				'label' => esc_html__( 'Active', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'itemBgA',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item.active',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'itemBorderA',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item.active',
			]
		);
		$this->add_responsive_control(
			'itemBrA',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item.active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'itemShadowA',
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper .eca-accordion-item.active',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*item end*/
		
		/*box start*/
		$this->start_controls_section(
            'boxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'boxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-accordion-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsBoxtyle' );
		$this->start_controls_tab(
			'tabBoxNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-accordion-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper',
			]
		);
		$this->add_responsive_control(
			'boxBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-accordion-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowNorm',
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabBoxHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-accordion-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'boxBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-accordion-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowHover',
				'selector' => '{{WRAPPER}} .eca-accordion-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*box end*/
		/*style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$uid = uniqid('accordion');
		$id_int = substr( $this->get_id_int(), 0, 3 );
		$EleTemplates = \Elementor\Plugin::instance()->templates_manager->get_source( 'local' )->get_items();
		
		$dataAttr  = [
			'data-id' => $uid,
			'type' => (isset($settings['accOnHover']) && $settings['accOnHover']=='yes') ? 'mouseenter' : 'click',
			'multi' => (isset($settings['accMulti']) && $settings['accMulti']=='yes') ? 'yes' : 'no',
			'speed' => 300
			];
		
		$output = '<div class="eca-accordion-wrapper elementor-accordion eca-icon-pos'.esc_attr($settings['iconAlign']).' '.esc_attr($uid).'" data-settings=\'' .json_encode($dataAttr) . '\'  role="tablist">';
			if(!empty($settings['accordionTabs'])){
				foreach($settings['accordionTabs'] as $index => $item){
					$index++;
					$parent_active = $active = '';
					if($settings["accActive"]==$index){
						$parent_active='active';
						$active='active-accordion';
					}
					
					$tab_title_id = 'elementor-tab-title-' . $id_int . $index;
					$tab_content_id = 'elementor-tab-content-' . $id_int . $index;
					
					$tabTitleKey = $this->get_repeater_setting_key( 'tab_title', 'tabs', $index-1 );
					$this->add_render_attribute( $tabTitleKey, [
						'id' => $tab_title_id,
						'class' => [ 'elementor-tab-title', 'eca-accordion-header', $active, $settings['titleAlign'] ],
						'tabindex' => $id_int . $index,
						'data-tab' => $index,
						'role' => 'tab',
						'aria-controls' => $tab_content_id,
					] );
					
					$tabContentKey = $this->get_repeater_setting_key( 'tab_content', 'tabs', $index-1 );	
					
					$this->add_render_attribute( $tabContentKey, [
						'id' => $tab_content_id,
						'class' => [ 'elementor-tab-content', 'elementor-clearfix', 'eca-accordion-content', $active],
						'data-tab' => $index,
						'role' => 'tabpanel',
						'aria-labelledby' => $tab_title_id,
					] );

					$this->add_inline_editing_attributes( $tabContentKey, 'advanced' );
					
					$toggle_icon='';
					
					$output .= '<div class="eca-accordion-item '.esc_attr($parent_active).'">';
						//Title
						$output .= '<'.\EcafeHelper::check_and_validate_html_tag($settings['titleTag']).' '.$this->get_render_attribute_string( $tabTitleKey ).'>';
						
							if ( $settings['openCloseIcon']=='yes' ){
								$icons='';
								if( !empty( $settings['openIcon'] ) ){
									ob_start();
									\Elementor\Icons_Manager::render_icon( $settings['openIcon'], [ 'aria-hidden' => 'true' ]);
									$icons = ob_get_contents();
									ob_end_clean();
								}
								$icons_active='';
								if( !empty( $settings['closeIcon'] ) ){
									ob_start();
									\Elementor\Icons_Manager::render_icon( $settings['closeIcon'], [ 'aria-hidden' => 'true' ]);
									$icons_active = ob_get_contents();
									ob_end_clean();
								}
								
								if(!empty($icons) && !empty($icons_active)){ 
									$toggle_icon='<span class="elementor-accordion-icon elementor-accordion-icon-'.esc_attr( $settings['iconAlign'] ).'" aria-hidden="true">';									
										$toggle_icon .='<span class="elementor-accordion-icon-closed">'.$icons.'</span>';
										$toggle_icon .='<span class="elementor-accordion-icon-opened">'.$icons_active.'</span>';
										
									$toggle_icon .='</span>';
								}
								
							}
							if(!empty($settings['iconAlign']) && $settings['iconAlign']=='left'){
								$output .= $toggle_icon;
							}
								
							$output .= '<span class="eca-accordion-header-in">';
								if( !empty($item['iconFontawesome']) ){
									ob_start();
									\Elementor\Icons_Manager::render_icon( $item['iconFontawesome'], [ 'aria-hidden' => 'true' ]);
									$icons_loop = ob_get_contents();
									ob_end_clean();
									
									if(!empty($icons_loop)){
										$output .= '<span class="accordion-icon-prefix"><span class="eca-icon-accordion">'.$icons_loop.'</span></span>';
									}
								}								
							$output .= esc_html($item['accTitle']).'</span>';
							if(!empty($settings['iconAlign']) && $settings['iconAlign']=='right'){
								$output .= $toggle_icon;
							}
						$output .= '</'.\EcafeHelper::check_and_validate_html_tag($settings['titleTag']).'>';
						
						//Content/Template
						if( ($item['accContentType']=='content' && !empty($item['accContent'])) || ( $item["accContentType"]=='page_template' && !empty($item['accContentTemplate']) ) ){
							$output .= '<div '.$this->get_render_attribute_string( $tabContentKey ).'>';
						
								if($item['accContentType']=='content' && !empty($item['accContent'])){
									$output .= '<div class="eca-content-editor norm-content">'.$this->parse_text_editor( $item['accContent'] ).'</div>';
								}
							
								if(\Elementor\Plugin::$instance->editor->is_edit_mode() && $item["accContentType"]=='page_template' && !empty($item['accContentTemplate'])){
									if(!empty($item["backendVisible"]) && $item["backendVisible"]=='yes'){
										$output .= '<div class="eca-content-editor">'.\Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $item['accContentTemplate'] ).'</div>';
									}else{
										$get_template_name = '';
										$get_template_id = $item['accContentTemplate'];
										
										if( !empty($EleTemplates) && !empty($get_template_id) ){
											foreach( $EleTemplates as $value ){
												if( $value["template_id"] == $get_template_id ){
													$get_template_name=$value["title"];
												}
											}
										}
										$output .= '<div class="eca-preview-notice"><div class="eca-preview-notice-heading">'.esc_html__('Selected Template :','essential-classy-addons-for-elementor').' <b>"'.esc_html($get_template_name).'"</b></div><div class="eca-preview-notice-desc"><b>'.esc_html__('Note :','essential-classy-addons-for-elementor').'</b> '.esc_html__('Visibility disable in the backend.','essential-classy-addons-for-elementor').'</div></div>';
									}
								}else if($item["accContentType"]=='page_template' && !empty($item['accContentTemplate'])){
									$output .= '<div class="eca-content-editor">'.\Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $item['accContentTemplate'] ).'</div>';
								}
							$output .= '</div>';
						}
					
					$output .= '</div>';
				}
			}
		$output .= '</div>';
		
		echo wp_kses_normalize_entities($output);
	}
}