<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Acf_Email extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-acf-email';
	}

    public function get_title() {
        return esc_html__('ACF : Email', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-acf-icon';
    }

    public function get_categories() {
        return array('ecacf');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-acf-general' ];
    }
	
	public function get_keywords() {
		return [ 'acf','email','acf email' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'ACF : Email', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'acfEmail',
			[
				'label' => esc_html__( 'Email Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'acfEmailType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'static',
				'options' => [
					'static'  => esc_html__( 'Static', 'essential-classy-addons-for-elementor' ),
					'dynamic' => esc_html__( 'Dynamic', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'acfEmailStatic',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'acfEmailType' => 'static'
				]
			]
		);
		$this->add_control(
			'acfEmailDynamic',
			[
				'label' => esc_html__( 'Text Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'acfEmailType' => 'dynamic'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'acfEmailStyling',
            [
                'label' => esc_html__('Acf Email', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'acfEmailTypography',
				'selector' => '{{WRAPPER}} .eca-acfemail',				
			]
		);
		$this->add_responsive_control(
			'acfEmailAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-acfemail' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsacfEmailStyle' );
		$this->start_controls_tab(
			'tabacfEmailNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acfEmailColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-acfemail' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabacfEmailHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acfEmailColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-acfemail:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( class_exists('ACF') ) {
			if(!empty($settings['acfEmail'])){
				echo '<a class="eca-acfemail" href="mailto:';
					echo the_field($settings['acfEmail']);
				echo '">';
					$acfEmailType = !empty($settings['acfEmailType']) ? $settings['acfEmailType'] : 'static';
					$acfEmailStatic = !empty($settings['acfEmailStatic']) ? $settings['acfEmailStatic'] : '';
					$acfEmailDynamic = !empty($settings['acfEmailDynamic']) ? $settings['acfEmailDynamic'] : '';
					
					if(!empty($acfEmailType) && $acfEmailType=='static' && !empty($acfEmailStatic)){
						echo $acfEmailStatic;
					}else if(!empty($acfEmailType) && $acfEmailType=='dynamic' && !empty($acfEmailDynamic)){
						echo the_field($acfEmailDynamic);
					}else if((!empty($acfEmailType) && $acfEmailType=='static') || (!empty($acfEmailType) && $acfEmailType=='dynamic') || (!empty($acfEmailDynamic) || !empty($acfEmailStatic))){
						echo the_field($settings['acfEmail']);
					}					
				echo '</a>';
			}
		}
	}
}