<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Acf_Oembed extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-acf-oembed';
	}

    public function get_title() {
        return esc_html__('ACF : oEmbed', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-acf-icon';
    }

    public function get_categories() {
        return array('ecacf');
    }	
	
	public function get_keywords() {
		return [ 'acf','oembed','acf oembed' ];
	}
	
	public function get_style_depends() {
		return [ 'ecafe-acf-oembed' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'ACF : oEmbed', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'acfoembed',
			[
				'label' => esc_html__( 'oEmbed Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'oEmbed Date Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'aocontrols',
			[
				'label'     => esc_html__( 'Controls', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'default' => 'no',
			]
		);
		$this->add_control(
			'aohd',
			[
				'label'     => esc_html__( 'HD', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'default' => 'yes',
			]
		);
		$this->add_control(
			'aoautohide',
			[
				'label'     => esc_html__( 'Auto Hide', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'default' => 'yes',
			]
		);
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( class_exists('ACF') ) {			
			$acfoembed = !empty($settings['acfoembed']) ? $settings['acfoembed'] : '';
			if(!empty($acfoembed)){
				$iframe = get_field($acfoembed);
				preg_match('/src="(.+?)"/', $iframe, $matches);
				if(!empty($matches[1])){
					$src = $matches[1];
					
					$aocontrols = $aohd = $aoautohide = 0;
					if(isset($settings['aocontrols']) && $settings['aocontrols']=='yes'){
						$aocontrols = 1;
					}
					if(isset($settings['aohd']) && $settings['aohd']=='yes'){
						$aohd = 1;
					}
					if(isset($settings['aoautohide']) && $settings['aoautohide']=='yes'){
						$aoautohide =  1;
					}
					
					$params = array(
						'controls'  => $aocontrols,
						'hd'        => $aohd,
						'autohide'  => $aoautohide
					);
					$new_src = add_query_arg($params, $src);
					$iframe = str_replace($src, $new_src, $iframe);
					$attributes = 'frameborder="0"';
					$iframe = str_replace('></iframe>', ' ' . $attributes . '></iframe>', $iframe);
					
					echo '<div class="eca-acf-oembed">';
						echo  $iframe;
					echo '</div>';
				}
			}
		}
	}
}