<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Acf_Url extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-acf-url';
	}

    public function get_title() {
        return esc_html__('ACF : Url', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-acf-icon';
    }

    public function get_categories() {
        return array('ecacf');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-acf-general' ];
    }
	
	public function get_keywords() {
		return [ 'acf' ,'url', 'acf url' , 'link' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'ACF : Url', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'acfUrl',
			[
				'label' => esc_html__( 'URL Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'acfTextType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'static',
				'options' => [
					'static'  => esc_html__( 'Static', 'essential-classy-addons-for-elementor' ),
					'dynamic' => esc_html__( 'Dynamic', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'acfTextStatic',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'acfTextType' => 'static'
				]
			]
		);
		$this->add_control(
			'acfTextDynamic',
			[
				'label' => esc_html__( 'Text Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'acfTextType' => 'dynamic'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'acfUrlStyling',
            [
                'label' => esc_html__('Acf URL', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'acfUrlTypography',
				'selector' => '{{WRAPPER}} .eca-acfurl',				
			]
		);
		$this->add_responsive_control(
			'acfUrlAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-acfurl' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsacfUrlStyle' );
		$this->start_controls_tab(
			'tabacfUrlNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acfUrlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-acfurl' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabacfUrlHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acfUrlColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-acfurl:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( class_exists('ACF') ) {
			if(!empty($settings['acfUrl'])){							
				echo '<a class="eca-acfurl" href=';
					echo the_field($settings['acfUrl']);
				echo '>';
					$acfTextType = !empty($settings['acfTextType']) ? $settings['acfTextType'] : 'static';
					$acfTextStatic = !empty($settings['acfTextStatic']) ? $settings['acfTextStatic'] : '';
					$acfTextDynamic = !empty($settings['acfTextDynamic']) ? $settings['acfTextDynamic'] : '';
					
					if(!empty($acfTextType) && $acfTextType=='static' && !empty($acfTextStatic)){
						echo $acfTextStatic;
					}else if(!empty($acfTextType) && $acfTextType=='dynamic' && !empty($acfTextDynamic)){
						echo the_field($acfTextDynamic);
					}else if((!empty($acfTextType) && $acfTextType=='static') || (!empty($acfTextType) && $acfTextType=='dynamic') || (!empty($acfTextDynamic) || !empty($acfTextStatic))){
						echo the_field($settings['acfUrl']);
					}					
				echo '</a>';
			}
		}
	}
}