<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Acf_Wysiwyg_Editor extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-acf-wysiwyg-editor';
	}

    public function get_title() {
        return esc_html__('ACF : Wysiwyg Editor', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-acf-icon';
    }

    public function get_categories() {
        return array('ecacf');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-acf-general' ];
    }
	
	public function get_keywords() {
		return [ 'acf','acf editor','acf wysiwyg editor','wysiwyg','acf wysiwyg','editor' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'ACF : Wysiwyg Editor', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'acfWsiwyg',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'acfWysiwygStyling',
            [
                'label' => esc_html__('Acf Wysiwyg', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'acfWysiwygTypography',
				'selector' => '{{WRAPPER}} .ec-acf-wsiwyg-wrapper,{{WRAPPER}} .ec-acf-wsiwyg-wrapper p',				
			]
		);
		$this->add_responsive_control(
			'acfWysiwygAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-acf-wsiwyg-wrapper,{{WRAPPER}} .ec-acf-wsiwyg-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsacfWysiwygStyle' );
		$this->start_controls_tab(
			'tabacfWysiwygNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acfWysiwygColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-acf-wsiwyg-wrapper,{{WRAPPER}} .ec-acf-wsiwyg-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabacfWysiwygHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acfWysiwygColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-acf-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-acf-wsiwyg-wrapper:hover p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( class_exists('ACF') ) {
			$acfWsiwyg = !empty($settings['acfWsiwyg']) ? $settings['acfWsiwyg'] : '';
			if($acfWsiwyg){
				echo '<div class="ec-acf-wsiwyg-wrapper">';
					echo the_field($acfWsiwyg);
				echo '</div>';
			}
		}
	}
}