<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Back_To_Top extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-back-to-top';
	}

    public function get_title() {
        return esc_html__('Back to Top', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-back-to-top-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'back to top' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-back-to-top' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-back-to-top' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Back to Top', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'contentLayout',
			[
				'label' => esc_html__( 'Position', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'layoutright',
				'options' => [
					'layoutleft'  => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
					'layoutright'  => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_responsive_control(
  			'bttOffset',		
  			[		
  				'label' => esc_html__( 'Offset(%)', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px' ],		
				'range' => [		
					'px' => [		
						'min' => 0,		
						'max' => 1,
						'step' => 0.10,
					],
				],
				'default' => [					
					'size' => 0.20,
				],
  			]		
  		);
		$this->add_control(
			'btticonLibrary',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-arrow-alt-circle-up',
					'library' => 'solid',
				],
			]
		);
		$this->add_responsive_control(
  			'iconbottomoffset',		
  			[		
  				'label' => esc_html__( 'Bottom Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ '%'],		
				'range' => [
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} button.ecbctop' => 'bottom:{{SIZE}}%;',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'iconleftoffset',		
  			[		
  				'label' => esc_html__( 'Left Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ '%'],		
				'range' => [
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'condition'    => [
					'contentLayout' => 'layoutleft',
				],
				'selectors' => [		
					'{{WRAPPER}} button.ecbctop' => 'left:{{SIZE}}%;',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'iconrightoffset',		
  			[		
  				'label' => esc_html__( 'Right Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ '%'],		
				'range' => [
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'condition'    => [
					'contentLayout' => 'layoutright',
				],
				'selectors' => [		
					'{{WRAPPER}} button.ecbctop' => 'right:{{SIZE}}%;',
				],		
  			]		
  		);
		$this->end_controls_section();
		
		/*icon*/
		$this->start_controls_section(
            'iconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
  			'iconSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} button.ecbctop i:before' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} button.ecbctop svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsIcontyle' );
		$this->start_controls_tab(
			'tabIconNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} button.ecbctop i:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} button.ecbctop svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} button.ecbctop:hover i:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} button.ecbctop:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon*/
		
		/*button*/
		$this->start_controls_section(
            'buttonStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'buttonPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} button.ecbctop' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'buttonMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} button.ecbctop' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsButtontyle' );
		$this->start_controls_tab(
			'tabButtonNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} button.ecbctop',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} button.ecbctop',
			]
		);
		$this->add_responsive_control(
			'buttonBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} button.ecbctop' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowNorm',
				'selector' => '{{WRAPPER}} button.ecbctop',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabButtonHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} button.ecbctop:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} button.ecbctop:hover',
			]
		);
		$this->add_responsive_control(
			'buttonBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} button.ecbctop:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowHover',
				'selector' => '{{WRAPPER}} button.ecbctop:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*button*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$contentLayout=!empty($settings["contentLayout"]) ? $settings["contentLayout"] : 'layoutright';
		$btticonLibrary=!empty($settings["btticonLibrary"]) ? $settings["btticonLibrary"] : '';
		$bttOffset=!empty($settings["bttOffset"]["size"]) ? $settings["bttOffset"]["size"] : 0.20;
		$icon='';
		if(!empty($btticonLibrary)){
			ob_start();
			\Elementor\Icons_Manager::render_icon( $btticonLibrary, [ 'aria-hidden' => 'true' ]);
			$icon = ob_get_contents();
			ob_end_clean();
		}
		$Output = '<button class="ecbctop '.esc_attr($contentLayout).'" data-bttoffset="'.$bttOffset.'">'.$icon.'</button>';
		
		echo wp_kses_normalize_entities($Output);
	}
}