<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Business_Hours extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-business-hours';
	}

    public function get_title() {
        return esc_html__('Business Hours', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-businesshours-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'business hours','hours','opening','time table','schedule' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-business-hours' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Business Hours', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);		
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'firstIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-microblog',
					'library' => 'brands',
				],
			]
		);
		$repeater->add_control(
			'firstText',
			[
				'label' => esc_html__( 'First Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Label', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeater->add_control(
			'secondText',
			[
				'label' => esc_html__( 'Second Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Description', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeater->add_control(
			'firstIconColor',
			[
				'label' => esc_html__( 'Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list {{CURRENT_ITEM}} .eca-bh-list-left .eca-bh-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list {{CURRENT_ITEM}} .eca-bh-list-left .eca-bh-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$repeater->add_control(
			'firstTextColor',
			[
				'label' => esc_html__( 'First Text Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list {{CURRENT_ITEM}} .eca-bh-list-left' => 'color: {{VALUE}};',
				],
			]
		);
		$repeater->add_control(
			'secondTextColor',
			[
				'label' => esc_html__( 'Second Text Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list {{CURRENT_ITEM}} .eca-bh-list-right' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'bhList',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'separator' => 'before',
				'default' => [
					[						
						'firstText' => 'Sunday',
						'secondText' => 'Closed',
					],
					[						
						'firstText' => 'Monday - Friday',
						'secondText' => '9:00 AM - 6:00 PM',
					],
					[						
						'firstText' => 'Saturday',
						'secondText' => '9:00 AM - 6:00 PM',
					],
				],
				'title_field' => '{{{ firstText }}}',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'contentHeader',
			[
				'label' => esc_html__( 'Header', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'iconLibrary',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-microblog',
					'library' => 'brands',
				],				
			]
		);
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'OPENING HOURS', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Title', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'titleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'contentFooter',
			[
				'label' => esc_html__( 'Footer', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'buttonPosition',
			[
				'label' => esc_html__( 'Position', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),					
					'beforeHeader' => esc_html__( 'Before Header', 'essential-classy-addons-for-elementor' ),
					'afterHeader' => esc_html__( 'After Header', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'buttonType',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'link',
				'options' => [
					'link'  => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),					
					'tel' => esc_html__( 'Tel', 'essential-classy-addons-for-elementor' ),
					'email' => esc_html__( 'E Mail', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'buttonIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-microblog',
					'library' => 'brands',
				],				
			]
		);
		$this->add_control(
			'buttonText',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Contact Us', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'essential-classy-addons-for-elementor' ),
				'show_external' => true,
				'default' => ['url' => '#',],
				'dynamic' => ['active'=> true,],
				'condition' => [
					'buttonType' => 'link',
				],
			]
		);
		$this->add_control(
			'buttonTel',
			[
				'label' => __( 'Tel', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'condition' => [
					'buttonType' => 'tel',
				],
			]
		);
		$this->add_control(
			'buttonEmail',
			[
				'label' => esc_html__( 'Email', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Email', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'buttonType' => 'email',
				],
			]
		);
		$this->end_controls_section();
		
		/*style start*/		
		/*heading icon start*/
		$this->start_controls_section(
            'hiStyling',
            [
                'label' => esc_html__('Heading Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'hiPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hiMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'hiSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 200,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'hiColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hiBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hiBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon',
			]
		);
		$this->add_responsive_control(
			'hiBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hiShadowNorm',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-icon',
			]
		);
		$this->end_controls_section();
		/*heading icon end*/
		
		/*heading text start*/
		$this->start_controls_section(
            'htStyling',
            [
                'label' => esc_html__('Heading Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'hAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
			'htPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'htMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'htTypo',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area',
			]
		);
		$this->add_control(
			'htColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'htBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'htBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area',
			]
		);
		$this->add_responsive_control(
			'htBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'htShadowNorm',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-header .eca-bh-header-area',
			]
		);
		$this->end_controls_section();
		/*heading text end*/
		
		/*button start*/
		$this->start_controls_section(
            'bStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'bPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'bMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_control(
			'bIconStyling',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
  			'biSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 200,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button .eca-bh-icon' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button .eca-bh-icon svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsBiStyle' );
		$this->start_controls_tab(
			'tabBiNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'biNColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button .eca-bh-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button .eca-bh-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabBiHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'biHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover .eca-bh-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover .eca-bh-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'bTextStyling',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btTypo',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button',				
			]
		);
		$this->start_controls_tabs( 'tabsBtStyle' );
		$this->start_controls_tab(
			'tabBtNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'btNColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabBtHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'btHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'bBoxStyling',
			[
				'label' => esc_html__( 'Button Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);	
		$this->start_controls_tabs( 'tabsBStyle' );
		$this->start_controls_tab(
			'tabBNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'bBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'bBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button',
			]
		);
		$this->add_responsive_control(
			'bBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'bShadowNorm',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'bBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'bBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover',
			]
		);
		$this->add_responsive_control(
			'bBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'bShadowHover',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-footer .eca-bh-footer-button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*button end*/
		
		/*list common start*/
		$this->start_controls_section(
            'lctyling',
            [
                'label' => esc_html__('List Common', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'leftListStyling',
			[
				'label' => esc_html__( 'Left Side', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
  			'lLISize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 200,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-left .eca-bh-icon' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-left .eca-bh-icon svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'lLIColor',
			[
				'label' => esc_html__( 'Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-left .eca-bh-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-left .eca-bh-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lLTTypo',
				'label' => esc_html__( 'Text Typography', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-left',
			]
		);
		$this->add_control(
			'lLTColor',
			[
				'label' => esc_html__( 'Text Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-left' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rightListStyling',
			[
				'label' => esc_html__( 'Right Side', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rLTTypo',
				'label' => esc_html__( 'Text Typography', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-right',
			]
		);
		$this->add_control(
			'rLTColor',
			[
				'label' => esc_html__( 'Text Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list-right' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'bListStyling',
			[
				'label' => esc_html__( 'List', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'lcPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'lcMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'lcBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lcBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list',
			]
		);
		$this->add_responsive_control(
			'lcBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'lcShadow',
				'selector' => '{{WRAPPER}} .eca-business-hours .eca-bh-lists .eca-bh-list',
			]
		);
		$this->end_controls_section();
		/*list common end*/
		
		/*box start*/
		$this->start_controls_section(
            'bhBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'bhPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'bhMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-business-hours' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'bhBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-business-hours',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'bhBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-business-hours',
			]
		);
		$this->add_responsive_control(
			'bhBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-business-hours' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'bhShadow',
				'selector' => '{{WRAPPER}} .eca-business-hours',
			]
		);
		$this->end_controls_section();
		/*box end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$iconLibrary=!empty($settings["iconLibrary"]) ? $settings["iconLibrary"] : '';
		$titleText=!empty($settings["title"]) ? $settings["title"] : '';
		$titleTag=!empty($settings["titleTag"]) ? $settings["titleTag"] : 'h1';
		
		$buttonPosition=!empty($settings["buttonPosition"]) ? $settings["buttonPosition"] : 'default';
		$buttonType=!empty($settings["buttonType"]) ? $settings["buttonType"] : 'link';
		$buttonIcon=!empty($settings["buttonIcon"]) ? $settings["buttonIcon"] : '';
		$buttonText=!empty($settings["buttonText"]) ? $settings["buttonText"] : '';
		
		$buttonLink=!empty($settings["buttonLink"]["url"]) ? $settings["buttonLink"]["url"] : '';
		$buttonTel=!empty($settings["buttonTel"]) ? $settings["buttonTel"] : '';
		$buttonEmail=!empty($settings["buttonEmail"]) ? $settings["buttonEmail"] : '';
		
		$title=$titleIconCol=$titleTextCol='';
		if(!empty($iconLibrary) || !empty($titleText)){
			if(!empty($iconLibrary)){
				ob_start();
				\Elementor\Icons_Manager::render_icon( $iconLibrary, [ 'aria-hidden' => 'true' ]);
				$titleIconCol = '<span class="eca-bh-icon">'.ob_get_contents().'</span>';
				ob_end_clean();
			}
			if(!empty($titleText)){
				$titleTextCol = esc_html($titleText);
			}
			
			$title = '<div class="eca-bh-header"><'.\EcafeHelper::check_and_validate_html_tag($titleTag).' class="eca-bh-header-area">'.$titleIconCol.$titleTextCol.'</'.\EcafeHelper::check_and_validate_html_tag($titleTag).'></div>';
		}
		
		
		$button=$buttonSrc=$buttonTextCol=$buttonIconCol='';
		if(!empty($buttonIcon) || !empty($buttonText)){
			if($buttonType=='link' && !empty($buttonLink)){				
				$buttonSrc = $buttonLink;
			}else if($buttonType=='tel' && !empty($buttonTel)){
				$buttonSrc = 'tel:'.$buttonTel;
			}else if($buttonType=='email'&& !empty($buttonEmail)){
				$buttonSrc = 'mailto:'.$buttonEmail;
			}
			
			if(!empty($buttonIcon)){
				ob_start();
				\Elementor\Icons_Manager::render_icon( $buttonIcon, [ 'aria-hidden' => 'true' ]);
				$buttonIconCol = '<span class="eca-bh-icon">'.ob_get_contents().'</span>';
				ob_end_clean();
			}
			if(!empty($buttonText)){
				$buttonTextCol = esc_html($buttonText);
			}
			
			$button ='<div class="eca-bh-footer"><a class="eca-bh-footer-button" href="'.esc_url($buttonSrc).'">'.$buttonIconCol.$buttonTextCol.'</a></div>';
		}
		
		$output ='<div class="eca-business-hours">';
			
			if($buttonPosition=='beforeHeader'){
				$output .= $button;
			}
			
			$output .= $title;
			
			if($buttonPosition=='afterHeader'){
				$output .= $button;
			}
			
			$output .='<ul class="eca-bh-lists">';
				foreach($settings["bhList"] as $item) {
					$firstIcon=!empty($item["firstIcon"]) ? $item["firstIcon"] : '';
					$firstText=!empty($item["firstText"]) ? $item["firstText"] : '';
					$secondText=!empty($item["secondText"]) ? $item["secondText"] : '';
					
					$output .='<li class="eca-bh-list">';
						$output .='<span class="elementor-repeater-item-'.$item['_id'].' eca-bh-list-in">';
								$firstIconCol=$firstTextCol='';
								if(!empty($firstIcon) || !empty($firstText)){
									if(!empty($firstIcon)){
										ob_start();
										\Elementor\Icons_Manager::render_icon( $firstIcon, [ 'aria-hidden' => 'true' ]);
										$firstIconCol = '<span class="eca-bh-icon">'.ob_get_contents().'</span>';
										ob_end_clean();
									}
									if(!empty($firstText)){
										$firstTextCol .= esc_html($firstText);
									}
									
									$output .='<span class="eca-bh-list-left">'.$firstIconCol.$firstTextCol.'</span>';
								}
								if(!empty($secondText)){
									$output .='<span class="eca-bh-list-right">'.$secondText.'</span>';
								}								
					$output .='</li>';	
				}
			$output .='</ul>';
			
			if($buttonPosition=='default'){
				$output .= $button;
			}
		$output .='</div>';
		
		echo wp_kses_normalize_entities($output);
	}
}