<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Button extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-button';
	}

    public function get_title() {
        return esc_html__('Button', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-button-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'button','creative button','cool button','advanced button' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-button' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'contentType',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'normal',
				'options' => [
					'normal'  => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
					'dual' => esc_html__( 'Dual', 'essential-classy-addons-for-elementor' ),
				],
			]
		);		
		$this->add_control(
			'normalStyle',
			[
				'label' => esc_html__( 'Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => esc_html__( 'Style 1', 'essential-classy-addons-for-elementor' ),					
					'style2' => esc_html__( 'Style 2', 'essential-classy-addons-for-elementor' ),
					'style3' => esc_html__( 'Style 3', 'essential-classy-addons-for-elementor' ),
					'style4' => esc_html__( 'Style 4', 'essential-classy-addons-for-elementor' ),
					'style5' => esc_html__( 'Style 5', 'essential-classy-addons-for-elementor' ),
					'style6' => esc_html__( 'Style 6', 'essential-classy-addons-for-elementor' ),
					'style7' => esc_html__( 'Style 7', 'essential-classy-addons-for-elementor' ),
					'style8' => esc_html__( 'Style 8', 'essential-classy-addons-for-elementor' ),
					'style9' => esc_html__( 'Style 9', 'essential-classy-addons-for-elementor' ),
					'style10' => esc_html__( 'Style 10', 'essential-classy-addons-for-elementor' ),
					'style11' => esc_html__( 'Style 11', 'essential-classy-addons-for-elementor' ),
					'style12' => esc_html__( 'Style 12', 'essential-classy-addons-for-elementor' ),
					'style13' => esc_html__( 'Style 13', 'essential-classy-addons-for-elementor' ),
					'style14' => esc_html__( 'Style 14', 'essential-classy-addons-for-elementor' ),
					'style15' => esc_html__( 'Style 15', 'essential-classy-addons-for-elementor' ),
					'style16' => esc_html__( 'Style 16', 'essential-classy-addons-for-elementor' ),
					'style17' => esc_html__( 'Style 17', 'essential-classy-addons-for-elementor' ),
					'style18' => esc_html__( 'Style 18', 'essential-classy-addons-for-elementor' ),
					'style19' => esc_html__( 'Style 19', 'essential-classy-addons-for-elementor' ),
					'style20' => esc_html__( 'Style 20', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'contentType' => 'normal'
				]
			]
		);
		$this->add_control(
			'dualStyle',
			[
				'label' => esc_html__( 'Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => esc_html__( 'Style 1', 'essential-classy-addons-for-elementor' ),					
					'style2' => esc_html__( 'Style 2', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'contentType' => 'dual'
				]
			]
		);
		$this->add_control(
			'buttonText',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Click Here', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'buttonHoverText',
			[
				'label' => esc_html__( 'Hover Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Click Here', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style16'
				],				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'buttonLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
			]
		);
		$this->add_control(
			'buttonSeprator',
			[
				'label' => esc_html__( 'Seprator Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Or', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
				'condition' => [
					'contentType' => 'dual'
				]
			]
		);
		$this->add_control(
			'buttonText2',
			[
				'label' => esc_html__( 'Second Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Click Here', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
				'condition' => [
					'contentType' => 'dual'
				]
			]
		);
		$this->add_control(
			'buttonLink2',
			[
				'label' => esc_html__( 'Second Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
				'condition' => [
					'contentType' => 'dual'
				]
			]
		);
		$this->add_responsive_control(
			'contentAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .eca-button-wrapper-main,{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'bMinWidth',		
  			[		
  				'label' => esc_html__( 'Min. Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main a' => 'min-width:{{SIZE}}px;',
				],		
  			]		
  		);	
		$this->end_controls_section();
		
		/*icon start*/
		$this->start_controls_section(
			'contentIconSection',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'iconSwitch',
			[
				'label'     => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'default' => 'no',
			]
		);
		$this->add_control(
			'iconPosition',
			[
				'label' => esc_html__( 'Position', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'before',
				'options' => [
					'before'  => esc_html__( 'Before', 'essential-classy-addons-for-elementor' ),					
					'after' => esc_html__( 'After', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'iconSwitch' => 'yes'
				]
			]
		);
		$this->add_control(
			'iconLibrary',
			[
				'label' => esc_html__( 'Icon Library', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => [
					'iconSwitch' => 'yes'
				]
			]
		);
		$this->add_control(
			'iconLibrary2',
			[
				'label' => esc_html__( 'Second Icon Library', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => [
					'contentType' => 'dual',
					'iconSwitch' => 'yes'					
				]	
			]
		);
		$this->add_control(
			'sepratorIcon',
			[
				'label' => esc_html__( 'Seprator Icon Library', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => [
					'contentType' => 'dual',
					'iconSwitch' => 'yes',					
				]	
			]
		);
		$this->end_controls_section();
		
		/*style start*/
		$this->start_controls_section(
            'sectionStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentType' => 'normal',					
				]
            ]
        );
		$this->add_responsive_control(
			'buttonPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'buttonMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			's16MaxWidth',		
  			[		
  				'label' => esc_html__( 'Max-Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],		
				],
				'condition' => [
					'contentType' => 'normal',					
					'normalStyle' => 'style16',					
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper' => 'max-width:{{SIZE}}px;',
				],		
  			]		
  		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'buttonTypography',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper',				
			]
		);
		$this->add_responsive_control(
  			'buttonSvgIcon',		
  			[		
  				'label' => esc_html__( 'Svg Icon', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsButtontyle' );
		$this->start_controls_tab(
			'tabButtonN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper svg,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
				{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
				{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap',
			]
		);
		$this->add_responsive_control(
			'buttonBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowN',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
				{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap',
			]
		);
		$this->add_control(
			'buttonTransitionN',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
				{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'buttonTransformN',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper,
				{{WRAPPER}} .eca-button-wrapper-main.normal.style16 .eca-button-wrapper .eca-span-wrap' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabButtonH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover svg,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two',
			]
		);
		$this->add_responsive_control(
			'buttonBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowH',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two',
			]
		);
		$this->add_control(
			'buttonTransitionH',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'buttonTransformH',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal .eca-button-wrapper:hover,
					.eca-button-wrapper-main.normal.style16 .eca-button-wrapper:hover .eca-span-wrap-two' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		/*left button start*/
		$this->start_controls_section(
            'leftButtonStyling',
            [
                'label' => esc_html__('Left Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentType' => 'dual',					
				]
            ]
        );
		$this->add_responsive_control(
			'lrcPadding',
			[
				'label' => esc_html__( 'Left-Right Buttons Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lbTypography',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper',				
			]
		);
		$this->add_responsive_control(
  			'lbSvgIcon',		
  			[		
  				'label' => esc_html__( 'Svg Icon', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsLBButtontyle' );
		$this->start_controls_tab(
			'tabLBN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'lbColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'lbBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lbBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper',
			]
		);
		$this->add_responsive_control(
			'lbBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'lbShadowN',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper',
			]
		);
		$this->add_control(
			'lbTransitionN',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'lbTransformN',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabLBH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'lbColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'lbBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lbBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'lbBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'lbShadowH',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover',
			]
		);
		$this->add_control(
			'lbTransitionH',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'lbTransformH',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper:hover' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*left button end*/
		
		/*right button start*/
		$this->start_controls_section(
            'rightButtonStyling',
            [
                'label' => esc_html__('Right Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentType' => 'dual',					
				]
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rbTypography',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual',				
			]
		);
		$this->add_responsive_control(
  			'rbSvgIcon',		
  			[		
  				'label' => esc_html__( 'Svg Icon', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->start_controls_tabs( 'TabsRBButtontyle' );
		$this->start_controls_tab(
			'tabRBN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'rbColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rbBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rbBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual',
			]
		);
		$this->add_responsive_control(
			'rbBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rbShadowN',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual',
			]
		);
		$this->add_control(
			'rbTransitionN',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'rbTransformN',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabRBH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'rbColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rbBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rbBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover',
			]
		);
		$this->add_responsive_control(
			'rbBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rbShadowH',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover',
			]
		);
		$this->add_control(
			'rbTransitionH',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'rbTransformH',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-button-wrapper-dual:hover' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*right button end*/
		
		/*separator start*/
		$this->start_controls_section(
            'separatorStyling',
            [
                'label' => esc_html__('Separator', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentType' => 'dual',					
				]
            ]
        );		
		$this->add_responsive_control(
			'sepPadding',
			[
				'label' => esc_html__( 'Separator Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);	
		$this->add_responsive_control(
			'sepIconMargin',
			[
				'label' => esc_html__( 'Icon Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-separator .eca-button-icon svg' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);			
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sepTypography',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator',				
			]
		);
		$this->add_responsive_control(
  			'sepSvgIcon',		
  			[		
  				'label' => esc_html__( 'Svg Icon', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->add_control(
			'sepColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'sepBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sepBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator',
			]
		);
		$this->add_responsive_control(
			'sepBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'sepShadowN',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator',
			]
		);
		$this->add_control(
			'sepTransitionN',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'sepTransformN',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.dual .eca-separator' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_section();
		/*separator end*/
		
		/*icon style start*/
		$this->start_controls_section(
            'sectionIconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'iconSwitch' => 'yes',				
				]
            ]
        );
		$this->add_responsive_control(
  			'iconSpaceAfter',		
  			[		
  				'label' => esc_html__( 'Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'condition' => [
					'iconPosition' => 'after',
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i,{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon svg' => 'margin-left: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);	
		$this->add_responsive_control(
  			'iconSpaceBefore',		
  			[		
  				'label' => esc_html__( 'Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'condition' => [
					'iconPosition' => 'before',
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i,{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon svg' => 'margin-right: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->add_responsive_control(		
  			'iconSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i' => 'font-size: {{SIZE}}{{UNIT}};',		
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon svg' => 'width: {{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->add_responsive_control(
			'iconPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i,{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon svg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsIconStyle' );
		$this->start_controls_tab(
			'tabIconN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowN',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i',
			]
		);
		$this->add_control(
			'iconTransformN',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-icon i' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);	
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main a:hover .eca-button-icon i,
					{{WRAPPER}} .eca-button-wrapper-main .eca-separator:hover i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main a:hover .eca-button-icon svg,
					{{WRAPPER}} .eca-button-wrapper-main .eca-separator:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-button-wrapper-main .eca-button-wrapper:hover .eca-button-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main .eca-button-wrapper:hover .eca-button-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-wrapper:hover .eca-button-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowH',
				'selector' => '{{WRAPPER}} .eca-button-wrapper-main .eca-button-wrapper:hover .eca-button-icon i',
			]
		);
		$this->add_control(
			'iconTransformH',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main .eca-button-wrapper:hover .eca-button-icon i' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);	
		$this->end_controls_tab();
		$this->end_controls_tabs();	
		$this->end_controls_section();
		/*icon style end*/
		
		/*icon style start*/
		$this->start_controls_section(
            'sectionAEStyling',
            [
                'label' => esc_html__('Advanced Effect', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => ['style1','style2','style3','style4','style5','style6','style7','style8','style9','style10','style11','style12','style13','style17','style19'],
				]
            ]
        );
		$this->add_control(
			'csColor1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style1 .eca-button-wrapper::before,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style2 .eca-button-wrapper::before,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style3 .eca-button-wrapper:hover::before,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style4 .eca-button-wrapper::before,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style6 .eca-button-wrapper::after,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style6 .eca-button-wrapper::before,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style8 .eca-button-wrapper .eca-inner-wrap,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style9 .eca-button-wrapper .eca-inner-wrap,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style10 .eca-button-wrapper::after,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style11 .eca-button-wrapper::after,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style12 .eca-button-wrapper:before,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style12 .eca-button-wrapper:after,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style13 .eca-button-wrapper:active,
					{{WRAPPER}} .eca-button-wrapper-main.normal.style19 .eca-button-wrapper:after' => 'background: {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style6 .eca-button-wrapper:hover' => 'border-left: 1px solid {{VALUE}};border-right: 1px solid {{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => ['style1','style2','style3','style4','style6','style8','style9','style10','style11','style12','style13','style19'],
				]
			]
		);
		$this->add_control(
			'csColor21',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style5 .eca-button-wrapper::before' => 'box-shadow: inset 0px 0px 0px {{VALUE}};',
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style5 .eca-button-wrapper:hover::before' => 'box-shadow: inset 500px 0px 0px {{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style5',
				]
			]
		);
		$this->add_control(
			'csColor23',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style7 .eca-button-wrapper:hover' => 'box-shadow: inset 0px 100px 0px 0px  {{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style7',
				]
			]
		);
		$this->add_control(
			'csColor241',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style10 .eca-button-wrapper::before' => 'background:{{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style10',
				]
			]
		);
		$this->add_control(
			'csColor242',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style11 .eca-button-wrapper::before' => 'background:{{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style11',
				]
			]
		);
		$this->add_control(
			'csColor25',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style13 .eca-button-wrapper:active' => 'box-shadow: 0 5px {{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style13',
				]
			]
		);
		$this->add_control(
			'csColor26',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-button-wrapper-main.normal.style17 .eca-button-wrapper:hover:after,
						{{WRAPPER}} .eca-button-wrapper-main.normal.style17 .eca-button-wrapper:hover:before' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					'contentType' => 'normal',
					'normalStyle' => 'style17',
				]
			]
		);
		$this->end_controls_section();
		/*icon style end*/
		/*style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$contentType=$settings["contentType"];
		$normalStyle=$settings["normalStyle"];
		$dualStyle=$settings["dualStyle"];
		$buttonText=!empty($settings["buttonText"]) ? $settings["buttonText"] : '';
		$buttonHoverText=!empty($settings["buttonHoverText"]) ? $settings["buttonHoverText"] : '';
		$buttonLink=!empty($settings["buttonLink"]["url"]) ? $settings["buttonLink"]["url"] : '';		
		$buttonText2=!empty($settings["buttonText2"]) ? $settings["buttonText2"] : '';
		$buttonLink2=!empty($settings["buttonLink2"]["url"]) ? $settings["buttonLink2"]["url"] : '';
		$iconSwitch=!empty($settings["iconSwitch"]) ? $settings["iconSwitch"] : 'yes';
		$iconPosition=!empty($settings["iconPosition"]) ? $settings["iconPosition"] : 'before';
		$iconLibrary=!empty($settings["iconLibrary"]) ? $settings["iconLibrary"] : '';
		$iconLibrary2=!empty($settings["iconLibrary2"]) ? $settings["iconLibrary2"] : '';
		$buttonSeprator=!empty($settings["buttonSeprator"]) ? $settings["buttonSeprator"] : '';
		$sepratorIcon=!empty($settings["sepratorIcon"]) ? $settings["sepratorIcon"] : '';
		
		$Style = '';
		if(!empty($contentType) && $contentType=='normal'){
			$Style = $normalStyle;
		}else if(!empty($contentType) && $contentType=='dual'){
			$Style = $dualStyle;
		}
		
		$Output=$firstBtn=$firstButtonOp=$secondButtonOp=$buttonLinkTarget=$buttonLinkNoFollow=$iconPosBefore=$iconPosAfter=$iconPosBefore2=$iconPosAfter2=$sepratorIconLib=$iconPosAfterSep2=$iconPosBeforeSep2='';		
		if((!empty($contentType) && $contentType=='normal') || (!empty($contentType) && $contentType=='dual')){
			if(!empty($normalStyle) || !empty($dualStyle)){
				if(!empty($buttonText)){
					if(!empty($iconSwitch) && $iconSwitch=='yes'){
						if(!empty($iconLibrary)){
							ob_start();
							\Elementor\Icons_Manager::render_icon( $iconLibrary, [ 'aria-hidden' => 'true' ]);
							$firstBtn = ob_get_contents();
							ob_end_clean();
						}						
						if(!empty($iconPosition)){
							if($iconPosition=='before'){
								$iconPosBefore ='<span class="eca-button-icon eca-button-icon-before">'.$firstBtn.'</span>';
							}else if($iconPosition=='after'){
								$iconPosAfter = '<span class="eca-button-icon eca-button-icon-after">'.$firstBtn.'</span>';
							}
						}
					}				
					if ( ! empty( $settings['buttonLink']['url'] ) ) {
						$this->add_link_attributes( 'button', $settings['buttonLink'] );
						$this->add_render_attribute( 'button', 'class', 'eca-button-wrapper' );
					}
					$firstButtonOp .='<a '.$this->get_render_attribute_string( "button" ).'>';
						
						if($normalStyle==='style8' || $normalStyle==='style9' || $normalStyle==='style10' || $normalStyle==='style11' || $normalStyle==='style12' || $normalStyle==='style14' || $normalStyle==='style16' || $normalStyle==='style18' || $normalStyle=='style20'){
							$firstButtonOp .='<span class="eca-span-wrap">'.$iconPosBefore.' '.$buttonText.' '.$iconPosAfter.'</span>';
							
							if($normalStyle==='style16'){
								$firstButtonOp .='<span class="eca-span-wrap-two">'.$buttonHoverText.'</span>';
							}							
							if($normalStyle!='style10' && $normalStyle!='style12' && $normalStyle!='style14' && $normalStyle!='style16' && $normalStyle!='style18' && $normalStyle!='style20'){
								$firstButtonOp .='<div class="eca-inner-wrap"></div>';
							}
						}else{								
							$firstButtonOp .= $iconPosBefore.$buttonText.$iconPosAfter;
						}
					$firstButtonOp .='</a>';
				}
			}			
		}
		
		if(!empty($contentType) && $contentType=='dual'){
			if(!empty($dualStyle)){
				if(!empty($buttonText2)){
					if(!empty($iconSwitch) && $iconSwitch=='yes'){
						if(!empty($iconLibrary2)){
							ob_start();
							\Elementor\Icons_Manager::render_icon( $iconLibrary2, [ 'aria-hidden' => 'true' ]);
							$SecondBtn = ob_get_contents();
							ob_end_clean();
						}
						if(!empty($iconPosition)){
							if(!empty($sepratorIcon)){
								ob_start();
								\Elementor\Icons_Manager::render_icon( $sepratorIcon, [ 'aria-hidden' => 'true' ]);
								$sepratorIconLib = ob_get_contents();
								ob_end_clean();
							}
							if($iconPosition=='before'){
								$iconPosBefore2 ='<span class="eca-button-icon eca-button-icon-before">'.$SecondBtn.'</span>';
								$iconPosBeforeSep2 ='<span class="eca-button-icon eca-button-icon-sep-before">'.$sepratorIconLib.'</span>';
							}else if($iconPosition=='after'){
								$iconPosAfter2 = '<span class="eca-button-icon eca-button-icon-after">'.$SecondBtn.'</span>';
								$iconPosAfterSep2 = '<span class="eca-button-icon eca-button-icon-sep-after">'.$sepratorIconLib.'</span>';
							}
						}
					}
					
					if ( ! empty( $settings['buttonLink2']['url'] ) ) {
						$this->add_link_attributes( 'button2', $settings['buttonLink2'] );
						$this->add_render_attribute( 'button2', 'class', 'eca-button-wrapper-dual' );
					}
					$secondButtonOp .='<a '.$this->get_render_attribute_string( "button2" ).'>'.$iconPosBefore2.' '.$buttonText2.' '.$iconPosAfter2.'</a>';
					$secondButtonOp .='<span class="eca-separator">'.$iconPosBeforeSep2.' '.$buttonSeprator.' '.$iconPosAfterSep2.'</span>';
				}
			}
		}
		
		$Output .='<div class="eca-button-wrapper-main '.$contentType.' '.$Style.'">';
			if(!empty($contentType) && $contentType=='dual'){
				$Output .= '<div class="eca-button-wrapper-inner">';
			}
			
				$Output .= $firstButtonOp;
				$Output .= $secondButtonOp;
			
			if(!empty($contentType) && $contentType=='dual'){
				$Output .= '</div>';
			}
		
		$Output .='</div>';
		
		echo wp_kses_normalize_entities($Output);
		
	}
}