<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Cfs_Hyperlink extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-cfs-hyperlink';
	}

    public function get_title() {
        return esc_html__('CFS : Hyperlink', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-cfs-icon';
    }

    public function get_categories() {
        return array('eccfs');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-cfs-general' ];
    }
	
	public function get_keywords() {
		return [ 'cfs','cfs hyperlink','cfs link','link' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Custom Field Suite : Hyperlink', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'cfsHyperlink',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'cfsHyperlinkStyling',
            [
                'label' => esc_html__('CFS Hyperlink', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfsHyperlinkTypography',
				'selector' => '{{WRAPPER}} .ec-cfs-hyperlink-wrapper .cfs-hyperlink',				
			]
		);
		$this->add_responsive_control(
			'cfsHyperlinkAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-cfs-hyperlink-wrapper .cfs-hyperlink' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabscfsHyperlinkStyle' );
		$this->start_controls_tab(
			'tabcfsHyperlinkNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cfsHyperlinkColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-cfs-hyperlink-wrapper .cfs-hyperlink' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcfsHyperlinkHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cfsHyperlinkColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-cfs-hyperlink-wrapper .cfs-hyperlink:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('CFS_VERSION') ) {
			$cfsHyperlink = !empty($settings['cfsHyperlink']) ? $settings['cfsHyperlink'] : '';
			if($cfsHyperlink){
				echo '<div class="ec-cfs-hyperlink-wrapper">';
					echo CFS()->get( $cfsHyperlink );
				echo '</div>';
			}			
		}
	}
}