<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Cfs_Image extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-cfs-image';
	}

    public function get_title() {
        return esc_html__('CFS : Image', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-cfs-icon';
    }

    public function get_categories() {
        return array('eccfs');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-cfs-general' ];
    }
	
	public function get_keywords() {
		return [ 'cfs','image','cfs image' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Custom Field Suite : Image', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'cfsImageType',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'id',
				'options' => [
					'id'  => esc_html__( 'ID', 'essential-classy-addons-for-elementor' ),
					'url' => esc_html__( 'URL', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'cfsImage',
			[
				'label' => esc_html__( 'Image Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Image Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'cfsImageSize',
				'default' => 'full',				
				'exclude' => [ 'custom' ],
				'condition' => [
					'cfsImageType' => 'id'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'cfsImageStyling',
            [
                'label' => esc_html__('CFS Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
  			'cfsImageSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-cfs-image img' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
			'cfsImagePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-cfs-image img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabscfsImageStyle' );
		$this->start_controls_tab(
			'tabcfsImageNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cfsImageBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-cfs-image img',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cfsImageBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-cfs-image img',
			]
		);
		$this->add_responsive_control(
			'cfsImageBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-cfs-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cfsImageShadowNorm',
				'selector' => '{{WRAPPER}} .eca-cfs-image img',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcfsImageHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cfsImageBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-cfs-image img:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cfsImageBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-cfs-image img:hover',
			]
		);
		$this->add_responsive_control(
			'cfsImageBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-cfs-image img:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cfsImageShadowH',
				'selector' => '{{WRAPPER}} .eca-cfs-image img:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('CFS_VERSION') ) {
			$cfsImageType = !empty($settings['cfsImageType']) ? $settings['cfsImageType'] : 'id';
			$cfsImage = !empty($settings['cfsImage']) ? $settings['cfsImage'] : '';
			if(!empty($cfsImage)){
				$image = CFS()->get( $cfsImage );
				if($image) {
					echo '<div class="eca-cfs-image">';
						if(!empty($cfsImageType) && $cfsImageType == 'id'){
							$size = !empty($settings['cfsImageSize_size']) ? $settings['cfsImageSize_size'] : 'full';					
							echo wp_get_attachment_image( $image, $size );
						}else if(!empty($cfsImageType) && $cfsImageType == 'url'){
							echo '<img src="'.esc_url($image).'" />';
						}
					echo '</div>';
				}				
			}
		}
	}
}