<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Cfs_Text extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-cfs-text';
	}

    public function get_title() {
        return esc_html__('CFS : Text', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-cfs-icon';
    }

    public function get_categories() {
        return array('eccfs');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-cfs-general' ];
    }
	
	public function get_keywords() {
		return [ 'cfs','cfs text','text' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Custom Field Suite : Text', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'cfsText',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'cfsTextTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag('a'),
			]
		);
		$this->add_control(
			'cfsTextLink',
			[
				'label' => esc_html__( 'URL Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'cfsTextTag' => 'a'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'cfsTextStyling',
            [
                'label' => esc_html__('CFS Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfsTextTypography',
				'selector' => '{{WRAPPER}} .ec-cfs-text-wrapper .eca-cfs-text',				
			]
		);
		$this->add_responsive_control(
			'cfsTextAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-cfs-text-wrapper .eca-cfs-text' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabscfsTextStyle' );
		$this->start_controls_tab(
			'tabcfsTextNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cfsTextColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-cfs-text-wrapper .eca-cfs-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcfsTextHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cfsTextColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-cfs-text-wrapper .eca-cfs-text:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('CFS_VERSION') ) {
			$cfsText = !empty($settings['cfsText']) ? $settings['cfsText'] : '';
			if($cfsText){
				echo '<div class="ec-cfs-text-wrapper">';				
					$cfsTextTag= !empty($settings['cfsTextTag']) ? $settings['cfsTextTag'] : 'h1';
					if($cfsTextTag=='a'){
						if(!empty($settings['cfsTextLink'])){							
							echo '<'.\EcafeHelper::check_and_validate_html_tag($cfsTextTag).' class="eca-cfs-text" href=';
								$link = CFS()->get( $settings['cfsTextLink'] );
								if(isset($link) && !empty($link['url'])){
									echo $link['url'];
								}else{
									echo '#';
								}
								
							echo '>';
									echo CFS()->get( $cfsText );
							echo '</'.\EcafeHelper::check_and_validate_html_tag($cfsTextTag).'>';
						}
					}else{
						echo '<'.\EcafeHelper::check_and_validate_html_tag($cfsTextTag).' class="eca-cfs-text">';
						echo CFS()->get( $cfsText );
						echo '</'.\EcafeHelper::check_and_validate_html_tag($cfsTextTag).'>';
					}				
				echo '</div>';
			}
		}
	}
}