<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Changelog extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-changelog';
	}

    public function get_title() {
        return esc_html__('Changelog', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-changelog-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'log','changelog' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-changelog' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-changelog' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Changelog', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'iconLibrary',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-microblog',
					'library' => 'brands',
				],				
			]
		);
		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Version 1.0', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Title', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'titleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$this->add_control(
			'extraText',
			[
				'label' => esc_html__( 'Extra Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( '01 Jan 2021', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);		
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'clLabel',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Label', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeater->add_control(
			'clContent',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'It is a long established fact here.', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter your content here', 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active' => true,],
			]
		);
		$repeater->add_control(
			'clLabelColor',
			[
				'label' => esc_html__( 'Label Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists {{CURRENT_ITEM}} .eca-changelog-label-in' => 'color: {{VALUE}};',
				],
			]
		);
		$repeater->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'clLabelBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-changelog-lists {{CURRENT_ITEM}} .eca-changelog-label-in',
			]
		);
		$this->add_control(
			'clList',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'separator' => 'before',
				'default' => [
					[						
						'clLabel' => 'Add',
						'clContent' => 'It is a long established fact here.',
					],
					[						
						'clLabel' => 'Update',
						'clContent' => 'Various versions have evolved over the years.',
					],
					[						
						'clLabel' => 'Fix',
						'clContent' => 'There are many variations of passages.',
					],
				],
				'title_field' => '{{{ clContent }}}',
			]
		);
		$this->end_controls_section();
		
		/*advanced*/
		$this->start_controls_section(
			'advancedSection',
			[
				'label' => esc_html__( 'Advanced', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'oneByOneAnimation',
			[
				'label'     => esc_html__( 'One By One Animation', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'default' => 'no',
			]
		);
		$this->add_control(
			'oneByOneAnimationGap',
			[
				'label' => __('Gap', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 5000,
				'step' => 100,
				'default' => 700,
				'condition' => [
					'oneByOneAnimation' => 'yes',
				],
			]
		);
		$this->add_control(
			'oneByOneAnimationDelay',
			[
				'label' => esc_html__( 'Delay', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 10000,
				'step' => 100,
				'default' => 700,
				'condition' => [
					'oneByOneAnimation' => 'yes',
				],
			]
		);
		$this->end_controls_section();
		/*advanced*/
		
		/*style start*/		
		/*heading icon start*/
		$this->start_controls_section(
            'hiStyling',
            [
                'label' => esc_html__('Heading Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'hiPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hiMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'hiSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 200,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'hiColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hiBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hiBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon',
			]
		);
		$this->add_responsive_control(
			'hiBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hiShadowNorm',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-icon',
			]
		);
		$this->end_controls_section();
		/*heading icon end*/
		
		/*heading text start*/
		$this->start_controls_section(
            'htStyling',
            [
                'label' => esc_html__('Heading Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'htPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'htMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'htTypo',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title',				
			]
		);		
		$this->add_control(
			'htColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'htBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'htBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title',
			]
		);
		$this->add_responsive_control(
			'htBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'htShadowNorm',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-title',
			]
		);
		$this->end_controls_section();
		/*heading text end*/
		
		/*heading extra text start*/
		$this->start_controls_section(
            'hetStyling',
            [
                'label' => esc_html__('Heading Extra Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'hetPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hetMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hetTypo',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text',				
			]
		);
		$this->add_control(
			'hetColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hetBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hetBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text',
			]
		);
		$this->add_responsive_control(
			'hetBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hetShadowNorm',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header .eca-cl-extra-text',
			]
		);
		$this->end_controls_section();
		/*heading extra text end*/
		
		/*heading box start*/
		$this->start_controls_section(
            'hBoxStyling',
            [
                'label' => esc_html__('Heading Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'hAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-changelog .eca-cl-header' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
			'hPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-cl-header',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header',
			]
		);
		$this->add_responsive_control(
			'hBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-changelog .eca-cl-header' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hShadowNorm',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-cl-header',
			]
		);
		$this->end_controls_section();
		/*heading box end*/
		
		/*lists common start*/
		$this->start_controls_section(
            'listsCommonStyling',
            [
                'label' => esc_html__('Lists Common', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'listsCommonMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_control(
			'commonLabelStyling',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'listsLabelPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'listsLabelTypo',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in',				
			]
		);
		$this->add_responsive_control(
  			'listsLabelMinWidth',		
  			[		
  				'label' => esc_html__( 'Min. Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in' => 'min-width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'listsLabelBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'listsLabelBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in',
			]
		);
		$this->add_responsive_control(
			'listsLabelBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'listsLabelShadow',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list .eca-changelog-label .eca-changelog-label-in',
			]
		);
		$this->add_control(
			'commonDescStyling',
			[
				'label' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'commonDescTypo',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list,{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list p',				
			]
		);
		$this->add_control(
			'commonDescColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list,{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'commonDescLinkStyling',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'commonDescLinkTypo',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list a',				
			]
		);
		$this->add_control(
			'commonDescLinkColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists .eca-changelog-list a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*lists common end*/
		
		/*list box start*/
		$this->start_controls_section(
            'listBoxStyling',
            [
                'label' => esc_html__('List Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'listBoxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'listBoxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'listBoxBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-changelog .eca-changelog-lists',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'listBoxBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists',
			]
		);
		$this->add_responsive_control(
			'listBoxBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-changelog .eca-changelog-lists' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'listBoxShadow',
				'selector' => '{{WRAPPER}} .eca-changelog .eca-changelog-lists',
			]
		);
		$this->end_controls_section();
		/*list box end*/
		/*style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$iconLibrary=!empty($settings["iconLibrary"]) ? $settings["iconLibrary"] : '';
		$title= !empty($settings['title']) ? $settings['title'] : '';
		$titleTag= !empty($settings['titleTag']) ? $settings['titleTag'] : 'h1';
		$extraText= !empty($settings['extraText']) ? $settings['extraText'] : '';
		
		$oneByOneAnimation = (isset($settings['oneByOneAnimation']) && $settings['oneByOneAnimation']=='yes') ? 'yes' : 'no';
		$oneByOneAnimationGap = !empty($settings['oneByOneAnimationGap']) ? $settings['oneByOneAnimationGap'] : 700;
		$oneByOneAnimationDelay = !empty($settings['oneByOneAnimationDelay']) ? $settings['oneByOneAnimationDelay'] : 700;
		$DataAttr=$class='';
		if($oneByOneAnimation == 'yes'){
			$DataAttr .= ' data-one-by-one="'.$oneByOneAnimation.'"';
			$DataAttr .= ' data-gap="'.$oneByOneAnimationGap.'"';
			$DataAttr .= ' data-delay="'.$oneByOneAnimationDelay.'"';
			$class=' one-by-one-anim';
		}
		
		$output ='<div class="eca-changelog '.esc_attr($class).'" '.$DataAttr.'>';
			if(!empty($iconLibrary) || !empty($title) || !empty($extraText)){
				$output .='<div class="eca-cl-header">';
					if(!empty($iconLibrary)){
						ob_start();
						\Elementor\Icons_Manager::render_icon( $iconLibrary, [ 'aria-hidden' => 'true' ]);
						$output .= '<span class="eca-cl-icon">'.ob_get_contents().'</span>';
						ob_end_clean();
					}
					if(!empty($title)){
						$output .= '<'.\EcafeHelper::check_and_validate_html_tag($titleTag).' class="eca-cl-title">'.esc_html($title).'</'.\EcafeHelper::check_and_validate_html_tag($titleTag).'>';
					}
					if(!empty($extraText)){
						$output .= '<span class="eca-cl-extra-text">'.esc_html($extraText).'</span>';
					}
				$output .='</div>';
			}			
			
			$output .='<ul class="eca-changelog-lists">';
				foreach($settings["clList"] as $item) {
					$clLabel=!empty($item["clLabel"]) ? $item["clLabel"] : '';
					$clContent=!empty($item["clContent"]) ? $item["clContent"] : '';
					
					$output .='<li class="eca-changelog-list">';
						$output .='<span class="elementor-repeater-item-'.$item['_id'].' eca-cl-'.esc_attr($clLabel).' eca-changelog-label">';
								$output .='<span class="eca-changelog-label-in">'.esc_html($clLabel).'</span>';
						$output .='</span>';
						$output .= $clContent;
					$output .='</li>';					
				}
			$output .='</ul>';
		$output .='</div>';
		
		echo wp_kses_normalize_entities($output);
	}
}