<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Countdown extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-countdown';
	}

    public function get_title() {
        return esc_html__('Countdown', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-countdown-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'countdown' ];
	}
	
	public function get_style_depends() {
		return [ 'ecafe-countdown' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-countdown' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Countdown', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'horizontal',
				'options' => [
					'vertical'  => esc_html__( 'Vertical', 'essential-classy-addons-for-elementor' ),
					'horizontal' => esc_html__( 'Horizontal', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'type',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),
					'inline' => esc_html__( 'Inline', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'date',
			[
				'label' => esc_html__( 'Date', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( '2023, 11 ,31, 23, 59, 00', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'year, month, day, hours, minutes, seconds', 'essential-classy-addons-for-elementor' ),  
				'dynamic' => ['active' => true,],
			]
		);
		$this->add_control(
			'dateNote',
			[
				'label' => esc_html__( 'Note', 'essential-classy-addons-for-elementor' ),
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => '<br/><br/>year, month, day, hours, minutes, seconds<br/><br/>6 numbers specify year, month, day, hour, minute and second<br/><br/>
				JavaScript counts months from 0 to 11<br/><br/>January = 0<br/><br/>December = 11',
				'content_classes' => 'ec-description-note',
			]
		);
		
		$this->add_control(
			'labelSwitch',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'separator' => 'before',
			]
		);
		$this->add_control(
			'labelDays',
			[
				'label' => esc_html__( 'Days', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'days', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter days', 'essential-classy-addons-for-elementor' ),  
				'dynamic' => ['active' => true,],
				'condition' => [
					'labelSwitch' => 'yes',
				],
			]
		);
		$this->add_control(
			'labelHours',
			[
				'label' => esc_html__( 'Hours', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'hours', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter hours', 'essential-classy-addons-for-elementor' ),  
				'dynamic' => ['active' => true,],
				'condition' => [
					'labelSwitch' => 'yes',
				],
			]
		);
		$this->add_control(
			'labelMinutes',
			[
				'label' => esc_html__( 'Minutes', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'minutes', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter minutes', 'essential-classy-addons-for-elementor' ),  
				'dynamic' => ['active' => true,],
				'condition' => [
					'labelSwitch' => 'yes',
				],
			]
		);
		$this->add_control(
			'labelSeconds',
			[
				'label' => esc_html__( 'Seconds', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'seconds', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter seconds', 'essential-classy-addons-for-elementor' ),  
				'dynamic' => ['active' => true,],
				'condition' => [
					'labelSwitch' => 'yes',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'headingSection',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'headingTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Happy New Year', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Title', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'headingTitleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'descriptionSection',
			[
				'label' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'description',
			[
				'label' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Just another sale of the year', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter description', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'expireSection',
			[
				'label' => esc_html__( 'After Expire Message', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'expireMsg',
			[
				'label' => esc_html__( 'Message', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => ['active' => true,],
				'default' => '<h1>Countdown Has Expired</h1>',
				'placeholder' => esc_html__( 'Enter Expired Message', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->end_controls_section();
		
		/* style start*/
		$this->start_controls_section(
            'daysStyling',
            [
                'label' => esc_html__('Days', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'hideDays',
			[
				'label' => esc_html__( 'Days', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li:nth-child(1)' => 'display: flex;',
				],
			]
		);
		$this->add_control(
			'daystAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(1)' => 'text-align: {{VALUE}};',
				],
				'default' => 'left',
				'label_block' => false,				
			]
		);
		$this->add_control(
			'daysDigitHeading',
			[
				'label' => esc_html__( 'Digit', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
			'ddPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(1)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ddMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(1)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ddTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(1)',				
			]
		);
		$this->add_control(
			'ddColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(1)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'ddTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(1)',
			]
		);
		$this->add_control(
			'daysLabelHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'dlPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(2)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'dlMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(2)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'dlTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(2)',				
			]
		);
		$this->add_control(
			'dlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(2)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'dlTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li > div:nth-child(2)',
			]
		);
		$this->add_control(
			'daysBoxHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'dbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'dbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'dbBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dbBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li',
			]
		);
		$this->add_responsive_control(
			'dbBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'dbShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner li',
			]
		);
		$this->end_controls_section();		
		/*day style start*/
		
		/*hours style start*/
		$this->start_controls_section(
            'hoursStyling',
            [
                'label' => esc_html__('Hours', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'hoursDigitHeading',
			[
				'label' => esc_html__( 'Digit', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
			'hdPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(1)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hdMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(1)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hdTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(1)',				
			]
		);
		$this->add_control(
			'hdColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(1)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'hdTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(1)',
			]
		);
		$this->add_control(
			'hoursLabelHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'hlPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(2)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hlMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(2)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hlTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(2)',				
			]
		);
		$this->add_control(
			'hlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(2)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'hlTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2) > div:nth-child(2)',
			]
		);
		$this->add_control(
			'hoursBoxHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'hbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2)',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2)',
			]
		);
		$this->add_responsive_control(
			'hbBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2)' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(2)',
			]
		);
		$this->end_controls_section();		
		/*hours style start*/
		
		/*minutes style start*/
		$this->start_controls_section(
            'minutesStyling',
            [
                'label' => esc_html__('Minutes', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'minutesDigitHeading',
			[
				'label' => esc_html__( 'Digit', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
			'mdPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(1)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'mdMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(1)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'mdTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(1)',				
			]
		);
		$this->add_control(
			'mdColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(1)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'mdTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(1)',
			]
		);
		$this->add_control(
			'minutesLabelHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'mlPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(2)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'mlMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(2)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'mlTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(2)',				
			]
		);
		$this->add_control(
			'mlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(2)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'mlTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3) > div:nth-child(2)',
			]
		);
		$this->add_control(
			'minutesBoxHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'mbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'mbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'mbBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3)',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'mbBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3)',
			]
		);
		$this->add_responsive_control(
			'mbBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3)' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'mbShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(3)',
			]
		);
		$this->end_controls_section();		
		/*minutes style start*/
		
		/*seconds style start*/
		$this->start_controls_section(
            'secondsStyling',
            [
                'label' => esc_html__('Seconds', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'secondsDigitHeading',
			[
				'label' => esc_html__( 'Digit', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
			'sdPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(1)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'sdMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(1)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sdTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(1)',				
			]
		);
		$this->add_control(
			'sdColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(1)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'sdTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(1)',
			]
		);
		$this->add_control(
			'secondsLabelHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'slPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(2)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'slMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(2)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'slTypography',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(2)',				
			]
		);
		$this->add_control(
			'slColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(2)' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'slTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4) > div:nth-child(2)',
			]
		);
		$this->add_control(
			'secondsBoxHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'sbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4)' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'sbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4)' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'sbBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4)',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sbBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4)',
			]
		);
		$this->add_responsive_control(
			'sbBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4)' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'sbShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner > li:nth-child(4)',
			]
		);
		$this->end_controls_section();		
		/*seconds style start*/
		
		/*counterbox style start*/
		$this->start_controls_section(
            'counterboxStyling',
            [
                'label' => esc_html__('Counter Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'cbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'cbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner',
			]
		);
		$this->add_responsive_control(
			'cbBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main ul.ec-countdown-inner',
			]
		);
		$this->end_controls_section();		
		/*counterbox style start*/
		
		/*heading style start*/
		$this->start_controls_section(
            'headingStyling',
            [
                'label' => esc_html__('Heading', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'hPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hTypo',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading',
			]
		);
		$this->add_control(
			'hAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading' => 'text-align: {{VALUE}};',
				],
				'default' => 'center',
				'label_block' => false,				
			]
		);
		$this->add_control(
			'hColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading',
			]
		);
		$this->add_responsive_control(
			'hBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'hTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-heading',
			]
		);
		$this->end_controls_section();		
		/*heading style start*/
		
		/*description style start*/
		$this->start_controls_section(
            'descriptionStyling',
            [
                'label' => esc_html__('Description', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'dPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'dMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'dTypo',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description',
			]
		);
		$this->add_control(
			'dAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description' => 'text-align: {{VALUE}};',
				],
				'default' => 'center',
				'label_block' => false,				
			]
		);
		$this->add_control(
			'dColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'dBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description',
			]
		);
		$this->add_responsive_control(
			'dBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'dTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'dShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main .ec-countdown-description',
			]
		);
		$this->end_controls_section();		
		/*description style start*/
		
		/*box style start*/
		$this->start_controls_section(
            'boxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'bPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'bMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-countdown-wrapper-main' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'bBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-countdown-wrapper-main',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'bBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main',
			]
		);
		$this->add_responsive_control(
			'bBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-countdown-wrapper-main' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'bShadow',
				'selector' => '{{WRAPPER}} .ec-countdown-wrapper-main',
			]
		);
		$this->end_controls_section();		
		/*box style start*/;	
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		
		$daysHtml=$hoursHtml=$minutesHtml=$secondHtml='';
		
		if(isset($settings['labelSwitch']) && $settings['labelSwitch']=='yes'){
			$labelDays = !empty($settings['labelDays']) ? $settings['labelDays'] : '';
			$labelHours = !empty($settings['labelHours']) ? $settings['labelHours'] : '';
			$labelMinutes = !empty($settings['labelMinutes']) ? $settings['labelMinutes'] : '';
			$labelSeconds = !empty($settings['labelSeconds']) ? $settings['labelSeconds'] : '';
			
			if(!empty($labelDays)){
				$daysHtml = '<div>'.esc_attr($labelDays).'</div>';
			}
			
			if(!empty($labelHours)){
				$hoursHtml = '<div>'.esc_attr($labelHours).'</div>';
			}
			
			if(!empty($labelMinutes)){
				$minutesHtml = '<div>'.esc_attr($labelMinutes).'</div>';
			}
			
			if(!empty($labelSeconds)){
				$secondHtml = '<div>'.esc_attr($labelSeconds).'</div>';
			}
		}
		
		$headingHtml='';
		$headingTitle = !empty($settings['headingTitle']) ? $settings['headingTitle'] : '';
		if(!empty($headingTitle)){
			$headingTitleTag=!empty($settings["headingTitleTag"]) ? $settings["headingTitleTag"] : 'h1';
			$headingHtml = '<'.\EcafeHelper::check_and_validate_html_tag($headingTitleTag).' class="ec-countdown-heading">'.$headingTitle.'</'.\EcafeHelper::check_and_validate_html_tag($headingTitleTag).'>';
		}
		
		$descriptionHtml='';
		$description = !empty($settings['description']) ? $settings['description'] : '';
		if(!empty($description)){
			$descriptionHtml='<div class="ec-countdown-description">'.$description.'</div>';
		}
		
		$date = !empty($settings['date']) ? $settings['date'] : '';
		$expireMsg = !empty($settings['expireMsg']) ? $settings['expireMsg'] : '';
		
		$attr ='';
		if(!empty($date)){
			$attr .= ' data-date="'.esc_attr($date).'"';
		}
		
		if(!empty($expireMsg)){
			$attr .= ' data-expire="'.esc_attr($expireMsg).'"';
		}
		
		$layout = !empty($settings['layout']) ? $settings['layout'] : 'horizontal';
		$type = !empty($settings['type']) ? $settings['type'] : 'default';
		?>
		
		<div class="ec-countdown-wrapper-main ec-countdown-<?php echo $layout; ?> ec-countdown-<?php echo $type; ?>" <?php echo $attr; ?>>			
			<?php echo $headingHtml ?>
			<ul class="ec-countdown-inner">
				<li><div id="ec-cd-day">00</div><?php echo $daysHtml ?></li>
				<li><div id="ec-cd-hours">00</div><?php echo $hoursHtml ?></li>
				<li><div id="ec-cd-minutes">00</div><?php echo $minutesHtml ?></li>
				<li><div id="ec-cd-seconds">00</div><?php echo $secondHtml ?></li>
			</ul>
			<?php echo $descriptionHtml ?>			
		</div>
		<?php
	}
}