<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Darkmode_Styling extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-darkmode-styling';
	}

    public function get_title() {
        return esc_html__('Darkmode Styling', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-darkmode-styling';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'darkmode','dark mode','mode'];
	}
	public function get_style_depends() {
		return [ 'ecafe-darkmode-styling' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Darkmode Styling', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'buttonText',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( '🌛', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonTextDark',
			[
				'label' => esc_html__( 'Dark Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( '🌜', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ecBodyColor',
			[
				'label' => esc_html__( 'Body Background', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'body.ec-darkmode-active' => 'background: {{VALUE}} !important;',
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'ecContentClass',
			[
				'label' => esc_html__( 'Content Class/ID', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'dynamic' => ['active' => true,],
				'label_block' => true,
			]
		);
		$this->add_control(
			'ecContentColor',
			[
				'label' => esc_html__( 'Content Background', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'ecContentClass!' => '',
				],
			]
		);
		
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'ecRepeaterLabel',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active' => true,],
			]
		);
		$repeater->add_control(
			'ecRepeaterColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,				
			]
		);
		$this->add_control(
            'ecRepeaterContent',
            [
				'label' => esc_html__( 'Global Colors', 'essential-classy-addons-for-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [
                        'ecRepeaterLabel' => 'primary',                       
                    ],
					[
                        'ecRepeaterLabel' => 'secondary',
                    ],
					[
                        'ecRepeaterLabel' => 'text',
                    ],
					[
                        'ecRepeaterLabel' => 'accent',
                    ],
                ],
                'separator' => 'before',
				'fields' => $repeater->get_controls(),
                'title_field' => '{{{ ecRepeaterLabel }}}',				
            ]
        );
		$this->end_controls_section();
		
		/*button start*/
		$this->start_controls_section(
            'buttonStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'buttonPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} button.ec-darkmode-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsButtontyle' );
		$this->start_controls_tab(
			'tabButtonN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} button.ec-darkmode-wrap' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} button.ec-darkmode-wrap',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} button.ec-darkmode-wrap',
			]
		);
		$this->add_responsive_control(
			'buttonBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} button.ec-darkmode-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowN',
				'selector' => '{{WRAPPER}} button.ec-darkmode-wrap',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabButtonA',
			[
				'label' => esc_html__( 'Active/Dark', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorA',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} button.ec-darkmode-wrap:hover,.ec-darkmode-active {{WRAPPER}} button.ec-darkmode-wrap' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBackgroundA',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} button.ec-darkmode-wrap:hover,.ec-darkmode-active {{WRAPPER}} button.ec-darkmode-wrap',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderA',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} button.ec-darkmode-wrap:hover,.ec-darkmode-active {{WRAPPER}} button.ec-darkmode-wrap',
			]
		);
		$this->add_responsive_control(
			'buttonBrA',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} button.ec-darkmode-wrap:hover,.ec-darkmode-active {{WRAPPER}} button.ec-darkmode-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowA',
				'selector' => '{{WRAPPER}} button.ec-darkmode-wrap:hover,.ec-darkmode-active {{WRAPPER}} button.ec-darkmode-wrap',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->end_controls_section();
		/*button end*/
	}
	
	 protected function render() {
        $settings = $this->get_settings_for_display();
		$ecContentClass = !empty($settings['ecContentClass']) ? $settings['ecContentClass'] : '';
		$buttonText = !empty($settings['buttonText']) ? $settings['buttonText'] : '';
		$buttonTextDark = !empty($settings['buttonTextDark']) ? $settings['buttonTextDark'] : '';
		$ecContentColor = !empty($settings['ecContentColor']) ? $settings['ecContentColor'] : '';
		$ecRepeaterContent=$settings["ecRepeaterContent"];
		$kitFrontend = \Elementor\Plugin::$instance->kits_manager->get_active_kit_for_frontend();
		$kitFrontendId = $kitFrontend->get_id();
		
		if(!empty(intval($kitFrontendId))){
			$elementorDefaultsItem = $kitFrontend->get_settings_for_display( 'system_colors' );
			$elementorNewAddedItem = $kitFrontend->get_settings_for_display( 'custom_colors' );
		
			if ( ! $elementorDefaultsItem ) {
				$elementorDefaultsItem = [];
			}

			if ( ! $elementorNewAddedItem ) {
				$elementorNewAddedItem = [];
			}

			$mergeItems = array_merge( $elementorDefaultsItem, $elementorNewAddedItem );
			$sort=0;
			$mergeItemName=$mergeItemColor=[];
			
			foreach ( $mergeItems as $sort => $mergeItemsNew ) {
				$mergeItemName[] = $mergeItemsNew['_id'];			
			}

			foreach($ecRepeaterContent as $sort => $mergeItemColorCheck) {			
				if ( ! empty( $mergeItemColorCheck['ecRepeaterColor'])){					
					$mergeItemColor[] = $mergeItemColorCheck['ecRepeaterColor'];
				}
				$sort++;
			}

			$array1 = array_values($mergeItemName);
			$array2 = array_values($mergeItemColor);
			
			echo '<style>';
			if(isset($array1) && !empty($array1) && isset($array2) && !empty($array2)){
				echo '.elementor-kit-'.intval($kitFrontendId).'.ec-darkmode-active{';
				foreach($array1 as $sort => $sortArray) {
					if(!empty($sortArray) && isset($array2[$sort]) && !empty($array2[$sort])){
						echo '--e-global-color-'.$sortArray.' : '.$array2[$sort].';';
					}
				}
				echo '}';
				
				if(!empty($ecContentClass) && !empty($ecContentColor)){
					echo '.elementor-kit-'.intval($kitFrontendId).'.ec-darkmode-active '.esc_attr($ecContentClass).'{background-color:'.$ecContentColor.' !important;}';
				}			
			}
			echo '.ec-darkmode-active button.ec-darkmode-wrap span.ec-dmw-lite,button.ec-darkmode-wrap span.ec-dmw-dark{opacity:0}.ec-darkmode-active button.ec-darkmode-wrap span.ec-dmw-dark{opacity:1}button.ec-darkmode-wrap>span{position:absolute}button.ec-darkmode-wrap{position:relative;display:flex;align-items:center;justify-content:center;padding:15px;border:1px solid #000;color:#000;transition: all 0.3s linear;overflow:hidden;    background:transparent;}button.ec-darkmode-wrap:hover,.ec-darkmode-active button.ec-darkmode-wrap{background: #000;}}</style>';
			
			echo '<button type="button" class="ec-darkmode-wrap"><span class="ec-dmw-lite">'.esc_attr($buttonText).'</span><span class="ec-dmw-dark">'.esc_attr($buttonTextDark).'</span></button>';
			
			$inlineJS = 'jQuery("button.ec-darkmode-wrap").on("click", function() {
							if(jQuery("body").hasClass("ec-darkmode-active")){
								jQuery("body").removeClass("ec-darkmode-active");
							}else{
								jQuery("body").addClass("ec-darkmode-active");
							}
						});';
			
			echo wp_print_inline_script_tag($inlineJS);
		}
	}
}