<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Dropcap extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-dropcap';
	}

    public function get_title() {
        return esc_html__('Dropcap', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-dropcap-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'dropcap' ];
	}
	
	public function get_style_depends() {
		return [ 'ecafe-dropcap' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Dropcap', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'contentLayout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'layout1',
				'options' => [
					'layout1'  => esc_html__( 'Layout 1', 'essential-classy-addons-for-elementor' ),
					'layout2'  => esc_html__( 'Layout 2', 'essential-classy-addons-for-elementor' ),
					'layout3'  => esc_html__( 'Layout 3', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'contentSrc',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using Content here.', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter your content here', 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active' => true,],
			]
		);
		$this->add_control(
			'contentSrcBackend',
			[
				'label' => esc_html__( 'Background Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'A' ),
				'placeholder' => esc_html__( 'Enter your Text', 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active' => true,],
				'condition' => [
					'contentLayout' => 'layout3'
				]
			]
		);
		$this->add_responsive_control(
			'contentSrcBackendAlign',
			[
				'label' => esc_html__( 'Background Text Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'csbalignleft' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'csbaligncenter' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'csbaligright' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'csbaligncenter',
				'condition' => [
					'contentLayout' => 'layout3'
				]
			]
		);
		$this->add_responsive_control(
			'dTextAlign',
			[
				'label' => esc_html__( 'Text Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-dropcap-wrapper.layout3' => 'text-align:{{VALUE}};',
                ],
				'condition' => [
					'contentLayout' => 'layout3'
				]
			]
		);
		$this->end_controls_section();
		
		/*general*/
		$this->start_controls_section(
            'generalStyling',
            [
                'label' => esc_html__('General', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'generalTypo',
				'selector' => '{{WRAPPER}} .eca-dropcap-wrapper',				
			]
		);
		$this->add_control(
			'generalColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-dropcap-wrapper' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*general*/
		
		/*first latter*/
		$this->start_controls_section(
            'firstLatterStyling',
            [
                'label' => esc_html__('First Latter', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentLayout' => ['layout1','layout2'],				
				]
            ]
        );
		$this->add_responsive_control(
			'firstLatterPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-dropcap-wrapper:first-letter' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'firstLatterTypo',
				'selector' => '{{WRAPPER}} .eca-dropcap-wrapper:first-letter',				
			]
		);
		$this->add_control(
			'firstLatterColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-dropcap-wrapper:first-letter' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*first latter*/
		
		/*background text*/
		$this->start_controls_section(
            'backgroundTextStyling',
            [
                'label' => esc_html__('Background Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'contentLayout' => 'layout3',
				]
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'backgroundTextTypo',
				'selector' => '{{WRAPPER}} .eca-dropcap-wrapper.layout3:before ',				
			]
		);
		$this->add_control(
			'backgroundTextColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-dropcap-wrapper.layout3:before ' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*background text*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$contentLayout=!empty($settings["contentLayout"]) ? $settings["contentLayout"] : 'layout1';
		$contentSrc=!empty($settings["contentSrc"]) ? $settings["contentSrc"] : '';
		$contentSrcBackend=!empty($settings["contentSrcBackend"]) ? $settings["contentSrcBackend"] : '';
		$contentSrcBackendAlign=!empty($settings["contentSrcBackendAlign"]) ? $settings["contentSrcBackendAlign"] : 'csbaligncenter';
		
		$DataAttr=$csba='';
		if($contentLayout==='layout3' && !empty($contentSrcBackend)){
			$DataAttr = 'data-first-letter='.$contentSrcBackend;
			$csba = $contentSrcBackendAlign;
		}
		$Output = '<div class="eca-dropcap-wrapper '.esc_attr($contentLayout).' '.esc_attr($csba).'" '.esc_attr($DataAttr).'>'.$contentSrc.'</div>';
		
		echo wp_kses_normalize_entities($Output);
		
	}
}