<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Gravity_Forms extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-gravity-forms';
	}

    public function get_title() {
        return esc_html__('Gravity Forms', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-gravity-icon';
    }

    public function get_categories() {
        return array('ecforms');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-gravity-forms' ];
    }
	
	public function get_keywords() {
		return [ 'form','forms','gravity','gravity forms' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Gravity Forms', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'ecgf',
			[
				'label' => esc_html__( 'Select', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => $this->ecgf(),
			]
		);
		$this->add_control(
		    'ecgfTitle',
		    [
				'label'   => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
		    ]
		);
		$this->add_control(
		    'ecgfDesc',
		    [
				'label'   => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
		    ]
		);
		$this->add_control(
		    'ecgfajax',
		    [
				'label'   => esc_html__( 'Ajax Based', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
		    ]
		);
		$this->end_controls_section();
		
		/*style*/
		$this->start_controls_section(
            'gfHFStyling',
            [
                'label' => esc_html__('Heading', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfHFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfHFMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfHFTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title',				
			]
		);
		$this->add_control(
			'gfHFColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfHFBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfHFBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title',
			]
		);
		$this->add_responsive_control(
			'gfHFBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfHFShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfHFTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_title',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfDFStyling',
            [
                'label' => esc_html__('Description', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfDFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfDFMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfDFTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description',				
			]
		);
		$this->add_control(
			'gfDFColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfDFBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfDFBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description',
			]
		);
		$this->add_responsive_control(
			'gfDFBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfDFShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfDFTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_heading .gform_description',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfLabelStyling',
            [
                'label' => esc_html__('Label', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfLPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfLMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfLTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_label',				
			]
		);
		$this->add_control(
			'gfLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .gfield_label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_label',
			]
		);
		$this->add_responsive_control(
			'gfLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfLShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfLTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_label',
			]
		);
		$this->add_control(
			'gfLRHeading',
			[
				'label' => esc_html__( 'Required', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'gfLRPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_label .gfield_required' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfLRTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_label .gfield_required',				
			]
		);
		$this->add_control(
			'gfLRColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_label .gfield_required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfInputStyling',
            [
                'label' => esc_html__('Input', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfIPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfITypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input',				
			]
		);
		$this->add_control(
			'gfIColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabsgfIstyle' );
		$this->start_controls_tab(
			'tabgfINorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfIColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfIBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfIBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input',
			]
		);
		$this->add_responsive_control(
			'gfIBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfIShadowN',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfITextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabgfIFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfIColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfIBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfIBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input:focus',
			]
		);
		$this->add_responsive_control(
			'gfIBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfIShadowF',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfITextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfTextareaStyling',
            [
                'label' => esc_html__('Textarea', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfITAPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'gfITAHeight',		
  			[		
  				'label' => esc_html__( 'Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-gf-wrapper textarea' => 'height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfITATypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea',				
			]
		);
		$this->add_control(
			'gfITAColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper textarea::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabsgfITAstyle' );
		$this->start_controls_tab(
			'tabgfITANorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfITAColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper textarea' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfITABgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper textarea',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfITABorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea',
			]
		);
		$this->add_responsive_control(
			'gfITABrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper textarea' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfITAShadowN',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfITATextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabgfITAFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfITAColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper textarea:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfITABgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper textarea:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfITABorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea:focus',
			]
		);
		$this->add_responsive_control(
			'gfITABrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper textarea:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfITAShadowF',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'gfITATextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper textarea:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfSelectStyling',
            [
                'label' => esc_html__('Select', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfiSPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper select' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfiSTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper select',				
			]
		);
		$this->add_control(
			'gfiSColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper select' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfiSColorON',
			[
				'label' => esc_html__( 'Option Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper select option' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfiSBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper select',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfiSBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper select',
			]
		);
		$this->add_responsive_control(
			'gfiSBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper select' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfiSShadowN',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper select',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfRadioStyling',
            [
                'label' => esc_html__('Radio', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfRPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_radio .gfield_radio .gchoice' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfRMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_radio .gfield_radio .gchoice' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfRTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_radio .gfield_radio .gchoice label',				
			]
		);
		$this->start_controls_tabs( 'tabsgfRStyle' );
		$this->start_controls_tab(
			'tabgfRNorm',
			[
				'label' => esc_html__( 'Checked', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfRColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:checked + label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfRBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:checked + label:after',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfRBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:checked + label:before',
			]
		);
		$this->add_responsive_control(
			'gfRBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:checked + label:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfRShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:checked + label:before',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabgfRUN',
			[
				'label' => esc_html__( 'Unchecked', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfRColorU',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:not(:checked) + label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfRBgU',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:not(:checked) + label:before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfRBorderU',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:not(:checked) + label:before',
			]
		);
		$this->add_responsive_control(
			'gfRBrU',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:not(:checked) + label:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfRShadowU',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper form [type="radio"]:not(:checked) + label:before',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfCheckboxStyling',
            [
                'label' => esc_html__('Checkbox', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfCPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox .gchoice' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfCMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox .gchoice' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfCTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox .gchoice label',				
			]
		);
		$this->start_controls_tabs( 'tabsgfCStyle' );
		$this->start_controls_tab(
			'tabgfCNorm',
			[
				'label' => esc_html__( 'Checked', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox .gchoice label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfCIColor',
			[
				'label' => esc_html__( 'Check Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]:checked:before' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfCBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]:checked',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfCBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]:checked',
			]
		);
		$this->add_responsive_control(
			'gfCBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]:checked' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfCShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]:checked',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabgfCUN',
			[
				'label' => esc_html__( 'Unchecked', 'essential-classy-addons-for-elementor' ),
			]
		);		
		$this->add_control(
			'gfCIColorU',
			[
				'label' => esc_html__( 'Unheck Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]:before' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfCBgU',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfCBorderU',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]',
			]
		);
		$this->add_responsive_control(
			'gfCBrU',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfCShadowU',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_checkbox input[type=checkbox]',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfFUStyling',
            [
                'label' => esc_html__('File Upload', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfFUPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input[type="file"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfFUTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]',				
			]
		);
		$this->add_control(
			'gfFUColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input[type="file"]' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfFUBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfFUBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]',
			]
		);
		$this->add_responsive_control(
			'gfFUBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper input[type="file"]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfFUShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]',
			]
		);
		$this->add_control(
			'gfFUBHeading',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'gfFUBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfFUBTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button',
			]
		);
		$this->add_control(
			'gfFUBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfFUBBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfFUBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button',
			]
		);
		$this->add_responsive_control(
			'gfFUBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfFUBShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper input[type="file"]::-webkit-file-upload-button',
			]
		);
		$this->add_control(
			'gfFURHeading',
			[
				'label' => esc_html__( 'Rules', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfFURTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_fileupload_rules',				
			]
		);
		$this->add_control(
			'gfFURColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_fileupload_rules' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfNPSStyling',
            [
                'label' => esc_html__('Next/Previous & Submit', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'gfSBHeading',
			[
				'label' => esc_html__( 'Submit', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
			'gfSBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfSBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfSBTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button',				
			]
		);
		$this->start_controls_tabs( 'tabgfSB' );
		$this->start_controls_tab(
			'gfSBN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'gfSBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_button' => 'color: {{VALUE}}',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'gfSBBg',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfSBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button',
			]
		);
		$this->add_responsive_control(
			'gfSBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'gfSBShadow',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button',
				'separator' => 'before',
			]
		);	
		$this->end_controls_tab();
		$this->start_controls_tab(
			'gfSBH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'gfSBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_button:hover' => 'color: {{VALUE}}',
				],
				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'gfSBBgH',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfSBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button:hover',
			]
		);
		$this->add_responsive_control(
			'gfSBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'gfSBShadowH',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_button:hover',				
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'gfNBHeading',
			[
				'label' => esc_html__( 'Next', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'gfNBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_next_button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfNBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_next_button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfNBTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button',				
			]
		);
		$this->start_controls_tabs( 'tabsgfNB' );
		$this->start_controls_tab(
			'gfNBN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'gfNBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_next_button' => 'color: {{VALUE}}',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'gfNBBg',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfNBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button',
			]
		);
		$this->add_responsive_control(
			'gfNBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_next_button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'gfNBShadow',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button',				
			]
		);	
		$this->end_controls_tab();
		$this->start_controls_tab(
			'gfNBH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'gfNBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_next_button:hover' => 'color: {{VALUE}}',
				],
				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'gfNBBgH',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfNBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button:hover',
			]
		);
		$this->add_responsive_control(
			'gfNBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_next_button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'gfNBShadowH',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_next_button:hover',				
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'gfPBHeading',
			[
				'label' => esc_html__( 'Previous', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'gfPBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_previous_button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfPBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_previous_button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfPBTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button',				
			]
		);
		$this->start_controls_tabs( 'tabsgfPB' );
		$this->start_controls_tab(
			'gfPBBN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'gfPBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_previous_button' => 'color: {{VALUE}}',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'gfPBBg',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfPBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button',
			]
		);
		$this->add_responsive_control(
			'gfPBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_previous_button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'gfPBShadow',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button',
			]
		);	
		$this->end_controls_tab();
		$this->start_controls_tab(
			'gfPBH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'gfPBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_previous_button:hover' => 'color: {{VALUE}}',
				],
				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'gfPBBgH',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfPBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button:hover',
			]
		);
		$this->add_responsive_control(
			'gfPBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_previous_button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'gfPBShadowH',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_previous_button:hover',				
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfAPPStyling',
            [
                'label' => esc_html__('Consent', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfAPPPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfAPPMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfAPPTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent label',				
			]
		);
		$this->start_controls_tabs( 'tabsgfAPPStyle' );
		$this->start_controls_tab(
			'tabgfAPPNorm',
			[
				'label' => esc_html__( 'Checked', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'gfAPPColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfAPPIColor',
			[
				'label' => esc_html__( 'Check Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]:checked:before' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfAPPBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]:checked',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfAPPBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]:checked',
			]
		);
		$this->add_responsive_control(
			'gfAPPBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]:checked' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfAPPShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]:checked',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabgfAPPUN',
			[
				'label' => esc_html__( 'Unchecked', 'essential-classy-addons-for-elementor' ),
			]
		);		
		$this->add_control(
			'gfAPPColorU',
			[
				'label' => esc_html__( 'Unheck Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]:before' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfAPPBgU',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfAPPBorderU',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]',
			]
		);
		$this->add_responsive_control(
			'gfAPPBrU',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfAPPShadowU',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .ginput_container_consent input[type=checkbox]',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfStepsStyling',
            [
                'label' => esc_html__('Steps', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'gfStepsCheading',
			[
				'label' => esc_html__( 'Current', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfStepsCTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar_title .gf_step_current_page',				
			]
		);		
		$this->add_control(
			'gfStepsCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar_title .gf_step_current_page' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfStepsCoheading',
			[
				'label' => esc_html__( 'Count', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfStepsCoTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar_title .gf_step_page_count',				
			]
		);		
		$this->add_control(
			'gfStepsCoColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar_title .gf_step_page_count' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfStepsTheading',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfStepsTTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar_title',				
			]
		);		
		$this->add_control(
			'gfStepsTColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar_title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfStepsPheading',
			[
				'label' => esc_html__( 'Progress', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'gfStepsPTColor',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar .gf_progressbar_percentage' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfStepsPFColor',
			[
				'label' => esc_html__( 'Fill', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar .gf_progressbar_percentage' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'gfStepsPEColor',
			[
				'label' => esc_html__( 'Empty', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gf_progressbar_wrapper .gf_progressbar' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfVMStyling',
            [
                'label' => esc_html__('Validation', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfVMPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfVMMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfVMTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message',				
			]
		);		
		$this->add_control(
			'gfVMColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfVMBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfVMBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message',
			]
		);
		$this->add_responsive_control(
			'gfVMBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfVMShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gfield_validation_message',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfVEStyling',
            [
                'label' => esc_html__('Error', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfVEPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfVEMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfVETypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors .gform_submission_error',				
			]
		);		
		$this->add_control(
			'gfVEColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors .gform_submission_error' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfVEBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfVEBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors',
			]
		);
		$this->add_responsive_control(
			'gfVEBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfVEShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_validation_errors',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfRMStyling',
            [
                'label' => esc_html__('Response', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfRMPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfRMMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'gfRMTypo',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message',				
			]
		);		
		$this->add_control(
			'gfRMColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfRMBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfRMBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message',
			]
		);
		$this->add_responsive_control(
			'gfRMBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfRMShadow',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper .gform_confirmation_message',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'gfBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'gfBoxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'gfBoxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-gf-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsgfBoxStyle' );
		$this->start_controls_tab(
			'tabgfBoxNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfBoxBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfBoxBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper',
			]
		);
		$this->add_responsive_control(
			'gfBoxBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfBoxShadowN',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabgfBoxHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'gfBoxBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-gf-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'gfBoxBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-gf-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'gfBoxBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-gf-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'gfBoxShadowH',
				'selector' => '{{WRAPPER}} .ec-gf-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();		
	}
	
	private function ecgf() {	
		if ( class_exists( 'GFCommon' ) ) {
		$gravityForm = \RGFormsModel::get_forms( null, 'title' );
		$gravityFormList = ['0' => esc_html__( 'Select Form', 'essential-classy-addons-for-elementor' )];
			if ( ! empty( $gravityForm ) && ! is_wp_error( $gravityForm ) ) {
				foreach ( $gravityForm as $form ) {   
					$gravityFormList[ $form->id ] = $form->title;
				}
			}
		}else{
			$gravityFormList = ['0' => esc_html__( 'No Form Found', 'essential-classy-addons-for-elementor' ) ];
		}

		return $gravityFormList;		
	}
	
	private function ecGfShortcode() {
		$settings = $this->get_settings_for_display();

		if (empty($settings['ecgf'])) {
			return '<div class="ec-gf-notice-wrapper">'.esc_html__('Select a Gravity Forms', 'essential-classy-addons-for-elementor').'</div>';
		}
		
		$attributes = [
			'id'	=> $settings['ecgf'],
			'title' => !empty($settings['ecgfTitle']) ? 'true' : 'false',
			'description' => !empty($settings['ecgfDesc']) ? 'true' : 'false',			
			'ajax' => !empty($settings['ecgfajax']) ? 'true' : 'false',
		];

		$this->add_render_attribute( 'ecFormShortcode', $attributes );
		
		$shortcode[] = sprintf( '[gravityform %s]', $this->get_render_attribute_string( 'ecFormShortcode' ) );

		return implode("", $shortcode);
	}
	
	protected function render() {
        $settings = $this->get_settings_for_display();
		
		$output = '<div class="ec-gf-wrapper">';
			$output .= do_shortcode( $this->ecGfShortcode() );				
		$output .= '</div>';
		echo $output;
	}
}