<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Grid_Post_Listing extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-grid-post-listing';
	}

    public function get_title() {
        return esc_html__('Grid Post Listing', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-gridpostlisting-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'post', 'post list', 'listing' , 'cpt', 'grid', 'masonry' ];
	}
	
	public function get_style_depends() {
		return [ 'ecafe-post-listing' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-isotope','ecafe-min-js', 'ecafe-imagesloaded', 'ecafe-post-listing' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);		
		$this->add_control(
			'selectPostType',
			[
				'label' => esc_html__( 'Post Types', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'post',
				'options' => \EcafeHelper::getPostTypes(),
			]
		);
		$this->add_control(
			'style',
			[
				'label' => esc_html__( 'Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style-1',
				'options' => \EcafeHelper::getStyleLoop( 9 ,'','yes' ),
			]
		);
		$this->add_control(
			'grid_post_custom_template',
			[
				'label' => esc_html__( 'Custom Template', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT2,
				'label_block' => true,
				'default'     => '0',				
				'options' => \EcafeHelper::getTemplates(),
				'condition' => [
					'style' => 'custom-template',
				],
			]
		);
		$this->add_control(
			'postLayout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'grid',
				'options' => \EcafeHelper::getListLayout(),
			]
		);
		$this->add_control(
			'style8FlipType',
			[
				'label' => esc_html__( 'Flip Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'horizontal',
				'options' => [
					"horizontal" => esc_html__("Horizontal", 'essential-classy-addons-for-elementor'),
					"vertical" => esc_html__("Vertical", 'essential-classy-addons-for-elementor'),
				],
				'condition' => [
					'style' => 'style-8',
				],
			]
		);
		$this->add_control(
			'relayoutissue',
			[
				'label' => esc_html__( 'Relayout Issue', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Try', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Try', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',				
				'selectors' => [
					'.elementor-editor-active {{WRAPPER}} .eca-post-listing-inner' => 'height: 100% !important;',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'query_section',
			[
				'label' => esc_html__( 'Query Control', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'selectTaxonomy',
			[
				'label' => esc_html__( 'Taxonomy', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'category',
				'options' => \EcafeHelper::getTaxonomiesList(),
			]
		);
		$this->add_control(
			'postCategory',
			[
				'label' => esc_html__( 'Categories', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => \EcafeHelper::getTermsList(),
				'default' => [],
				'label_block' => true,
				'condition' => [
					'selectPostType' => 'post',
				],
			]
		);
		$this->add_control(
			'postTags',
			[
				'label' => esc_html__( 'Post Tags', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => \EcafeHelper::getTermsList('post_tag','term_id'),
				'default' => [],
				'label_block' => true,
				'condition' => [
					'selectPostType' => 'post',
				],
			]
		);
		$this->add_control(
			'taxonomyInclude',
			[
				'label'       => esc_html__( 'Taxonomies Terms IDs', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,				
				'label_block' => true,
				'placeholder'     => esc_html__('Taxonomies like : 11,22','essential-classy-addons-for-elementor'),
				'condition' => [
					'selectPostType!' => ['post'],
					'selectTaxonomy!' => '',
				],
			]
		);
		// $this->add_control(
			// 'postAuthors',
			// [
				// 'label' => esc_html__( 'Author', 'essential-classy-addons-for-elementor' ),
				// 'type' => Controls_Manager::SELECT2,
				// 'multiple' => true,
				// 'options' => \EcafeHelper::getAuthorsList(),
				// 'default' => [],
				// 'label_block' => true,
			// ]
		// );
		$this->add_control(
			'postsInclude',
			[
				'label'       => esc_html__( 'Include Post(s)', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder'     => esc_html__('Include like : 11,22','essential-classy-addons-for-elementor'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'postsExclude',
			[
				'label'       => esc_html__( 'Exclude Post(s)', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder'     => esc_html__('Exclude like : 11,22','essential-classy-addons-for-elementor'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'numberOfPosts',
			[
				'label' => esc_html__( 'Maximum Posts Display', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'min' => -1,
				'max' => 1000,
				'step' => 1,
				'default' => 6,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'postsOffset',
			[
				'label' => esc_html__( 'Offset Posts', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 50,
				'step' => 1,
				'default' => '',
				'description' => esc_html__('Starting posts hide from the list.','essential-classy-addons-for-elementor'),				
			]
		);
		$this->add_control(
			'postsOrderBy',
			[
				'label' => esc_html__( 'Order By', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => \EcafeHelper::getOrderByArray(),
			]
		);
		$this->add_control(
			'postsOrder',
			[
				'label' => esc_html__( 'Order', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => \EcafeHelper::getOrderArray(),
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'columnsSection',
			[
				'label' => esc_html__( 'Columns', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
				'condition' => [
					'style!' => 'style-3',
				],
			]
		);
		$this->add_responsive_control(
			'selectColumns',
			[
				'label' => esc_html__( 'Columns', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => '33.3333',
				'options' => \EcafeHelper::getResponsiveColumn(),
				'render_type' => 'ui',
				'selectors' => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap .ec-grid-wrap' => 'width: {{selectColumns}}%;',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'extraOptionsSection',
			[
				'label' => esc_html__( 'Layout Options', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'showImage',
			[
				'label' => esc_html__( 'Show Image', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),
				'default' => 'yes',
			]
		);
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'imageSize',
				'default' => 'full',
				'separator' => 'none',
				'exclude' => [ 'custom' ],
				'condition'   => [
					'showImage' => 'yes',
				],
			]
		);
		$this->add_control(
			'showTitle',
			[
				'label' => esc_html__( 'Show Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),
				'default' => 'yes',
				'separator' => 'before',
			]
		);
		$this->add_control(
            'titleTag',
            [
                'label' => __('Title Tag', 'essential-classy-addons-for-elementor'),
                'type' => Controls_Manager::SELECT,
                'default' => 'h2',
                'options' => \EcafeHelper::getHtmlTag(),
				'condition'   => [
					'showTitle' => 'yes',
				],
            ]
        );
		 $this->add_control(
			'titleLength',
			[
				'label' => __('Title Length', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'condition' => [
					'showTitle' => 'yes',
				],
			]
		);
		$this->add_control(
			'showExcerpt',
			[
				'label' => esc_html__( 'Show Excerpt/Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),
				'default' => 'yes',
				'separator' => 'before',
				'condition' => [
					'style!' => ['style-3','style-4'],
				],
			]
		);		
		$this->add_control(
			'postExcerptLength',
			[
				'label' => esc_html__( 'Excerpt/Content Length', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'step' => 2,
				'default' => 30,
				'condition'   => [
					'style!' => ['style-3','style-4'],
					'showExcerpt' => 'yes',
				],
			]
		);		
		$this->add_control(
			'showPostMeta',
			[
				'label' => __('Show Post Meta', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'essential-classy-addons-for-elementor'),
				'label_off' => __('Hide', 'essential-classy-addons-for-elementor'),
				'default' => 'yes',
				'separator' => 'before',
				'condition' => [
					'style!' => ['style-3','style-8'],
				],
			]
		);
		$this->add_control(
			'postMetaStyle',
			[
				'label' => esc_html__( 'Meta Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style-1',
				'options' => \EcafeHelper::getStyleLoop( 1 ),
				'condition' => [
					'style!' => ['style-3','style-8'],
					'showPostMeta' => 'yes',
				],
			]
		);
		$this->add_control(
			'postUserMeta',
			[
				'label' => __('Show User Meta', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'essential-classy-addons-for-elementor'),
				'label_off' => __('Hide', 'essential-classy-addons-for-elementor'),
				'default' => 'yes',
				'condition' => [
					'style!' => ['style-3','style-4','style-8'],
					'showPostMeta' => 'yes',
				],
			]
		);
		$this->add_control(
			'prefixTextPostUserMeta',
			[
				'label' => esc_html__('Prefix Text User', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'label_block' => false,
				'default' => esc_html__('By', 'essential-classy-addons-for-elementor'),
				'condition' => [
					'style!' => ['style-3','style-4','style-8'],
					'showPostMeta' => 'yes',
					'postUserMeta' => 'yes',
				],
			]
		);
		$this->add_control(
			'postDateMeta',
			[
				'label' => __('Show Date Meta', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'essential-classy-addons-for-elementor'),
				'label_off' => __('Hide', 'essential-classy-addons-for-elementor'),
				'default' => 'yes',
				'condition' => [
					'style!' => ['style-3','style-4','style-8'],
					'showPostMeta' => 'yes',
				],
			]
		);
		$this->add_control(
			'readMoreButton',
			[
				'label' => __('Show Read More Button', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'essential-classy-addons-for-elementor'),
				'label_off' => __('Hide', 'essential-classy-addons-for-elementor'),
				'default' => 'yes',
				'separator' => 'before',
				'condition' => [
					'style!' => ['style-3','style-4','style-6','style-8'],
					'selectPostType!' => 'product',
				],
			]
		);
		$this->add_control(
			'readButtonText',
			[
				'label' => __('Button Text', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default' => __('Read More', 'essential-classy-addons-for-elementor'),
				'condition' => [
					'style!' => ['style-3','style-4','style-6','style-8'],
					'readMoreButton' => 'yes',
					'selectPostType!' => 'product',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'AdvOptionsSection',
			[
				'label' => esc_html__( 'Advanced Options', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,				
			]
		);
		$this->add_control(
			'filterPost',
			[
				'label' => esc_html__( 'Filter', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),
				'default' => 'no',
				'separator' => 'before',				
			]
		);		
		$this->add_control(
			'filterAllShow',
			[
				'label' => esc_html__( 'Show All Filter', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'SHOW', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'HIDE', 'essential-classy-addons-for-elementor' ),
				'default' => 'yes',
				'condition' => [
					'filterPost'    => 'yes',
				],
			]
		);
		$this->add_control(
			'allFilterText',
			[
				'label' => esc_html__( 'All Filter Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'All', 'essential-classy-addons-for-elementor' ),
				'condition'   => [
					'filterAllShow'    => 'yes',
					'filterPost'    => 'yes',
				],
			]
		);
		$this->add_control(
			'filterStyle',
			[
				'label' => esc_html__( 'Filter Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style-1',
				'options' => \EcafeHelper::getStyleLoop( 1 ),
				'condition'   => [
					'filterPost'    => 'yes',
				],
			]
		);
		$this->add_control(
			'filterAlign',
			[
				'label' => esc_html__( 'Filter Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'left',
				'toggle' => true,
				'label_block' => false,
				'selectors' => [
                    '{{WRAPPER}} .terms-filters-wrap' => 'text-align:{{VALUE}};',
                ],
				'condition'   => [
					'filterPost'    => 'yes',
				],
			]
		);		
		$this->add_control(
			'postLoadingOpt',
			[
				'label' => esc_html__( 'Loading Options', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => \EcafeHelper::getLoadingOptions(),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'paginateNext',
			[
				'label' => esc_html__( 'Next Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Next', 'essential-classy-addons-for-elementor' ),
				'condition'   => [
					'postLoadingOpt'    => 'pagination',
				],
			]
		);
		$this->add_control(
			'paginatePrev',
			[
				'label' => esc_html__( 'Prev Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Prev', 'essential-classy-addons-for-elementor' ),
				'condition'   => [
					'postLoadingOpt'    => 'pagination',
				],
			]
		);
		$this->add_control(
			'paginateAlign',
			[
				'label' => esc_html__( 'Paginate Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'flex-start',
				'toggle' => true,
				'label_block' => false,
				'selectors' => [
                    '{{WRAPPER}} .eca-paginate' => 'justify-content:{{VALUE}};',
                ],
				'condition'   => [
					'postLoadingOpt'    => 'pagination',
				],
			]
		);
		
		$this->add_control(
			'loadMoreBtnText',
			[
				'label' => esc_html__( 'Button Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Load More', 'essential-classy-addons-for-elementor' ),
				'condition'   => [
					'postLoadingOpt'    => 'load_more',
				],
			]
		);
		$this->add_control(
			'loadingMoreText',
			[
				'label' => esc_html__( 'Loading Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Loading...', 'essential-classy-addons-for-elementor' ),
				'condition'   => [
					'postLoadingOpt'    => ['load_more','lazy_load']
				],
			]
		);
		$this->add_control(
			'loadedPostsText',
			[
				'label' => esc_html__( 'After All Posts Loaded Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'All done!', 'essential-classy-addons-for-elementor' ),
				'condition'   => [
					'postLoadingOpt'    => ['load_more','lazy_load']
				],
			]
		);
		$this->add_control(
			'loadMorePost',
			[
				'label' => esc_html__( 'More posts on click/scroll', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 40,
				'step' => 1,
				'default' => 3,
				'condition'   => [					
					'postLoadingOpt'    => ['load_more','lazy_load']
				],
			]
		);
		$this->end_controls_section();
		
		/*title start*/
		$this->start_controls_section(
            'titleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'titlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'titleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'titleTypo',
				'selector' => '{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title',
			]
		);
		$this->start_controls_tabs( 'tabstitleStyle' );
		$this->start_controls_tab(
			'tabtitleNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title',
			]
		);
		$this->add_responsive_control(
			'titleBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowN',
				'selector' => '{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabtitleHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-title a,{{WRAPPER}} .ec-grid-wrap:hover .post-title *,{{WRAPPER}}  .grid-style-3:hover .post-title,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover .post-title a,{{WRAPPER}} .ec-grid-wrap:hover .post-title *,{{WRAPPER}}  .grid-style-3:hover .post-title,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-title a,{{WRAPPER}} .ec-grid-wrap:hover .post-title *,{{WRAPPER}}  .grid-style-3:hover .post-title,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-title',
			]
		);
		$this->add_responsive_control(
			'titleBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-title a,{{WRAPPER}} .ec-grid-wrap:hover .post-title *,{{WRAPPER}}  .grid-style-3:hover .post-title,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-title a,{{WRAPPER}} .ec-grid-wrap:hover .post-title *,{{WRAPPER}}  .grid-style-3:hover .post-title,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-title a,{{WRAPPER}} .ec-grid-wrap:hover .post-title *,{{WRAPPER}}  .grid-style-3:hover .post-title,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-title',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'titleTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'titleTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-title a,{{WRAPPER}} .listing-style-3 .post-title,{{WRAPPER}} .listing-style-8 .post-title' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*title end*/
		
		/*separator style*/
		$this->start_controls_section(
            'sepratorStyling',
            [
                'label' => esc_html__('Seprator', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style' => ['style-4','style-5'],					
				],
            ]
        );
		$this->add_control(
			'SepratorColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .listing-style-4 .post-title:after' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .listing-style-5 .top-sep-border' => 'border-top: .1rem solid {{VALUE}};',
				],				
			]
		);
		$this->end_controls_section();
		/*separator style*/
		
		/*Excerpt start*/
		$this->start_controls_section(
            'excerptStyling',
            [
                'label' => esc_html__('Excerpt/Content', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style!' => ['style-3','style-4'],					
				],
            ]
        );
		$this->add_responsive_control(
			'excerptPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .entry-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'excerptMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .entry-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'excerptTypo',
				'selector' => '{{WRAPPER}} .entry-content,{{WRAPPER}} .entry-content p',
			]
		);
		$this->start_controls_tabs( 'tabsexcerptStyle' );
		$this->start_controls_tab(
			'tabexcerptNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'excerptColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .entry-content,{{WRAPPER}} .entry-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'excerptBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .entry-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'excerptBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .entry-content',
			]
		);
		$this->add_responsive_control(
			'excerptBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .entry-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'excerptShadowN',
				'selector' => '{{WRAPPER}} .entry-content',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'excerptTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .entry-content,{{WRAPPER}} .entry-content p',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabexcerptHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'excerptColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .entry-content,{{WRAPPER}} .ec-grid-wrap:hover .entry-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'excerptBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover .entry-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'excerptBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .entry-content',
			]
		);
		$this->add_responsive_control(
			'excerptBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover .entry-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'excerptShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .entry-content',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'excerptTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .entry-content',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'excerptTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .entry-content,{{WRAPPER}} .entry-content p' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'excerptTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .entry-content,{{WRAPPER}} .entry-content p' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],
			]
		);
		$this->end_controls_section();
		/*Excerpt end*/
		
		/*Date start*/
		$this->start_controls_section(
            'dateStyling',
            [
                'label' => esc_html__('Date Meta', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style!' => ['style-3','style-4','style-8'],					
				],
            ]
        );
		$this->add_responsive_control(
			'datePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'dateMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'dateTypo',
				'selector' => '{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a',
			]
		);
		$this->start_controls_tabs( 'tabsdateStyle' );
		$this->start_controls_tab(
			'tabdateNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'dateColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'dateBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dateBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a',
			]
		);
		$this->add_responsive_control(
			'dateBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'dateShadowN',
				'selector' => '{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'dateTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabdateHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'dateColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .meta-date a,{{WRAPPER}} .ec-grid-wrap:hover .meta-date-6 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'dateBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover .meta-date a,{{WRAPPER}} .ec-grid-wrap:hover .meta-date-6 a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dateBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .meta-date a,{{WRAPPER}} .ec-grid-wrap:hover .meta-date-6 a',
			]
		);
		$this->add_responsive_control(
			'dateBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover .meta-date a,{{WRAPPER}} .ec-grid-wrap:hover .meta-date-6 a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'dateShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .meta-date a,{{WRAPPER}} .ec-grid-wrap:hover .meta-date-6 a',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'dateTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .meta-date a,{{WRAPPER}} .ec-grid-wrap:hover .meta-date-6 a',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'dateTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'dateTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .meta-date a,{{WRAPPER}} .meta-date-6 a' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*Date end*/
		
		/*User start*/
		$this->start_controls_section(
            'userStyling',
            [
                'label' => esc_html__('User Meta', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style!' => ['style-3','style-4','style-8'],					
				],
            ]
        );
		$this->add_responsive_control(
			'userPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .post-author' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'userMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .post-author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'userTypo',
				'selector' => '{{WRAPPER}} .post-author,{{WRAPPER}} .post-author a',
			]
		);
		$this->start_controls_tabs( 'tabsuserStyle' );
		$this->start_controls_tab(
			'tabuserNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'userColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .post-author,{{WRAPPER}} .post-author a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'userBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .post-author',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'userBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .post-author',
			]
		);
		$this->add_responsive_control(
			'userBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .post-author' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'userShadowN',
				'selector' => '{{WRAPPER}} .post-author',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'userTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .post-author',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabuserHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'userColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-author,,{{WRAPPER}} .ec-grid-wrap:hover .post-author a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'userBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover .post-author',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'userBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-author',
			]
		);
		$this->add_responsive_control(
			'userBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-author' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'userShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-author',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'userTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-author',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'userTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-author' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'userTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-author' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'metaPrefixHeading',
			[
				'label' => esc_html__( 'Prefix', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'metaPrefixTypo',
				'selector' => '{{WRAPPER}} .ec-grid-wrap .post-author .post-author-by',
			]
		);
		$this->add_control(
			'metaPrefixColorN',
			[
				'label' => esc_html__( 'Normal Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap .post-author .post-author-by' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'metaPrefixColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-author .post-author-by' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*User end*/
		
		/*Image start*/
		$this->start_controls_section(
            'imageStyling',
            [
                'label' => esc_html__('Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'imagePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'imageMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'imageWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 700,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'imageHeight',		
  			[		
  				'label' => esc_html__( 'Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 700,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsimageStyle' );
		$this->start_controls_tab(
			'tabimageNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'imageBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'imageBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img',
			]
		);
		$this->add_responsive_control(
			'imageBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'imageShadowN',
				'selector' => '{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabimageHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'imageBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover .post-content-image img,{{WRAPPER}} .grid-style-3:hover .post-content-image img,{{WRAPPER}} .ec-grid-wrap:hover .post-flip-front-content img',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'imageBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-content-image img,{{WRAPPER}} .grid-style-3:hover .post-content-image img,{{WRAPPER}} .ec-grid-wrap:hover .post-flip-front-content img',
			]
		);
		$this->add_responsive_control(
			'imageBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-content-image img,{{WRAPPER}} .grid-style-3:hover .post-content-image img,{{WRAPPER}} .ec-grid-wrap:hover .post-flip-front-content img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'imageShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .post-content-image img,{{WRAPPER}} .grid-style-3:hover .post-content-image img,{{WRAPPER}} .ec-grid-wrap:hover .post-flip-front-content img',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'imageTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'imageTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-content-image img,{{WRAPPER}} .post-flip-front-content img' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*Image end*/
		
		/*Button start*/
		$this->start_controls_section(
            'buttonStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style' => ['style-1','style-2','style-5','style-7'],					
				],
            ]
        );
		$this->add_responsive_control(
			'buttonPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-post-read-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'buttonMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-post-read-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'buttonTypo',
				'selector' => '{{WRAPPER}} .eca-post-read-more',
			]
		);
		$this->start_controls_tabs( 'tabsbuttonStyle' );
		$this->start_controls_tab(
			'tabbuttonNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-post-read-more' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-post-read-more',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-post-read-more',
			]
		);
		$this->add_responsive_control(
			'buttonBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-post-read-more' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowN',
				'selector' => '{{WRAPPER}} .eca-post-read-more',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'buttonTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-post-read-more',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabbuttonHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .eca-post-read-more' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover .eca-post-read-more',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .eca-post-read-more',
			]
		);
		$this->add_responsive_control(
			'buttonBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover .eca-post-read-more' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .eca-post-read-more',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'buttonTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover .eca-post-read-more',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'buttonTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-post-read-more' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'buttonTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-post-read-more' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*Button end*/
		
		/*Loadmore start*/
		$this->start_controls_section(
            'loadMoreStyling',
            [
                'label' => esc_html__('Load More', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'postLoadingOpt'    => 'load_more',
				],
            ]
        );
		$this->add_responsive_control(
			'loadMorePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'loadMoreMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'loadMoreTypo',
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more,{{WRAPPER}} .eca-all-posts-loaded',
			]
		);
		$this->start_controls_tabs( 'tabsloadMoreStyle' );
		$this->start_controls_tab(
			'tabloadMoreNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'loadMoreColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more,{{WRAPPER}} .eca-all-posts-loaded' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'loadMoreBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'loadMoreBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more',
			]
		);
		$this->add_responsive_control(
			'loadMoreBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'loadMoreShadowN',
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'loadMoreTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more,{{WRAPPER}} .eca-all-posts-loaded',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabloadMoreHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'loadMoreColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more:hover,{{WRAPPER}} .eca-posts-load-more a.posts-load-more:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'loadMoreBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more:hover,{{WRAPPER}} .eca-posts-load-more a.posts-load-more:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'loadMoreBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more:hover,{{WRAPPER}} .eca-posts-load-more a.posts-load-more:focus',
			]
		);
		$this->add_responsive_control(
			'loadMoreBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more:hover,{{WRAPPER}} .eca-posts-load-more a.posts-load-more:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'loadMoreShadowH',
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more:hover,{{WRAPPER}} .eca-posts-load-more a.posts-load-more:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'loadMoreTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-posts-load-more a.posts-load-more:hover,{{WRAPPER}} .eca-posts-load-more a.posts-load-more:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'loadMoreTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'loadMoreTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-posts-load-more a.posts-load-more' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*Loadmore end*/
		
		/*Lazyload start*/
		$this->start_controls_section(
            'lazyLoadStyling',
            [
                'label' => esc_html__('Lazy Load', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'postLoadingOpt'    => 'lazy_load',
				],
            ]
        );
		$this->add_responsive_control(
  			'lazyLoadIconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .posts-lazy-load::after' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}}',
				],		
  			]		
  		);
		$this->add_control(
			'lazyLoadIconColor',
			[
				'label' => esc_html__( 'Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
			]
		);
		$this->add_responsive_control(
  			'lazyLoadIconBorderSize',		
  			[		
  				'label' => esc_html__( 'Icon Border Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 10,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .posts-lazy-load::after' => 'border: {{SIZE}}{{UNIT}} solid transparent;border-left: {{SIZE}}{{UNIT}} solid {{lazyLoadIconColor.VALUE}};border-right: {{SIZE}}{{UNIT}} solid {{lazyLoadIconColor.VALUE}};',
				],		
  			]		
  		);
		$this->add_control(
			'lazyLoadTextHeading',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_control(
			'lazyLoadTextColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .posts-lazy-load .lazy-text,{{WRAPPER}} .eca-all-posts-loaded' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*Lazyload end*/
		
		/*Category start*/
		$this->start_controls_section(
            'categoryStyling',
            [
                'label' => esc_html__('Category', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style' => ['style-2','style-4'],					
				],
            ]
        );
		$this->add_responsive_control(
			'categoryPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}}  .post-category-list a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'categoryMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}}  .post-category-list a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'categoryTypo',
				'selector' => '{{WRAPPER}}  .post-category-list a',
			]
		);
		$this->start_controls_tabs( 'tabscategoryStyle' );
		$this->start_controls_tab(
			'tabcategoryNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'categoryColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .post-category-list a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'categoryBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}}  .post-category-list a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'categoryBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}}  .post-category-list a',
			]
		);
		$this->add_responsive_control(
			'categoryBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}}  .post-category-list a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'categoryShadowN',
				'selector' => '{{WRAPPER}}  .post-category-list a',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'categoryTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}}  .post-category-list a',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcategoryHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'categoryColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover  .post-category-list a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'categoryBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-grid-wrap:hover  .post-category-list a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'categoryBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover  .post-category-list a',
			]
		);
		$this->add_responsive_control(
			'categoryBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-grid-wrap:hover  .post-category-list a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'categoryShadowH',
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover  .post-category-list a',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'categoryTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-grid-wrap:hover  .post-category-list a',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'categoryTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}}  .post-category-list a' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'categoryTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}}  .post-category-list a' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*Category end*/
		
		/*Arrow start*/
		$this->start_controls_section(
            'arrowStyling',
            [
                'label' => esc_html__('Arrow', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'style' => ['style-5','style-6'],					
				],
            ]
        );
		$this->add_control(
			'arrowColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .post-list-content.post-trans:before' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'arrowColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-grid-wrap:hover .post-list-content.post-trans:before' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'arrowTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-list-content.post-trans:before' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'arrowTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .post-list-content.post-trans:before' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		/*Arrow end*/		
		
		/*filter start*/
		$this->start_controls_section(
            'filterStyling',
            [
                'label' => esc_html__('Filter', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'filterPost'    => 'yes',
				],			
            ]
        );
		$this->add_responsive_control(
			'filterPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'filterMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'filterTypo',
				'selector' => '{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li span',				
			]
		);
		$this->add_control(
			'filterColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li span' => 'color:{{VALUE}};',
				],
			]
		);
		$this->add_control(
			'filterCountColor',
			[
				'label' => esc_html__( 'Count Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li span.term_count' => 'color:{{VALUE}};',
				],
			]
		);
		$this->add_control(
			'filterColorActive',
			[
				'label' => esc_html__( 'Active Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li .active span' => 'color:{{VALUE}};',
				],
			]
		);
		$this->add_control(
			'filterCountColorActive',
			[
				'label' => esc_html__( 'Active Count Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .terms-filters-wrap ul.terms-filters-lists li .active span.term_count' => 'color:{{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*filter end*/
		
		/*Paginate style start*/
		$this->start_controls_section(
            'paginationStyling',
            [
                'label' => esc_html__('Pagination', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'   => [
					'postLoadingOpt'    => 'pagination',
				],				
            ]
        );
		$this->add_responsive_control(
			'paginationPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],			
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'paginationMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],			
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'paginationTypography',
				'selector' => '{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span',
			]
		);
		$this->add_control(
			'paginationGeneralHeading',
			[
				'label' => esc_html__( 'General', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->start_controls_tabs( 'tabsPgStyle' );
		$this->start_controls_tab(
			'pgNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pNColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pNBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pNBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span',
			]
		);
		$this->add_responsive_control(
			'pNBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'pNTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'placeholder' => esc_html__( 'all 0.3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span' => 'transition: {{VALUE}};'
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'pNTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'placeholder' => esc_html__( 'rotate(25deg) scale(1.2)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a,{{WRAPPER}} .eca-paginate span' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'pGHover',
			[
				'label' => esc_html__( 'Active/Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pgHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a:hover,{{WRAPPER}} .eca-paginate span:hover,{{WRAPPER}} .eca-paginate .current' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pgHBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .eca-paginate a:hover,{{WRAPPER}} .eca-paginate span:hover,{{WRAPPER}} .eca-paginate .current',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pgHBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-paginate a:hover,{{WRAPPER}} .eca-paginate span:hover,{{WRAPPER}} .eca-paginate .current',
			]
		);
		$this->add_responsive_control(
			'pgHBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-paginate a:hover,{{WRAPPER}} .eca-paginate span:hover,{{WRAPPER}} .eca-paginate .current' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'paginationNextHeading',
			[
				'label' => esc_html__( 'Next', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->start_controls_tabs( 'tabsPnStyle' );
		$this->start_controls_tab(
			'pnNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pnNColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.next' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pnNBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .eca-paginate a.next',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pnNBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-paginate a.next',
			]
		);
		$this->add_responsive_control(
			'pnNBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-paginate a.next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'pnNTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'placeholder' => esc_html__( 'all 0.3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.next' => 'transition: {{VALUE}};'
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'pnNTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'placeholder' => esc_html__( 'rotate(25deg) scale(1.2)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.next' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'pNHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pnHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.next:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pnHBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .eca-paginate a.next:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pnHBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-paginate a.next:hover',
			]
		);
		$this->add_responsive_control(
			'pnHBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-paginate a.next:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'paginationPrevHeading',
			[
				'label' => esc_html__( 'Previous', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->start_controls_tabs( 'tabsPPStyle' );
		$this->start_controls_tab(
			'ppNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ppNColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.prev' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'ppNBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .eca-paginate a.prev',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'ppNBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-paginate a.prev',
			]
		);
		$this->add_responsive_control(
			'ppNBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-paginate a.prev' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'ppNTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'placeholder' => esc_html__( 'all 0.3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.prev' => 'transition: {{VALUE}};'
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'ppNTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,				
				'placeholder' => esc_html__( 'rotate(25deg) scale(1.2)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.prev' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'ppHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ppHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-paginate a.prev:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'ppHBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .eca-paginate a.prev:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'ppHBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-paginate a.prev:hover',
			]
		);
		$this->add_responsive_control(
			'ppHBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-paginate a.prev:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*Paginate end*/
		
		/*Box start*/
		$this->start_controls_section(
            'boxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'boxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'boxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsboxStyle' );
		$this->start_controls_tab(
			'tabboxNormal',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front',
			]
		);
		$this->add_responsive_control(
			'boxBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowN',
				'selector' => '{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabboxHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap:hover article,{{WRAPPER}} .listing-style-3 .grid-style-3:hover .post-list-content,{{WRAPPER}}  .listing-style-6 .ec-grid-wrap:hover .post-list-content,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-flip-back',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap:hover article,{{WRAPPER}} .listing-style-3 .grid-style-3:hover .post-list-content,{{WRAPPER}}  .listing-style-6 .ec-grid-wrap:hover .post-list-content,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-flip-back',
			]
		);
		$this->add_responsive_control(
			'boxBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap:hover article,{{WRAPPER}} .listing-style-3 .grid-style-3:hover .post-list-content,{{WRAPPER}}  .listing-style-6 .ec-grid-wrap:hover .post-list-content,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-flip-back' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowH',
				'selector' => '{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap:hover article,{{WRAPPER}} .listing-style-3 .grid-style-3:hover .post-list-content,{{WRAPPER}}  .listing-style-6 .ec-grid-wrap:hover .post-list-content,{{WRAPPER}} .listing-style-8 .ec-grid-wrap:hover .post-flip-back',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'boxTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'boxTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'boxOverflow',
			[
				'label'     => esc_html__( 'Overflow', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Hidden', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Visible', 'essential-classy-addons-for-elementor' ),
				'default' => 'no',
				'selectors' => [
					'{{WRAPPER}} .eca-post-grid-listing-wrap:not(.listing-style-6):not(.listing-style-8) .ec-grid-wrap article,{{WRAPPER}} .listing-style-3 .post-list-content,{{WRAPPER}} .listing-style-6 .post-list-content,{{WRAPPER}} .listing-style-8 .post-flip-front' => 'overflow:hidden;',
				],
			]
		);
		$this->end_controls_section();
		/*Box end*/
	}
	
	 protected function render() {
        $settings = $this->get_settings_for_display();
		$uid = uniqid('post');
		$query_args = $this->post_query_args();
		
		$query = new \WP_Query( $query_args );
		
		$data_attr = [];
		$data_attr['id'] = $uid;		
		$data_attr['selectPostType'] = $settings['selectPostType'];
		$data_attr['style'] = $settings['style'];
		$data_attr['postLayout'] = ($settings['postLayout']=='grid') ? 'fitRows' : 'masonry';
		$data_attr['selectTaxonomy'] = $settings['selectTaxonomy'];
		$data_attr['postCategory'] = $settings['postCategory'];
		$data_attr['postTags'] = $settings['postTags'];
		$data_attr['taxonomyInclude'] = $settings['taxonomyInclude'];
		// $data_attr['postAuthors'] = $settings['postAuthors'];
		$data_attr['postsInclude'] = $settings['postsInclude'];
		$data_attr['postsExclude'] = $settings['postsExclude'];
		$data_attr['numberOfPosts'] = $settings['numberOfPosts'];
		$data_attr['postsOffset'] = $settings['postsOffset'];
		$data_attr['postsOrderBy'] = $settings['postsOrderBy'];
		$data_attr['postsOrder'] = $settings['postsOrder'];
		
		$data_attr['showImage'] = $settings['showImage'];
		$data_attr['imageSize'] = $settings['imageSize_size'];
		
		$data_attr['showTitle'] = $settings['showTitle'];
		$data_attr['titleTag'] = $settings['titleTag'];
		$data_attr['titleLength'] = $settings['titleLength'];
		$data_attr['showExcerpt'] = $settings['showExcerpt'];
		$data_attr['postExcerptLength'] = $settings['postExcerptLength'];
		$data_attr['showPostMeta'] = $settings['showPostMeta'];
		$data_attr['postMetaStyle'] = $settings['postMetaStyle'];
		$data_attr['postUserMeta'] = $settings['postUserMeta'];
		$data_attr['prefixTextPostUserMeta'] = $settings['prefixTextPostUserMeta'];
		$data_attr['postDateMeta'] = $settings['postDateMeta'];		
		$data_attr['readMoreButton'] = $settings['readMoreButton'];
		$data_attr['readButtonText'] = $settings['readButtonText'];
		$data_attr['filterPost'] = $settings['filterPost'];
		
		
		if( !empty($settings['style']) && $settings['style'] == 'custom-template'){
			$templateid = $settings['grid_post_custom_template'];
			$data_attr['templateid'] = $settings['grid_post_custom_template'];
			
		}
		
		if( $settings['postLoadingOpt'] != 'none'){
			$data_attr['postLoadingOpt'] = $settings['postLoadingOpt'];
			if($settings['postLoadingOpt'] == 'load_more'){
				$data_attr['loadMoreBtnText'] = $settings['loadMoreBtnText'];
				$data_attr['loadingMoreText'] = $settings['loadingMoreText'];
				$data_attr['loadedPostsText'] = $settings['loadedPostsText'];
				$data_attr['loadMorePost'] = $settings['loadMorePost'];
			}
			if($settings['postLoadingOpt'] == 'lazy_load'){
				$data_attr['loadingMoreText'] = $settings['loadingMoreText'];
				$data_attr['loadedPostsText'] = $settings['loadedPostsText'];
				$data_attr['loadMorePost'] = $settings['loadMorePost'];
			}
		}
		
		if($query->found_posts !=''){
			$totalPosts=$query->found_posts;
			$postsOffset = ($settings['postsOffset']!='') ? $settings['postsOffset'] : 0;
			$numberOfPosts = ($settings['numberOfPosts']!='') ? $settings['numberOfPosts'] : 0;
			$offset_posts=intval($numberOfPosts + $postsOffset);
			$totalPosts= intval($totalPosts - $offset_posts);				
			if($totalPosts!=0 && $settings['loadMorePost']!=0){
				$loadPage= ceil((int)$totalPosts/(int)$settings['loadMorePost']);
			}else{
				$loadPage=1;
			}
			$loadPage=$loadPage+1;
			$data_attr['totalPage'] = $loadPage;
		}else{
			$loadPage=1;
			$data_attr['totalPage'] = $loadPage;
		}
		
		$data_attr = json_encode($data_attr);
		
		$wrapClass = 'eca-isotope';
		$wrapClass .= ' eca-isotope-'.$settings['postLayout'];
		$wrapClass .= ' listing-'.$settings['style'];
		$wrapClass .= ' '.$uid;
		$wrapClass .= ($settings['filterPost']=='yes') ? ' eca-filter-post-category' : '';

		$output = '<div class="eca-post-grid-listing-wrap '.esc_attr( $wrapClass ).'" data-settings=\'' . $data_attr . '\'>';
			
			if($settings['filterPost']=='yes'){
				$output .= $this->filter_category();
			}
			
			$output .= '<div class="eca-post-listing-inner eca-row">';
				$output .= $this->getLoopItem( $query );
			$output .= '</div>';
			
			
			if( $settings['postLoadingOpt']=='pagination' ){
				$output .= \EcafeHelper::post_pagination($query->max_num_pages, 2, $settings['paginateNext'], $settings['paginatePrev']);
			}else if( $settings['postLoadingOpt']=='load_more' ){
				if(!empty($totalPosts) && $totalPosts>0){
					$output .= '<div class="eca-posts-load-more">';
						$output .= '<a class="posts-load-more" data-settings=\'' . $data_attr . '\' data-page="1">'.esc_html( $settings['loadMoreBtnText'] ).'</a>';
					$output .= '</div>';
				}
			}else if( $settings['postLoadingOpt']=='lazy_load' ){
				if(!empty($totalPosts) && $totalPosts>0){
					$output .= '<div class="eca-posts-lazy-load">';
						$output .= '<a class="posts-lazy-load" data-settings=\'' . $data_attr . '\' data-page="1"><span class="lazy-text">Lazy Load</span></a>';
					$output .= '</div>';
				}
			}
			
		$output .= '</div>';
		
		echo wp_kses_normalize_entities($output);
	}
	
	public function post_query_args(){
		$settings = $this->get_settings_for_display();
		$query_args = \EcafeHelper::getQueryArgs( $settings );
		$offset = $settings['postsOffset'];
		$offset = ! empty( $offset ) ? absint( $offset ) : 0;
		
		global $paged;
		if ( get_query_var('paged') ) {
			$paged = get_query_var('paged');
		}
		elseif ( get_query_var('page') ) {
			$paged = get_query_var('page');
		}
		else {
			$paged = 1;
		}	
		
		if ($settings['postLoadingOpt']!='pagination') {
			$query_args['offset'] = $offset;
		}else if( $settings['postLoadingOpt']=='pagination' ){
			$query_args['paged'] = $paged;
			$page = max( 1, $paged );
			$offset = ( $page - 1 ) * intval( $settings['numberOfPosts'] ) + $offset;
			$query_args['offset'] = $offset;
		}
		
		return $query_args;
	}
	
	public function filter_category() {
	
		$settings = $this->get_settings_for_display();
		$query_args = $this->post_query_args();
		$filterStyle = $settings['filterStyle'];		
		$query = new \WP_Query( $query_args );
		$postCategory=$settings['postCategory'];
		$postTags=$settings['postTags'];
		$selectTaxonomy=$settings['selectTaxonomy'];
		$taxonomyInclude=$settings['taxonomyInclude'];
		
		$all_filter=( $settings["filterAllShow"]=='yes' ) ? $settings["allFilterText"] : esc_html__('All','essential-classy-addons-for-elementor');
		
		$terms = get_terms( array('taxonomy' => $settings['selectTaxonomy'], 'hide_empty' => true) );
		
		$count=$query->post_count;
		$all_filter_count='<span class="term_count">'.esc_html($count).'</span>';
		
		$filter_loop = array();
		if($query->have_posts()){
			while ( $query->have_posts() ) {
				$query->the_post();
				
				$taxonomy = $settings['selectTaxonomy'];
				$categories = get_the_terms( $query->ID, $taxonomy );							
				
				if($categories){
					foreach( $categories as $category ) {
						if(isset($filter_loop[$category->slug])){
							$filter_loop[$category->slug]= $filter_loop[$category->slug] + 1;
						}else{
							$filter_loop[$category->slug]= 1;
						}
					}
				}
			}
		}
		wp_reset_postdata();
		
		$output_filter = '<div class="terms-filters-wrap filter-'.esc_attr($filterStyle).'">';
			$output_filter .='<ul class="terms-filters-lists">';
				if(!empty($settings['filterAllShow']) && $settings['filterAllShow']=='yes'){
					$output_filter .= '<li><a href="#" class="term-filter-list active all" data-filter="*" >'.$all_filter_count.'<span data-hover="'.esc_attr($all_filter).'">'.esc_html($all_filter).'</span></a></li>';
				}
				
				if ( $terms != null ){
					foreach( $terms as $term ) {						
						if(isset($filter_loop[$term->slug])){
							$count=	$filter_loop[$term->slug];
						}else{
							$count = 0;
						}
						$term_count='<span class="term_count">'.esc_html($count).'</span>';
						
						if($count != 0){
							if(!empty($taxonomyInclude)){	
								$taxonomyInclude = ($settings['taxonomyInclude']) ? explode(',', $settings['taxonomyInclude']) : [];
								if(in_array($term->slug,$taxonomyInclude)){
									$output_filter .= '<li><a href="#ecf'.esc_attr($term->term_id).'" class="term-filter-list" data-filter=".ecf'.esc_attr($term->term_id).'">'.$term_count.'<span data-hover="ecf'.esc_attr($term->term_id).'">'.esc_html($term->name).'</span></a></li>';
									unset($term);
								}
							}else{
								$output_filter .= '<li><a href="#ecf'.esc_attr($term->term_id).'" class="term-filter-list" data-filter=".ecf'.esc_attr($term->term_id).'">'.$term_count.'<span data-hover="ecf'.esc_attr($term->term_id).'">'.esc_html($term->name).'</span></a></li>';
								unset($term);
							}
						}						
					}
				}
			$output_filter .='</ul>';
		$output_filter .= '</div>';
		
		return $output_filter;
	}
	
	public function getLoopItem($query){
		$settings = $this->get_settings_for_display();
		
		$style = $settings['style'];
		$styleFlipType = ($settings['style'] == 'style-8' ) ? $settings['style8FlipType'] : '';
				
		$showTitle = $settings['showTitle'];
		$titleTag = $settings['titleTag'];
		$titleLength = $settings['titleLength'];
		
		$showImage = $settings['showImage'];
		$imageSize = $settings['imageSize_size'];
		
		$showExcerpt = $settings['showExcerpt'];
		$postExcerptLength = $settings['postExcerptLength'];
		
		$showPostMeta = $settings['showPostMeta'];
		$postMetaStyle = $settings['postMetaStyle'];
		$postDateMeta = $settings['postDateMeta'];
		$postUserMeta = $settings['postUserMeta'];
		$prefixTextPostUserMeta = $settings['prefixTextPostUserMeta'];
		
		$readMoreButton = $settings['readMoreButton'];
		$readButtonText = $settings['readButtonText'];
		
		$templateid = $settings['grid_post_custom_template'];
		
		$itemClass = '';
		if($style != 'style-3'){
			$itemClass .= 'ec-grid-wrap ';
		}else if($style == 'style-3'){
			$itemClass .= ' grid-style-3';
		}
		$output = '';
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				
				$filter_post='';
				if($settings['filterPost']=='yes'){				
					$terms = get_the_terms( $query->ID,$settings['selectTaxonomy']);
					
					if ( $terms != null ){
						foreach( $terms as $term ) {
							$filter_post .=' ecf'.esc_attr($term->term_id).' ';							
							unset($term);
						}
					}
				}
				
				$output .= '<div class="'.esc_attr($itemClass).' '.esc_attr($filter_post).'">';
					ob_start();
						include ECAFE_PATH. 'element/post-data/'.$style.'.php';
					$output .= ob_get_contents();
					ob_end_clean();
				$output .= '</div>';
			}
		}else {
			$output .= '<div class="eca-no-posts-found">'.esc_html__('No posts found!','essential-classy-addons-for-elementor').'</div>';
		}
		
		wp_reset_postdata();
		
		return $output;
	}
}