<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Hover_Background extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-hover-background';
	}

    public function get_title() {
        return esc_html__('Hover Background', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-hover-background';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'hover background' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-hover-background' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-hover-background' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Hover Background', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'hbBackgroundImage',
			[
				'label' => esc_html__( 'Background Image', 'essential-classy-addons-for-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'dynamic' => ['active'   => true,],
			]
		);
		$repeater->add_control(
			'hbIconImage',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'icon'  => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
					'image' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$repeater->add_control(
			'hbIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-plus',
					'library' => 'solid',
				],
				'condition' => [
					'hbIconImage' => 'icon',
				],
			]
		);
		$repeater->add_control(
			'hbImage',
			[
				'label' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'hbIconImage' => 'image',
				],
			]
		);
		$repeater->add_control(
			'hbTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title' , 'essential-classy-addons-for-elementor' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'hbTitleLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$repeater->add_control(
			'hbContent',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'show_label' => false,
				'dynamic' => [
					'active'   => true,
				],
			]
		);
		$repeater->add_control(
			'hbButtonText',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Click Here', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),			
			]
		);
		$repeater->add_control(
			'hbButtonLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
			]
		);
		$this->add_control(
			'hbItems',
			[
				'label' => '',
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'hbTitle' => esc_html__( 'Title #1', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus suscipit, velit in venenatis dignissim, risus mi ullamcorper justo, ac porta ante leo tempus enim.', 'essential-classy-addons-for-elementor' ),
					],
					[
						'hbTitle' => esc_html__( 'Title #2', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
					[
						'hbTitle' => esc_html__( 'Title #3', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
				],
				'title_field' => '{{{ hbTitle }}}',
			]
		);
		$this->end_controls_section();
		
		/*content sorting start*/
		$this->start_controls_section(
			'contentSortngSection',
			[
				'label' => esc_html__( 'Content Sortng', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeaterSort = new \Elementor\Repeater();		
		$repeaterSort->add_control(
			'sortingfield',[
				'label' => esc_html__( 'Select','essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'iconImage',
				'options' => [
					'iconImage' => esc_html__( 'Icon/Image','essential-classy-addons-for-elementor' ),	
					'title' => esc_html__( 'Title','essential-classy-addons-for-elementor' ),	
					'content' => esc_html__( 'Content','essential-classy-addons-for-elementor' ),	
					'button' => esc_html__( 'Button','essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
            'hbSort',
            [
				'label' => esc_html__( 'Sortable', 'essential-classy-addons-for-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [
                        'sortingfield' => 'iconImage',
                    ],
                    [
                        'sortingfield' => 'title',
                    ],						
					[
                       'sortingfield' => 'content',
                    ],	
                    [
                        'sortingfield' => 'button',
                    ],
                ],                
				'fields' => $repeaterSort->get_controls(),
                'title_field' => '{{{ sortingfield }}}',
            ]
        ); 
		$this->end_controls_section();
		/*content sorting end*/
		
		/*content animaion start*/
		$this->start_controls_section(
			'contentAnimationSection',
			[
				'label' => esc_html__( 'Content Animation', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbIconAnimation',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'top_to_bottom',
				'options' => [
					'none'  => esc_html__( 'None', 'essential-classy-addons-for-elementor' ),
					'top_to_bottom' => esc_html__( 'Top to Bottom', 'essential-classy-addons-for-elementor' ),
					'bottom_to_top' => esc_html__( 'Bottom to Top', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'hbTitleAnimation',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'none'  => esc_html__( 'None', 'essential-classy-addons-for-elementor' ),
					'top_to_bottom' => esc_html__( 'Top to Bottom', 'essential-classy-addons-for-elementor' ),
					'bottom_to_top' => esc_html__( 'Bottom to Top', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'hbContentAnimation',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'none'  => esc_html__( 'None', 'essential-classy-addons-for-elementor' ),
					'top_to_bottom' => esc_html__( 'Top to Bottom', 'essential-classy-addons-for-elementor' ),
					'bottom_to_top' => esc_html__( 'Bottom to Top', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'hbButtonAnimation',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'none'  => esc_html__( 'None', 'essential-classy-addons-for-elementor' ),
					'top_to_bottom' => esc_html__( 'Top to Bottom', 'essential-classy-addons-for-elementor' ),
					'bottom_to_top' => esc_html__( 'Bottom to Top', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->end_controls_section();
		/*content animaion end*/
		
		/*content visibility start*/
		$this->start_controls_section(
			'contentVisibilitySection',
			[
				'label' => esc_html__( 'Content Visibility', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->start_controls_tabs( 'tabConVis' );
		$this->start_controls_tab(
			'tabConVisN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ConVisIconImage',
			[
				'label' => __('Icon/Image', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 0,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ConVisTitle',
			[
				'label' => __('Title', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 1,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-title' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ConVisContent',
			[
				'label' => __('Content', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 0,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-content' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ConVisButton',
			[
				'label' => __('Button', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 0,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-button-wrapper' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabConVisH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ConVisIconImageH',
			[
				'label' => __('Icon/Image', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 1,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper:hover .eca-hb-icon-image' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ConVisTitleH',
			[
				'label' => __('Title', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 1,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper:hover .eca-hb-title' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ConVisContentH',
			[
				'label' => __('Content', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 1,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper:hover .eca-hb-content' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ConVisButtonH',
			[
				'label' => __('Button', 'essential-classy-addons-for-elementor'),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1,
				'step' => 0.1,
				'default' => 1,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper:hover .eca-hb-button-wrapper' => 'opacity:{{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'ContentTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'all .3s linear',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper i,
					{{WRAPPER}} .eca-hover-background-wrapper svg,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-icon-image,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title' => 'transition:{{VALUE}};'
				],	
			]
		);
		
		$this->start_controls_tabs( 'tabTransform' );
		$this->start_controls_tab(
			'tabTransformsN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ContentTransformttb',
			[
				'label' => esc_html__( 'Transform css Top to Bottom', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'translateY(-35px)',
				'placeholder' => esc_html__( 'translateY(-35px)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-icon-image.top_to_bottom,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-title.top_to_bottom,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content.top_to_bottom,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper.top_to_bottom' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'ContentTransformbtt',
			[
				'label' => esc_html__( 'Transform css Bottom to Top', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'translateY(35px)',
				'placeholder' => esc_html__( 'translateY(35px)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-icon-image.bottom_to_top,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-title.bottom_to_top,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content.bottom_to_top,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper.bottom_to_top' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabTransformH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ContentTransformH',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'translateY(0)',
				'placeholder' => esc_html__( 'translateY(-35px)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper:hover .eca-hb-icon-image,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper:hover .eca-hb-title,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper:hover .eca-hb-content,
					{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper:hover .eca-hb-button-wrapper' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();		
		$this->end_controls_section();
		/*content visibility end*/
		
		/*icon style start*/
		$this->start_controls_section(
            'sectionIconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'hbiPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hbiMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'hbiIconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabshbiStyle' );
		$this->start_controls_tab(
			'tabhbiN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbiColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbiBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbiBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image',
			]
		);
		$this->add_responsive_control(
			'hbiBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbiShadow',
				'selector' => '{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabhbiH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbiColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image:hover i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbiBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbiBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image:hover',
			]
		);
		$this->add_responsive_control(
			'hbiBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbiShadowH',
				'selector' => '{{WRAPPER}} .eca-hb-wrapper .eca-hb-icon-image:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon style end*/
		
		/*image style start*/
		$this->start_controls_section(
            'sectionImageStyling',
            [
                'label' => esc_html__('Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'hbimgPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hbimgMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'hbimgSize',		
  			[		
  				'label' => esc_html__( 'Image Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabshbimgStyle' );
		$this->start_controls_tab(
			'tabhbimgN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbimgBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbimgBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image',
			]
		);
		$this->add_responsive_control(
			'hbimgBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbimgShadow',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabhbimgH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbimgBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbimgBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image:hover',
			]
		);
		$this->add_responsive_control(
			'hbimgBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbimgShadowH',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-icon-image:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*image style end*/
		
		/*title style start*/
		$this->start_controls_section(
            'sectionTitleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'hbtPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hbtMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hbtTypography',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title',				
			]
		);
		$this->start_controls_tabs( 'tabshbtStyle' );
		$this->start_controls_tab(
			'tabhbtN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbtColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbtBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbtBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title',
			]
		);
		$this->add_responsive_control(
			'hbtBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbtShadow',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabhbtH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbtColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbtBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbtBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title:hover',
			]
		);
		$this->add_responsive_control(
			'hbtBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbtShadowH',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper .eca-hb-title:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*title style end*/
		
		/*desciption style start*/
		$this->start_controls_section(
            'sectionDesciptionStyling',
            [
                'label' => esc_html__('Desciption', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'hbdPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hbdMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_control(
			'hbdWordBreak',
			[
				'label' => esc_html__( 'Word Break', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'break-all',
				'options' => [
					'keep-all'  => esc_html__( 'keep-all', 'essential-classy-addons-for-elementor' ),
					'break-all' => esc_html__( 'break-all', 'essential-classy-addons-for-elementor' ),
				],
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content,{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content p' => 'word-break: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'hbdAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],								
				'selectors' => [
                    '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content,{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'hbdSize',		
  			[		
  				'label' => esc_html__( 'Max. Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],		
				],
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content' => 'max-width: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hbdTypography',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content,{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content p',
			]
		);
		$this->start_controls_tabs( 'tabshbdStyle' );
		$this->start_controls_tab(
			'tabhbdN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbdColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content,{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbdBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbdBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content',
			]
		);
		$this->add_responsive_control(
			'hbdBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbdShadow',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabhbdH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbdColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content,{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbdBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbdBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content',
			]
		);
		$this->add_responsive_control(
			'hbdBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbdShadowH',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-content',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*desciption style end*/
		
		/*button style start*/
		$this->start_controls_section(
            'sectionButtonStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'hbbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'hbbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'hbbTypography',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper',				
			]
		);
		$this->start_controls_tabs( 'tabshbbStyle' );
		$this->start_controls_tab(
			'tabhbbN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbbColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbbBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbbBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper',
			]
		);
		$this->add_responsive_control(
			'hbbBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbbShadowN',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabhbbH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'hbbColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'hbbBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hbbBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'hbbBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'hbbShadowH',
				'selector' => '{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-button-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*button style end*/
		
		/*box style start*/
		$this->start_controls_section(
            'sectionBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'boxOverlay',
			[
				'label' => esc_html__( 'Overlay Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'boxBlur',
			[
				'label' => esc_html__( 'Blur', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'max' => 100,
						'min' => 1,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper' => '-webkit-backdrop-filter:  blur({{boxBlur.SIZE}}{{boxBlur.UNIT}});backdrop-filter:blur({{boxBlur.SIZE}}{{boxBlur.UNIT}});',
				 ],
			]
		);
		$this->add_responsive_control(
  			'loopMinHeight',		
  			[		
  				'label' => esc_html__( 'Loop Min. Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [
					'px' => [
						'min' => 1,		
						'max' => 800,
					],		
				],
				'selectors' => [
					'{{WRAPPER}} .eca-hover-background-wrapper .eca-hb-wrapper' => 'min-height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);	
		$this->end_controls_section();
		/*button style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$hbIconAnimation = !empty($settings['hbIconAnimation']) ? $settings['hbIconAnimation'] : '';
		$hbTitleAnimation = !empty($settings['hbTitleAnimation']) ? $settings['hbTitleAnimation'] : '';
		$hbContentAnimation = !empty($settings['hbContentAnimation']) ? $settings['hbContentAnimation'] : '';
		$hbButtonAnimation = !empty($settings['hbButtonAnimation']) ? $settings['hbButtonAnimation'] : '';
		
		$output = '';
		if(!empty($settings['hbItems'])){
			$output .= '<div class="eca-hover-background-wrapper">';
				foreach($settings['hbItems'] as $index => $item){
					
					$hbIconImage = !empty($item['hbIconImage']) ? $item['hbIconImage'] : 'icon';
					$bh_icon = '';
					if($hbIconImage){
						if( !empty($item['hbIcon']) && $hbIconImage=='icon'){
							ob_start();
							\Elementor\Icons_Manager::render_icon( $item['hbIcon'], [ 'aria-hidden' => 'true' ]);
							$icons_loop = ob_get_contents();
							ob_end_clean();
							
							if(!empty($icons_loop)){
								$bh_icon .= '<div class="eca-hb-icon-image '.$hbIconAnimation.'"><span class="eca-hb-icon-image icon">'.$icons_loop.'</span></div>';
							}
						}

						if( !empty($item['hbImage']['id']) && $hbIconImage=='image'){
							$image_id=$item['hbImage']['id'];
							$image_src=wp_get_attachment_image_src($image_id, 'full');
							
							$bh_icon .='<div class="eca-hb-icon-image '.$hbIconAnimation.'"><img src="'.$image_src[0].'" class="eca-hb-icon-image image"></div>';
						}
					}
					
					$hbTitle = !empty($item['hbTitle']) ? $item['hbTitle'] : '';
					$hb_title='';
					if(!empty($hbTitle)){
						if(!empty( $item['hbTitleLink']['url'] )){				
							$hb_title = '<a href='.$item['hbTitleLink']['url'].' class="eca-hb-title '.$hbTitleAnimation.'">'.esc_html($hbTitle).'</a>';
						}else{
							$hb_title = '<div class="eca-hb-title '.$hbTitleAnimation.'">'.esc_html($hbTitle).'</div>';
						}			
					}

					$hbContent = !empty($item['hbContent']) ? $item['hbContent'] : '';
					$hb_content='';
					if(!empty($hbContent)){
						$hb_content = '<div class="eca-hb-content '.$hbContentAnimation.'">'.$hbContent.'</div>';
					}

					$hb_button = '';
					$hbButtonText=!empty($item["hbButtonText"]) ? $item["hbButtonText"] : '';
					$hbButtonLink=!empty($item["hbButtonLink"]["url"]) ? $item["hbButtonLink"]["url"] : '';
					if ( $hbButtonText ) {
						$hb_button = '<a class="eca-hb-button-wrapper '.$hbButtonAnimation.'" href="'.esc_url($hbButtonLink).'">'.$hbButtonText.'</a>';
					}

					$bh_bg_image = '';
					if( !empty($item['hbBackgroundImage']['id'])){
						$image_id=$item['hbBackgroundImage']['id'];
						$image_src=wp_get_attachment_image_src($image_id, 'full');
						$bh_bg_image .= $image_src[0];
					}else{
						$bh_bg_image .= $item['hbBackgroundImage']['url'];
					}
					
					$output .= '<div class="eca-hb-wrapper" data-bgimage='.$bh_bg_image.'>';
					$hbSort=$settings["hbSort"];
					if(!empty($hbSort)) {
						$indexSort=0;
						foreach($hbSort as $indexSort => $itemSort) {
							if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='iconImage'){
								$output .= $bh_icon;
							}
							
							if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='title'){
								$output .= $hb_title;
							}
							
							if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='content'){
								$output .= $hb_content;
							}
							
							if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='button'){
								$output .= $hb_button;
							}
						$indexSort++;
						}
					}
					$output .= '</div>';
					//$output .= '<div class="eca-hb-wrapper" data-bgimage='.$bh_bg_image.'>'.$bh_icon.$hb_title.$hb_content.$hb_button.'</div>';

				}
			$output .= '</div>';
		}
		
		echo wp_kses_normalize_entities($output);
	}
}