<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Image_Accordion extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-image-accordion';
	}

    public function get_title() {
        return esc_html__('Image Accordion', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-image-accordion-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'image accordion, accordion, vertical accordion, horizontal accordion' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-image-accordion' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-image-accordion' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Image Accordion', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'contentLayout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'horizontal',
				'options' => [
					'horizontal'  => esc_html__( 'Horizontal', 'essential-classy-addons-for-elementor' ),
					'vertical' => esc_html__( 'Vertical', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'activeSlide',
			[
				'label'       => esc_html__( 'Active Slide', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => \EcafeHelper::getNumbers(1),
			]
		);
		$this->add_control(
			'flexGrow',
			[
				'label' => esc_html__( 'Active Slide Width (0-20)', 'essential-classy-addons-for-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 20,
				'step' => 0.5,
				'default' => 7,				
			]
		);
		$this->add_control(
			'iaLoop',
			[
				'label' => esc_html__( 'Loop', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'iaLoopDuration',
			[
				'label' => esc_html__( 'Duration', 'essential-classy-addons-for-elementor' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 50,
				'step' => 1,
				'default' => 5,
				'condition'    => [
					'iaLoop' => 'yes',
				],		
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'iaIconImage',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'icon'  => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
					'image' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$repeater->add_control(
			'iaIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-plus',
					'library' => 'solid',
				],
				'condition' => [
					'iaIconImage' => 'icon',
				],
			]
		);
		$repeater->add_control(
			'iaImage',
			[
				'label' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'iaIconImage' => 'image',
				],
			]
		);
		$repeater->add_control(
			'iaTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title' , 'essential-classy-addons-for-elementor' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'iaTitleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'div',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$repeater->add_control(
			'iaContent',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'show_label' => false,
				'dynamic' => [
					'active'   => true,
				],
			]
		);
		$repeater->add_control(
			'iaButtonText',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Click Here', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),			
			]
		);
		$repeater->add_control(
			'iaButtonLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
			]
		);
		$repeater->add_control(
			'iaBackgroundImage',
			[
				'label' => esc_html__( 'Featured Image', 'essential-classy-addons-for-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'dynamic' => ['active'   => true,],
			]
		);	
		$this->add_control(
			'iaItems',
			[
				'label' => '',
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'iaTitle' => esc_html__( 'Title #1', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus suscipit, velit in venenatis dignissim, risus mi ullamcorper justo, ac porta ante leo tempus enim.', 'essential-classy-addons-for-elementor' ),
					],
					[
						'iaTitle' => esc_html__( 'Title #2', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
					[
						'iaTitle' => esc_html__( 'Title #3', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
				],
				'title_field' => '{{{ iaTitle }}}',
			]
		);
		$this->add_responsive_control(
			'VerticalAlign',
			[
				'label' => esc_html__( 'Vertical Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .eca-image-accordion-loop-content' => 'align-items:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
			'horizontalAlign',
			[
				'label' => esc_html__( 'Horizontal Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'selectors' => [
                    '{{WRAPPER}} .eca-image-accordion-loop-content' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'contentSortngSection',
			[
				'label' => esc_html__( 'Content Sorting', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeaterSort = new \Elementor\Repeater();		
		$repeaterSort->add_control(
			'sortingfield',[
				'label' => esc_html__( 'Select','essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'iconImage',
				'options' => [
					'iconImage' => esc_html__( 'Icon/Image','essential-classy-addons-for-elementor' ),	
					'title' => esc_html__( 'Title','essential-classy-addons-for-elementor' ),	
					'content' => esc_html__( 'Content','essential-classy-addons-for-elementor' ),	
					'button' => esc_html__( 'Button','essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
            'iaSort',
            [
				'label' => esc_html__( 'Sortable', 'essential-classy-addons-for-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [
                        'sortingfield' => 'iconImage',
                    ],
                    [
                        'sortingfield' => 'title',
                    ],						
					[
                       'sortingfield' => 'content',
                    ],	
                    [
                        'sortingfield' => 'button',
                    ],
                ],                
				'fields' => $repeaterSort->get_controls(),
                'title_field' => '{{{ sortingfield }}}',
            ]
        ); 
		$this->end_controls_section();
		
		$this->start_controls_section(
			'contentAdvancedSection',
			[
				'label' => esc_html__( 'Advanced Options', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iaContentAnim',
			[
				'label' => esc_html__( 'Content Animation', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iaContentAnimFrom',
			[
				'label' => esc_html__( 'From', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'iaafleft',
				'options' => [
					'iaafleft'  => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
					'iaafright' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
				],
				'condition'    => [
					'iaContentAnim' => 'yes',
				],
			]
		);
		$this->add_control(
			'iaMouseleave',
			[
				'label' => esc_html__( 'Mouse Leave Remove Active', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->end_controls_section();
		
		/*icon style start*/
		$this->start_controls_section(
            'sectionIconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iaiPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iaiMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iaiIconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);
		$this->add_control(
			'iaiColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iaiBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iaiBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon',
			]
		);
		$this->add_responsive_control(
			'iaiBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iaiShadow',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.icon',
			]
		);
		$this->end_controls_section();
		/*icon style end*/
		
		/*image style start*/
		$this->start_controls_section(
            'sectionImageStyling',
            [
                'label' => esc_html__('Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iaimgPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iaimgMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iaimgSize',		
  			[		
  				'label' => esc_html__( 'Image Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iaimgBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iaimgBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image',
			]
		);
		$this->add_responsive_control(
			'iaimgBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iaimgShadow',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-icon-image.image',
			]
		);
		$this->end_controls_section();
		/*image style end*/
		
		/*title style start*/
		$this->start_controls_section(
            'sectionTitleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iatPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iatMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'iatTypography',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper',				
			]
		);
		$this->add_control(
			'iatColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iatBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iatBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper',
			]
		);
		$this->add_responsive_control(
			'iatBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iatShadow',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-title-wrapper',
			]
		);
		$this->end_controls_section();
		/*title style end*/
		
		/*desciption style start*/
		$this->start_controls_section(
            'sectionDesciptionStyling',
            [
                'label' => esc_html__('Desciption', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iadPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iadMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_control(
			'iadWordBreak',
			[
				'label' => esc_html__( 'Word Break', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'break-all',
				'options' => [
					'keep-all'  => esc_html__( 'keep-all', 'essential-classy-addons-for-elementor' ),
					'break-all' => esc_html__( 'break-all', 'essential-classy-addons-for-elementor' ),
				],
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-loop-content .eca-ia-content-wrapper,{{WRAPPER}} .eca-image-accordion-loop-content .eca-ia-content-wrapper p' => 'word-break: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'iadAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],								
				'selectors' => [
                    '{{WRAPPER}} .eca-image-accordion-loop-content .eca-ia-content-wrapper,{{WRAPPER}} .eca-image-accordion-loop-content .eca-ia-content-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'iadSize',		
  			[		
  				'label' => esc_html__( 'Max. Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],		
				],
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper' => 'max-width: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'iadTypography',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper,{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper p',
			]
		);
		$this->add_control(
			'iadColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper,{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iadBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iadBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper',
			]
		);
		$this->add_responsive_control(
			'iadBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iadShadow',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-content-wrapper',
			]
		);
		$this->end_controls_section();
		/*desciption style end*/
		
		/*button style start*/
		$this->start_controls_section(
            'sectionButtonStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iabPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iabMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'iabTypography',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper',				
			]
		);
		$this->start_controls_tabs( 'tabsiabStyle' );
		$this->start_controls_tab(
			'tabiabN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iabColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iabBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iabBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper',
			]
		);
		$this->add_responsive_control(
			'iabBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iabShadowN',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabiabH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iabColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iabBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iabBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'iabBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iabShadowH',
				'selector' => '{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-content .eca-ia-button-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*button style end*/
		
		/*loop item style start*/
		$this->start_controls_section(
            'sectionLoopItemStyling',
            [
                'label' => esc_html__('Loop Item', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
  			'iaLoopGap',		
  			[		
  				'label' => esc_html__( 'Gap', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-wrapper:not(:first-child):not(:last-child)' => 'margin-left: calc( {{SIZE}}{{UNIT}} / 2 ) !important;margin-right: calc( {{SIZE}}{{UNIT}} / 2 ) !important;',
				],
				'condition'    => [
					'contentLayout' => 'horizontal',
				],
  			]		
  		);
		$this->add_responsive_control(
  			'iaLoopGapV',		
  			[		
  				'label' => esc_html__( 'Gap', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-wrapper:not(:first-child):not(:last-child)' => 'margin-top: calc( {{SIZE}}{{UNIT}} / 2 ) !important;margin-bottom: calc( {{SIZE}}{{UNIT}} / 2 ) !important;',
				],
				'condition'    => [
					'contentLayout' => 'vertical',
				],
  			]		
  		);
		$this->add_control(
			'iaLoopOverlayColor',
			[
				'label' => esc_html__( 'Overlay Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-wrapper:hover .eca-image-accordion-loop-content,
					{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-loop-wrapper.active-image-accrodian .eca-image-accordion-loop-content' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		/*loop item style end*/
		
		/*Box style start*/
		$this->start_controls_section(
            'sectionBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
  			'boxHeight',		
  			[		
  				'label' => esc_html__( 'Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-image-accordion-wrapper,{{WRAPPER}} .eca-image-accordion-wrapper .eca-image-accordion-inner' => 'height: {{SIZE}}{{UNIT}};',		
				],		
  			]		
  		);
		$this->add_responsive_control(
			'boxBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-image-accordion-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->end_controls_section();
		/*box style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$contentLayout = !empty($settings['contentLayout']) ? $settings['contentLayout'] : 'horizontal';
		$iaLoop = isset($settings['iaLoop']) ? $settings['iaLoop'] : 'no';
		$iaLoopDuration = !empty($settings['iaLoopDuration']) ? $settings['iaLoopDuration'] : 5;
		$activeSlide = !empty($settings['activeSlide']) ? $settings['activeSlide'] : 1;
		$flexGrow = !empty($settings['flexGrow']) ? $settings['flexGrow'] : 7;
		$flexGrowValue='data-flexgrow="'.esc_attr($flexGrow).'"';
		$iaContentAnim = isset($settings['iaContentAnim']) ? $settings['iaContentAnim'] : 'no';
		$iaMouseleave = isset($settings['iaMouseleave']) ? $settings['iaMouseleave'] : 'no';
		
		$iaContentAnimClass=$iaMouseleaveClass='';
		if($iaContentAnim && $iaContentAnim=='yes'){			
			$iaContentAnimClass = ' eca-ia-animation';
			$iaContentAnimClass .= ' '.$settings['iaContentAnimFrom'];
		}
		if($iaMouseleave && $iaMouseleave=='yes'){			
			$iaMouseleaveClass = ' eca-ia-mouseleave';
		}
		$iaLoopdata = $iaLoopclass = '';
		if($iaLoop && $iaLoop=='yes'){
			$iaLoopdata = 'data-ialoop='.$iaLoop;
			$iaLoopdata .= ' data-duration='.$iaLoopDuration;
			$iaLoopclass = ' ialoop';
		}
		$output = '<div class="eca-image-accordion-wrapper '.$contentLayout.' '.$iaLoopclass.' '.$iaMouseleaveClass.'" '.$iaLoopdata.'>';
			$output .= '<div class="eca-image-accordion-inner" '.$flexGrowValue.'>';
				if(!empty($settings['iaItems'])){
					$index=1;
					foreach($settings['iaItems'] as $index => $item){						
						$ia_bg_img = '';
						if(!empty($item['iaBackgroundImage']['url'])){
							$ia_bg_img = $item['iaBackgroundImage']['url'];
						}
						
						$iaIconImage = !empty($item['iaIconImage']) ? $item['iaIconImage'] : 'icon';
						$ia_icon = '';
						if($iaIconImage){
							if( !empty($item['iaIcon']) && $iaIconImage=='icon'){
								ob_start();
								\Elementor\Icons_Manager::render_icon( $item['iaIcon'], [ 'aria-hidden' => 'true' ]);
								$icons_loop = ob_get_contents();
								ob_end_clean();
								
								if(!empty($icons_loop)){
									$ia_icon .= '<span class="eca-ia-icon-image icon">'.$icons_loop.'</span>';
								}
							}

							if( !empty($item['iaImage']['id']) && $iaIconImage=='image'){
								$image_id=$item['iaImage']['id'];
								$image_src=wp_get_attachment_image_src($image_id, 'full');
								
								$ia_icon .='<img src="'.$image_src[0].'" class="eca-ia-icon-image image">';
							}
						}						
						
						$ia_title = '';
						$iaTitle = !empty($item['iaTitle']) ? $item['iaTitle'] : '';
						if( $iaTitle ){							
							$iaTitleTag = !empty($item['iaTitleTag']) ? $item['iaTitleTag'] : 'div';
							$ia_title ='<'.\EcafeHelper::check_and_validate_html_tag($iaTitleTag).' class="eca-ia-title-wrapper">'.$iaTitle.'</'.\EcafeHelper::check_and_validate_html_tag($iaTitleTag).'>';
						}
						
						$ia_content = '';
						$iaContent = !empty($item['iaContent']) ? $item['iaContent'] : '';
						if( $iaContent ){
							$ia_content ='<div class="eca-ia-content-wrapper">'.$iaContent.'</div>';
						}
						
						$ia_button = '';
						$iaButtonText=!empty($item["iaButtonText"]) ? $item["iaButtonText"] : '';
						$iaButtonLink=!empty($item["iaButtonLink"]["url"]) ? $item["iaButtonLink"]["url"] : '';
						if ( $iaButtonText ) {
							$ia_button = '<a class="eca-ia-button-wrapper" href="'.esc_url($iaButtonLink).'">'.$iaButtonText.'</a>';
						}

						$loopStyle='style="flex-grow: 1;"';
						$active='';						
						if($index== $activeSlide - 1){
							$loopStyle='style="flex-grow: '.esc_attr($flexGrow).';"';
							$active='active-image-accrodian';							
						}
							$output .= '<div class="eca-image-accordion-loop-wrapper '.esc_attr($active).' '.$iaContentAnimClass.'" '.$loopStyle.'>';
								$output .= '<img class="eca-image-accordion-loop-image" src="'.$ia_bg_img.'">';
								$output .= '<div class="eca-image-accordion-loop-content">';
									
									$iaSort=$settings["iaSort"];
									if(!empty($iaSort)) {
										$indexSort=0;
										foreach($iaSort as $indexSort => $itemSort) {
											if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='iconImage'){
												$output .= wp_kses_normalize_entities($ia_icon);
											}
											
											if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='title'){
												$output .= wp_kses_normalize_entities($ia_title);
											}
											
											if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='content'){
												$output .= wp_kses_normalize_entities($ia_content);
											}
											
											if(!empty($itemSort['sortingfield']) && $itemSort['sortingfield']=='button'){
												$output .= wp_kses_normalize_entities($ia_button);
											}
										$indexSort++;
										}
									}
									//$output .= wp_kses_normalize_entities($ia_icon.$ia_title.$ia_content.$ia_button);
								$output .= '</div>';
							$output .= '</div>';

						$index++;
					}
				}
			$output .= '</div>';
		$output .= '</div>';
		
		echo wp_kses_normalize_entities($output);
	}
}