<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Infobox extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-infobox';
	}

    public function get_title() {
        return esc_html__('Infobox', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-infobox-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'infobox','icon','box layout','iconic layout','list','info box' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-infobox' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Infobox', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'layout1',
				'options' => [
					'layout1'  => esc_html__( 'Layout 1', 'essential-classy-addons-for-elementor' ),
					'layout2'  => esc_html__( 'Layout 2', 'essential-classy-addons-for-elementor' ),
					'layout3'  => esc_html__( 'Layout 3', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'layout3Direction',
			[
				'label' => esc_html__( 'Effect', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left'  => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
					'right'  => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
					'top'  => esc_html__( 'Top', 'essential-classy-addons-for-elementor' ),
					'bottom'  => esc_html__( 'Bottom', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'layout' => 'layout3'
				]
			]
		);
		$this->add_control(
			'iconImageText',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'icon'  => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
					'image'  => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
					'text'  => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'iconLibrary',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => [
					'iconImageText' => 'icon'
				],
			]
		);
		$this->add_control(
			'imageSelect',
			[
				'label' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'media_type' => 'image',
				'dynamic' => [
					'active'   => true,
				],
				'condition' => [
					'iconImageText' => 'image'
				],
			]
		);
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'imageSelectThumbnail',
				'default' => 'full',
				'exclude' => [ 'custom' ],
				'condition' => [
					'iconImageText' => 'image'
				],
			]
		);
		$this->add_control(
			'textSelect',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'eca', 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active'   => true,],
				'condition' => [
					'iconImageText' => 'text'
				],
			]
		);
		$this->add_control(
			'infoTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Title', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'infoTitleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$this->add_control(
			'infoDesc',
			[
				'label' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter your Description', 'essential-classy-addons-for-elementor' ),
				'dynamic' => ['active' => true,],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'buttonText',
			[
				'label' => esc_html__( 'Button Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Click Here', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Text', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'buttonLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
			]
		);
		$this->add_control(
			'pinText',
			[
				'label' => esc_html__( 'Pin Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'New', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Pin Text', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
  			'boxMinHeight',		
  			[		
  				'label' => esc_html__( 'Min-Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 700,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'separator' => 'before',
				'selectors' => [		
					'{{WRAPPER}} .eca-info-wrapper' => 'min-height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
			'boxAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .eca-info-wrapper .eca-info-inner' => 'align-items:{{VALUE}};',
                    '{{WRAPPER}} .eca-info-wrapper.layout2 .eca-info-inner-one,{{WRAPPER}} .eca-info-wrapper.layout2 .eca-info-inner-two' => 'align-items:{{VALUE}};justify-content:{{VALUE}};',
                ],
				'condition' => [
					'layout' => ['layout1','layout2'],
				]
			]
		);
		$this->end_controls_section();
		
		/*style start*/
		/*icon*/
		$this->start_controls_section(
            'iconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'iconImageText' => 'icon',					
				]
            ]
        );
		$this->add_responsive_control(
			'iconPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iconMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iconSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon i:before' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsIcontyle' );
		$this->start_controls_tab(
			'tabIconNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon i:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon',
			]
		);
		$this->add_responsive_control(
			'iconBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-icon',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-icon i:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-icon',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-icon',
			]
		);
		$this->add_responsive_control(
			'iconBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-icon',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon*/
		
		/*image*/
		$this->start_controls_section(
            'imageStyling',
            [
                'label' => esc_html__('Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'iconImageText' => 'image',					
				]
            ]
        );
		$this->add_responsive_control(
			'imagePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'imageMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'imageMaxWidth',		
  			[		
  				'label' => esc_html__( 'Max Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-image' => 'max-width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsImagetyle' );
		$this->start_controls_tab(
			'tabImageNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'imageBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-image',
			]
		);
		$this->add_responsive_control(
			'imageBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'imageShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-image',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabImageHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'imageBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-image',
			]
		);
		$this->add_responsive_control(
			'imageBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'imageShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-image',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*image*/
		
		/*text*/
		$this->start_controls_section(
            'textStyling',
            [
                'label' => esc_html__('Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'iconImageText' => 'text',					
				]
            ]
        );
		$this->add_responsive_control(
			'textPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'textMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'textTypo',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text',				
			]
		);
		$this->start_controls_tabs( 'tabsTexttyle' );
		$this->start_controls_tab(
			'tabTextNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'textColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'textBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'textBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text',
			]
		);
		$this->add_responsive_control(
			'textBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'textShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'textTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-icon-image-text.eca-text',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabTextHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'textColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'textBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-text',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'textBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-text',
			]
		);
		$this->add_responsive_control(
			'textBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'textShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-text',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'textTextShadowHover',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-icon-image-text.eca-text',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*text*/
		
		/*title*/
		$this->start_controls_section(
            'titleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'titlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'titleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'titleTypo',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-title',				
			]
		);
		$this->start_controls_tabs( 'tabsTitletyle' );
		$this->start_controls_tab(
			'tabTitleNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper .eca-info-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-title',
			]
		);
		$this->add_responsive_control(
			'titleBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-title',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabTitleHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-title',
			]
		);
		$this->add_responsive_control(
			'titleBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowHover',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-title',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*title*/
		
		/*description*/
		$this->start_controls_section(
            'descStyling',
            [
                'label' => esc_html__('Description', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'descPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'descMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'descTypo',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',				
			]
		);
		$this->add_responsive_control(
			'descAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-info-wrapper .eca-info-desc' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsDesctyle' );
		$this->start_controls_tab(
			'tabDescNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'descColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'descBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'descBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->add_responsive_control(
			'descBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'descShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'descTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabDescHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'descColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'descBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'descBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->add_responsive_control(
			'descBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'descShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'descTextShadowHover',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-desc,{{WRAPPER}} .eca-info-wrapper .eca-info-desc p',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*description*/
		
		/*button*/
		$this->start_controls_section(
            'buttonStyling',
            [
                'label' => esc_html__('Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'buttonPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'buttonMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'buttonTypo',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-button',				
			]
		);
		$this->start_controls_tabs( 'tabsButtontyle' );
		$this->start_controls_tab(
			'tabButtonNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper .eca-info-button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-button',
			]
		);
		$this->add_responsive_control(
			'buttonBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabButtonHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'buttonColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'buttonBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'buttonBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-button',
			]
		);
		$this->add_responsive_control(
			'buttonBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'buttonShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-button',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*button*/
		
		/*pin*/
		$this->start_controls_section(
            'pinStyling',
            [
                'label' => esc_html__('Pin', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'pinPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-pin' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'pinTypo',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-pin',				
			]
		);
		$this->add_responsive_control(
  			'pinTopOffset',		
  			[		
  				'label' => esc_html__( 'Top Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => -300,		
						'max' => 300,
					],
					'%' => [		
						'min' => -100,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-info-wrapper .eca-info-pin' => 'top:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'pinRightOffset',		
  			[		
  				'label' => esc_html__( 'Right Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => -300,		
						'max' => 300,
					],
					'%' => [		
						'min' => -100,		
						'max' => 100,
						'step' => 1,
					],
				],
				'separator' => 'after',
				'selectors' => [		
					'{{WRAPPER}} .eca-info-wrapper .eca-info-pin' => 'right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsPintyle' );
		$this->start_controls_tab(
			'tabPinNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pinColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-pin' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pinBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper .eca-info-pin',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pinBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-pin',
			]
		);
		$this->add_responsive_control(
			'pinBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper .eca-info-pin' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'pinShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper .eca-info-pin',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabPinHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pinColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-pin' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pinBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-pin',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pinBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-pin',
			]
		);
		$this->add_responsive_control(
			'pinBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover .eca-info-pin' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'pinShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover .eca-info-pin',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*pin*/
		
		/*box content*/
		$this->start_controls_section(
            'boxContentStyling',
            [
                'label' => esc_html__('Box Content', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'boxContentPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'boxContentMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsboxContentStyle' );
		$this->start_controls_tab(
			'tabboxContentNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxContentBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxContentBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper',
			]
		);
		$this->add_responsive_control(
			'boxContentBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxContentShadowNorm',
				'selector' => '{{WRAPPER}} .eca-info-wrapper',
			]
		);
		$this->add_control(
			'boxContentTransformNorm',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabboxContentHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxContentBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-info-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxContentBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'boxContentBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-info-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxContentShadowHover',
				'selector' => '{{WRAPPER}} .eca-info-wrapper:hover',
			]
		);
		$this->add_control(
			'boxContentTransformHover',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-info-wrapper:hover' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'boxContentOverflow',
			[
				'label'     => esc_html__( 'Overflow', 'essential-classy-addons-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Hidden', 'essential-classy-addons-for-elementor' ),
				'label_off'    => esc_html__( 'Visible', 'essential-classy-addons-for-elementor' ),
				'default' => 'no',
			]
		);
		$this->end_controls_section();
		/*box content*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$layout=!empty($settings["layout"]) ? $settings["layout"] : 'layout1';
		$layout3Direction=!empty($settings["layout3Direction"]) ? $settings["layout3Direction"] : 'left';
		
		$iconImageText=!empty($settings["iconImageText"]) ? $settings["iconImageText"] : 'icon';
		$iconLibrary=!empty($settings["iconLibrary"]) ? $settings["iconLibrary"] : '';
		$imageSelect=!empty($settings["imageSelect"]) ? $settings["imageSelect"] : '';		
		$textSelect=!empty($settings["textSelect"]) ? $settings["textSelect"] : '';
		
		$infoTitle=!empty($settings["infoTitle"]) ? $settings["infoTitle"] : '';
		$infoDesc=!empty($settings["infoDesc"]) ? $settings["infoDesc"] : '';
		$buttonText=!empty($settings["buttonText"]) ? $settings["buttonText"] : '';
		$buttonLink=!empty($settings["buttonLink"]["url"]) ? $settings["buttonLink"]["url"] : '';
		$pinText=!empty($settings["pinText"]) ? $settings["pinText"] : '';
		$infoTitleTag=!empty($settings["infoTitleTag"]) ? $settings["infoTitleTag"] : 'h1';
		$boxContentOverflow=$settings["boxContentOverflow"];
		
		$iconImageTextOP=$buttonLinkTarget=$buttonLinkNoFollow=$button=$title=$desc=$pinTitle=$output=$layout3DirectionDir=$overflowClass='';
		if(!empty($iconImageText)){
			if($iconImageText=='icon'){
				if(!empty($iconLibrary)){
					ob_start();
					\Elementor\Icons_Manager::render_icon( $iconLibrary, [ 'aria-hidden' => 'true' ]);
					$iconImageTextOP = '<span class="eca-icon-image-text eca-icon">'.ob_get_contents().'</span>';
					ob_end_clean();
				}
			}else if($iconImageText=='image'){
				if(!empty($settings["imageSelect"]["url"])){
					$imageSelect=$settings['imageSelect']['id'];
					$img = wp_get_attachment_image_src($imageSelect,$settings['imageSelectThumbnail_size']);
					$imgSrc = $img[0];
					$imageId=$settings["imageSelect"]["id"];
					$imageAlt = get_post_meta($imageId, '_wp_attachment_image_alt', TRUE);
					if(!$imageAlt){
						$imageAlt = get_the_title($imageId);
					}else if(!$imageAlt){
						$imageAlt = 'Image';
					}
					$iconImageTextOP = '<img class="eca-icon-image-text eca-image" src='.esc_url($imgSrc).' alt="'.esc_attr($imageAlt).'" />';
				}
			}else if($iconImageText=='text'){
				if(!empty($textSelect)){
					$iconImageTextOP = '<span class="eca-icon-image-text eca-text">'.$textSelect.'</span>';
				}				
			}
		}
		
		if(!empty($infoTitle)){
			$title = '<'.\EcafeHelper::check_and_validate_html_tag($infoTitleTag).' class="eca-info-title">'.esc_html($infoTitle).'</'.\EcafeHelper::check_and_validate_html_tag($infoTitleTag).'>';
		}
		
		if(!empty($infoDesc)){
			$desc = '<div class="eca-info-desc">'.esc_html($infoDesc).'</div>';
		}
		
		if(!empty($pinText)){
			$pinTitle = '<span class="eca-info-pin">'.esc_html($pinText).'</span>';
		}
		
		if(!empty($buttonLink)){							
			$buttonLinkTarget = $settings['buttonLink']['is_external'] ? ' target="_blank"' : '';
			$buttonLinkNoFollow = $settings['buttonLink']['nofollow'] ? ' rel="nofollow"' : '';
		}
		
		if(!empty($buttonText)){
			$button = '<a class="eca-info-button" href="'.$buttonLink.'"' . $buttonLinkTarget . $buttonLinkNoFollow . '>'.esc_html($buttonText).'</a>';
		}
		
		if(!empty($boxContentOverflow) && $boxContentOverflow=='yes'){
			$overflowClass = 'eca-visible';
		}
		$output .= '<div class="eca-info-wrapper '.$layout.' '.$overflowClass.'">'; 
		if(!empty($layout)){
			if($layout=='layout1'){
				$output .= '<div class="eca-info-inner">';
					$output .= $iconImageTextOP;
					$output .= $title;
					$output .= $desc;
					$output .= $button;
					$output .= $pinTitle;
				$output .= '</div>';
			}else if($layout=='layout2' || $layout=='layout3'){
				$output .= '<div class="eca-info-inner-one">';
					$output .= $iconImageTextOP;
					$output .= $title;
				$output .= '</div>';
				
					if($layout=='layout3'){
						if($layout3Direction=='right'){
						  $layout3DirectionDir = ' eca-right-dir';
						}else if($layout3Direction=='top'){
							$layout3DirectionDir = ' eca-top-dir';
						}else if($layout3Direction=='bottom'){
							$layout3DirectionDir = ' eca-bottom-dir';
						}					
					}
					
				$output .= '<div class="eca-info-inner-two '.$layout3DirectionDir.'">'; 
					$output .= $desc;
					$output .= $button;
				$output .= '</div>';
				$output .= $pinTitle;
			}
		}
		$output .= '</div>';
		
		echo wp_kses_normalize_entities($output);
		
	}
}