<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Jetengine_Media extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-jetengine-media';
	}

    public function get_title() {
        return esc_html__('JetEngine : Media', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-jet-icon';
    }

    public function get_categories() {
        return array('ecjetengine');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-jet-general' ];
    }
	
	public function get_keywords() {
		return [ 'jet','jetengine','jet media','jetengine media','media','image' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'JetEngine : Media', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'jetImageType',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'id',
				'options' => [
					'id'  => esc_html__( 'ID', 'essential-classy-addons-for-elementor' ),
					'url' => esc_html__( 'URL', 'essential-classy-addons-for-elementor' ),
					'array' => esc_html__( 'Array', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'jetImage',
			[
				'label' => esc_html__( 'Image Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Image Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'jetImageSize',
				'default' => 'full',				
				'exclude' => [ 'custom' ],
				'condition' => [
					'jetImageType' => 'id'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'jetMediaStyling',
            [
                'label' => esc_html__('Jet Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
  			'jetMediaSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-jet-image img' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
			'jetMediaPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-jet-image img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsjetMediaStyle' );
		$this->start_controls_tab(
			'tabjetMediaNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'jetMediaBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-jet-image img',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'jetMediaBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-jet-image img',
			]
		);
		$this->add_responsive_control(
			'jetMediaBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-jet-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'jetMediaShadowNorm',
				'selector' => '{{WRAPPER}} .eca-jet-image img',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabjetMediaHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'jetMediaBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-jet-image img:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'jetMediaBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-jet-image img:hover',
			]
		);
		$this->add_responsive_control(
			'jetMediaBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-jet-image img:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'jetMediaShadowH',
				'selector' => '{{WRAPPER}} .eca-jet-image img:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if(class_exists('Jet_Engine')) {
			$postData = array();
			if(!isset($GLOBALS['post'])){
				return $postData;
			}
			$postData = $GLOBALS['post'];
			
			if(empty($postData)){
				$postData = get_post(0);
			}
			$id = $postData->ID;
			$jetImageType = !empty($settings['jetImageType']) ? $settings['jetImageType'] : 'id';
			$jetImage = !empty($settings['jetImage']) ? $settings['jetImage'] : '';
			if(!empty($jetImage)){
				$image = get_post_meta($id,$jetImage,true);
				$image_alt='';
				if($image) {
					echo '<div class="eca-jet-image">';
						if(!empty($jetImageType) && $jetImageType == 'id'){					
							$size = !empty($settings['jetImageSize_size']) ? $settings['jetImageSize_size'] : 'full';					
							echo wp_get_attachment_image( $image, $size );
						}else if(!empty($jetImageType) && $jetImageType == 'url'){
							echo '<img src="'.esc_url($image).'" />';
						}else if(!empty($jetImageType) && $jetImageType == 'array'){
							$image_alt = get_post_meta($image['id'], '_wp_attachment_image_alt', TRUE);
							echo '<img src="'.esc_url($image['url']).'" alt="'.esc_attr($image_alt).'" />';
						}
					echo '</div>';
				}				
			}
		}
	}
}