<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Jetengine_Text extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-jetengine-text';
	}

    public function get_title() {
        return esc_html__('JetEngine : Text', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-jet-icon';
    }

    public function get_categories() {
        return array('ecjetengine');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-jet-general' ];
    }
	
	public function get_keywords() {
		return [ 'jet','jetengine','jet text','jetengine tex','text' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'JetEngine : Text', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'jetText',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'jetTextTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'jetTextStyling',
            [
                'label' => esc_html__('Jet Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'jetTextTypography',
				'selector' => '{{WRAPPER}} .ec-jet-text-wrapper .eca-jettext',				
			]
		);
		$this->add_responsive_control(
			'jetTextAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-jet-text-wrapper .eca-jettext' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsjetTextStyle' );
		$this->start_controls_tab(
			'tabjetTextNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'jetTextColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-jet-text-wrapper .eca-jettext' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabjetTextHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'jetTextColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-jet-text-wrapper .eca-jettext:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if(class_exists('Jet_Engine')) {
			$postData = array();
			if(!isset($GLOBALS['post'])){
				return $postData;
			}
			$postData = $GLOBALS['post'];
			
			if(empty($postData)){
				$postData = get_post(0);
			}
			$id = $postData->ID;
			
			$jetText = !empty($settings['jetText']) ? $settings['jetText'] : '';
			if($jetText){
				echo '<div class="ec-jet-text-wrapper">';				
					$jetTextTag= !empty($settings['jetTextTag']) ? $settings['jetTextTag'] : 'h1';
					echo '<'.\EcafeHelper::check_and_validate_html_tag($jetTextTag).' class="eca-jettext">';
					echo get_post_meta($id,$jetText,true);
					echo '</'.\EcafeHelper::check_and_validate_html_tag($jetTextTag).'>';
				echo '</div>';
			}
		}				
	}
}