<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Jetengine_Time extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-jetengine-time';
	}

    public function get_title() {
        return esc_html__('JetEngine : Time', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-jet-icon';
    }

    public function get_categories() {
        return array('ecjetengine');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-jet-general' ];
    }
	
	public function get_keywords() {
		return [ 'jet','jetengine','jet time','jetengine time','time' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'JetEngine : Time', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'jetTime',
			[
				'label' => esc_html__( 'Time Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Time Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'jetTimeStyling',
            [
                'label' => esc_html__('Jet Time', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'jetTimeTypography',
				'selector' => '{{WRAPPER}} .eca-jet-time',				
			]
		);
		$this->add_responsive_control(
			'jetTimeAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-jet-time' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsjetTimeStyle' );
		$this->start_controls_tab(
			'tabjetTimeNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'jetTimeColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-jet-time' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabjetTimeHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'jetTimeColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-jet-time:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if(class_exists('Jet_Engine')) {
			$postData = array();
			if(!isset($GLOBALS['post'])){
				return $postData;
			}
			$postData = $GLOBALS['post'];
			
			if(empty($postData)){
				$postData = get_post(0);
			}
			$id = $postData->ID;
			$jetTime = !empty($settings['jetTime']) ? $settings['jetTime'] : '';
			if(!empty($jetTime)){
				echo '<div class="eca-jet-time">';
					echo get_post_meta($id,$jetTime,true);
				echo '</div>';
			}
		}		
	}
}