<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Jetengine_Wysiwyg extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-jetengine-wysiwyg';
	}

    public function get_title() {
        return esc_html__('JetEngine : Wysiwyg', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-jet-icon';
    }

    public function get_categories() {
        return array('ecjetengine');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-jet-general' ];
    }
	
	public function get_keywords() {
		return [ 'jet','jetengine','jet wysiwyg','visual','wysiwyg' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'JetEngine : Wysiwyg', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'jetWsiwyg',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'jetWysiwygStyling',
            [
                'label' => esc_html__('Jet Wysiwyg', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'jetWysiwygTypography',
				'selector' => '{{WRAPPER}} .ec-jet-wsiwyg-wrapper,{{WRAPPER}} .ec-jet-wsiwyg-wrapper p',				
			]
		);
		$this->add_responsive_control(
			'jetWysiwygAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-jet-wsiwyg-wrapper,{{WRAPPER}} .ec-jet-wsiwyg-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsjetWysiwygStyle' );
		$this->start_controls_tab(
			'tabjetWysiwygNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'jetWysiwygColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-jet-wsiwyg-wrapper,{{WRAPPER}} .ec-jet-wsiwyg-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabjetWysiwygHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'jetWysiwygColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-jet-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-jet-wsiwyg-wrapper:hover p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if(class_exists('Jet_Engine')) {
			$postData = array();
			if(!isset($GLOBALS['post'])){
				return $postData;
			}
			$postData = $GLOBALS['post'];
			
			if(empty($postData)){
				$postData = get_post(0);
			}
			$id = $postData->ID;
			$jetWsiwyg = !empty($settings['jetWsiwyg']) ? $settings['jetWsiwyg'] : '';
			if($jetWsiwyg){
				echo '<div class="ec-jet-wsiwyg-wrapper">';
					echo get_post_meta($id,$jetWsiwyg,true);
				echo '</div>';
			}
		}
	}
}