<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Marketing_Link extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-marketing-link';
	}

    public function get_title() {
        return esc_html__('Marketing Link', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-button-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'button','creative button','cool button','advanced button','link','marketing' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-marketing-link' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-marketing-link' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Marketing Link', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'mlStyle',
			[
				'label' => esc_html__( 'Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => esc_html__( 'Style 1', 'essential-classy-addons-for-elementor' ),
					'style2' => esc_html__( 'Style 2', 'essential-classy-addons-for-elementor' ),
					'style3' => esc_html__( 'Style 3', 'essential-classy-addons-for-elementor' ),
					'style4' => esc_html__( 'Style 4', 'essential-classy-addons-for-elementor' ),
					'style5' => esc_html__( 'Style 5', 'essential-classy-addons-for-elementor' ),
					'style6' => esc_html__( 'Style 6', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'mLMainText',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Label', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::after' => 'content: "{{VALUE}}";',
				],	
			]
		);
		$this->add_control(
			'mLLinkLabel',
			[
				'label' => esc_html__( 'Link Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'wordpress', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Label', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'mLMainLink',
			[
				'label' => esc_html__( 'URL', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'essential-classy-addons-for-elementor' ),
				'show_external' => true,
				'default' => ['url' => 'http://elementor.com/',],
				'dynamic' => ['active'=> true,],
			]
		);
		$this->add_control(
			'mLMainIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-microblog',
					'library' => 'brands',
				],
			]
		);
		$this->add_control(
			'mlType',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),
					'mbp' => esc_html__( 'Multiple Browser Popup', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'mlTypeD',
			[
				'label' => esc_html__( 'URL', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'essential-classy-addons-for-elementor' ),
				'show_external' => true,
				'default' => ['url' => 'http://elementor.com/',],
				'dynamic' => ['active'=> true,],
				'condition'    => [
					'mlType' => 'default',
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'mLLinkLabel',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Label', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeater->add_control(
			'mLLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'essential-classy-addons-for-elementor' ),
				'show_external' => true,
				'default' => ['url' => '#',],
				'dynamic' => ['active'=> true,],				
			]
		);
		$this->add_control(
			'mLLinkList',
			[
				'label' => esc_html__( 'List', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),			
				'default' => [
					[						
						'mLLinkLabel' => 'Wordpress',
					],
					[	
						'mLLinkLabel' => 'Google',
					],
					[	
						'mLLinkLabel' => 'Wordpress Plugins',						
					],
				],
				'condition'    => [
					'mlType' => 'mbp',
				],
				'title_field' => '{{{ mLLinkLabel }}}',
			]
		);
		$this->end_controls_section();
		/*style start*/
		$this->start_controls_section(
            'mlStyling',
            [
                'label' => esc_html__('Marketing Link', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'mlStyle' => 'style1',
				],
            ]
        );
		$this->add_responsive_control(
			'mlPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'mlAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .ec-marketing-link-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'mlIconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'mlIconSpace',		
  			[		
  				'label' => esc_html__( 'Icon Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i,{{WRAPPER}} .ec-marketing-link svg' => 'margin-right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'mlTextTypography',
				'selector' => '{{WRAPPER}} .ec-marketing-link',				
			]
		);
		$this->start_controls_tabs( 'tabsMltyle' );
		$this->start_controls_tab(
			'tabMlNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'mlColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'mlBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-marketing-link',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'mlBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-marketing-link',
			]
		);
		$this->add_responsive_control(
			'mlBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-marketing-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'mlShadowNorm',
				'selector' => '{{WRAPPER}} .ec-marketing-link',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'mlTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-marketing-link',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabMlHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'mlColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'mlBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-marketing-link:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'mlBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-marketing-link:hover',
			]
		);
		$this->add_responsive_control(
			'mlBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-marketing-link:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'mlShadowHover',
				'selector' => '{{WRAPPER}} .ec-marketing-link:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'mlTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-marketing-link:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'mlTransition',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'mlTransform',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'ml2Styling',
            [
                'label' => esc_html__('Marketing Link', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'mlStyle' => 'style2',
				],
            ]
        );
		$this->add_responsive_control(
			'ml2Padding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper .ec-marketing-link span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ml2Align',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .ec-marketing-link-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'ml2IconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ml2IconSpace',		
  			[		
  				'label' => esc_html__( 'Icon Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i,{{WRAPPER}} .ec-marketing-link svg' => 'margin-right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ml2TextTypography',
				'selector' => '{{WRAPPER}} .ec-marketing-link',				
			]
		);
		$this->add_control(
			'ml2Color1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ml2Color2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link,
					{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link:before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link:after,
					{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link span:before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link span:after' => 'background: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link:hover,
					{{WRAPPER}} .ec-marketing-link-wrapper.style2 .ec-marketing-link span:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'ml3Styling',
            [
                'label' => esc_html__('Marketing Link', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'mlStyle' => 'style3',
				],
            ]
        );
		$this->add_responsive_control(
			'ml3Padding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper .ec-marketing-link span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ml3Align',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .ec-marketing-link-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'ml3IconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ml3IconSpace',		
  			[		
  				'label' => esc_html__( 'Icon Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i,{{WRAPPER}} .ec-marketing-link svg' => 'margin-right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ml3TextTypography',
				'selector' => '{{WRAPPER}} .ec-marketing-link',				
			]
		);
		$this->add_control(
			'ml3Color1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style3 .ec-marketing-link' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ml3Color2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style3 .ec-marketing-link,
					{{WRAPPER}} .ec-marketing-link-wrapper.style3 .ec-marketing-link:before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style3 .ec-marketing-link:after' => 'background: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style3 .ec-marketing-link:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'ml4Styling',
            [
                'label' => esc_html__('Marketing Link', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'mlStyle' => 'style4',
				],
            ]
        );
		$this->add_responsive_control(
			'ml4Padding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper .ec-marketing-link span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ml4Align',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .ec-marketing-link-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'ml4IconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ml4IconSpace',		
  			[		
  				'label' => esc_html__( 'Icon Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i,{{WRAPPER}} .ec-marketing-link svg' => 'margin-right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ml4TextTypography',
				'selector' => '{{WRAPPER}} .ec-marketing-link',				
			]
		);
		$this->add_control(
			'ml4Color1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ml4Color2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link' => 'background: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link span:before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link span:after,
					{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link:hover:before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style4 .ec-marketing-link:hover:after' => 'box-shadow: 0 0 20px 0px {{VALUE}}, 0 0 5px 0px {{VALUE}}, 0 0 20px 0px {{VALUE}}, 0 0 5px 0px {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'ml5Styling',
            [
                'label' => esc_html__('Marketing Link', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'mlStyle' => 'style5',
				],
            ]
        );
		$this->add_responsive_control(
			'ml5Padding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper .ec-marketing-link span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ml5Align',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .ec-marketing-link-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'ml5IconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ml5IconSpace',		
  			[		
  				'label' => esc_html__( 'Icon Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i,{{WRAPPER}} .ec-marketing-link svg' => 'margin-right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ml5TextTypography',
				'selector' => '{{WRAPPER}} .ec-marketing-link',				
			]
		);
		$this->add_control(
			'ml5Color1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style5 .ec-marketing-link:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ml5Color2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [					
					'{{WRAPPER}} .ec-marketing-link-wrapper.style5 .ec-marketing-link' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style5 .ec-marketing-link::before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style5 .ec-marketing-link:hover::before' => 'background:{{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style5 .ec-marketing-link,
					{{WRAPPER}} .ec-marketing-link-wrapper.style5 .ec-marketing-link:hover' => 'border-color:{{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'ml5BrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-marketing-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'ml6Styling',
            [
                'label' => esc_html__('Marketing Link', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'mlStyle' => 'style6',
				],
            ]
        );
		$this->add_responsive_control(
			'ml6Padding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper .ec-marketing-link span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ml6Align',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .ec-marketing-link-wrapper' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'ml6IconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ec-marketing-link svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ml6IconSpace',		
  			[		
  				'label' => esc_html__( 'Icon Space', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link i,{{WRAPPER}} .ec-marketing-link svg' => 'margin-right:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ml6TextTypography',
				'selector' => '{{WRAPPER}} .ec-marketing-link',				
			]
		);
		$this->add_responsive_control(
  			'ml6TxtAdj',		
  			[		
  				'label' => esc_html__( 'Text Adjust', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 250,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::before' => 'padding-top:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'ml6Color1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::after' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ml6Color2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::before,
					{{WRAPPER}} .ec-marketing-link-wrapper.style6 .ec-marketing-link::after' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'ml6BrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-marketing-link' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->end_controls_section();
		/*style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$mLMainLink =!empty($settings["mLMainLink"]["url"]) ? $settings["mLMainLink"]["url"] : '';
		$mLMainText =!empty($settings["mLMainText"]) ? $settings["mLMainText"] : '';
		$mLLinkLabel =!empty($settings["mLLinkLabel"]) ? $settings["mLLinkLabel"] : '#';
		$mlType =!empty($settings["mlType"]) ? $settings["mlType"] : 'default';
		$mlTypeD =!empty($settings["mlTypeD"]["url"]) ? $settings["mlTypeD"]["url"] : '';
		
		$mLMainIcon='';
		if(!empty($settings['mLMainIcon'])){
			ob_start();
			\Elementor\Icons_Manager::render_icon( $settings['mLMainIcon'] , [ 'aria-hidden' => 'true' ]);
			$mLMainIcon = ob_get_contents();
			ob_end_clean();	
		}
		
		$data_attr = [];
		$class='';
		if($mlType=='default'){
			$data_attr[] = $mlTypeD;
			$class = ' ml-default';
		}else if($mlType=='mbp'){
			foreach($settings["mLLinkList"] as $item) {
				$mLLinkIn = !empty($item["mLLink"]["url"]) ? $item["mLLink"]["url"] : '';
				$data_attr[]= $mLLinkIn;
				$class = ' ml-mbp';
			}
		}
		
		
		$mLLinkMain = !empty($settings["mLMainLink"]["url"]) ? $settings["mLMainLink"]["url"] : '';
		
		$data_attr[]= $mLLinkMain;
		
		$data_attr = json_encode($data_attr);
		
		$mlStyle = !empty($settings['mlStyle']) ? $settings['mlStyle'] : 'style1';
		
		$output = '<div class="ec-marketing-link-wrapper '.esc_attr($mlStyle).'">';
			$output .= '<a class="ec-marketing-link '.esc_attr($class).'" href="'.esc_attr($mLLinkLabel).'" data-settings=\''.$data_attr .'\'>';
				if(!empty($mlStyle) && ($mlStyle=='style2' || $mlStyle=='style3' || $mlStyle=='style4' || $mlStyle=='style6')){
					$output .='<span>';
				}
				
				$output .= $mLMainIcon.esc_attr($mLMainText);
				
				if(!empty($mlStyle) && ($mlStyle=='style2' || $mlStyle=='style3' || $mlStyle=='style4' || $mlStyle=='style6')){
					$output .='</span>';
				}
			$output .= '</a>';
		$output .= '</div>';
		
		echo wp_kses_normalize_entities($output);
		
	}
}