<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Metabox_Datetime extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-metabox-datetime';
	}

    public function get_title() {
        return esc_html__('Meta Box : Datetime', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-metabox-icon';
    }

    public function get_categories() {
        return array('ecmetabox');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-meta-general' ];
    }
	
	public function get_keywords() {
		return [ 'meta box','metabox','date time','date','time','metabox date time' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Meta Box : Datetime', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'metaboxDateTime',
			[
				'label' => esc_html__( 'Date Time Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Date Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'metaboxDateFormate',
			[
				'label' => esc_html__( 'Date Format', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Format', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'metaDateTimeStyling',
            [
                'label' => esc_html__('Meta Date/Time', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'metaDateTimeTypography',
				'selector' => '{{WRAPPER}} .eca-metabox-datetime',				
			]
		);
		$this->add_responsive_control(
			'metaDateTimeAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-metabox-datetime' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsmetaDateTimeStyle' );
		$this->start_controls_tab(
			'tabmetaDateTimeNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaDateTimeColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-metabox-datetime' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabmetaDateTimeHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaDateTimeColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-metabox-datetime:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('RWMB_VER') ) {
			$metaboxDateTime = !empty($settings['metaboxDateTime']) ? $settings['metaboxDateTime'] : '';
			
			if(!empty($metaboxDateTime)){
				echo '<div class="eca-metabox-datetime">';
					$metaboxDateFormate = !empty($settings['metaboxDateFormate']) ? $settings['metaboxDateFormate'] : '';
					if(!empty($metaboxDateFormate)){
						$unixtimestamp = strtotime( rwmb_meta($metaboxDateTime) );
						echo date_i18n( $metaboxDateFormate, $unixtimestamp );
					}else{
						echo rwmb_meta($metaboxDateTime);
					}
				echo '</div>';
			}
		}		
	}
}