<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Metabox_Email extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-metabox-email';
	}

    public function get_title() {
        return esc_html__('Meta Box : Email', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-metabox-icon';
    }

    public function get_categories() {
        return array('ecmetabox');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-meta-general' ];
    }
	
	public function get_keywords() {
		return [ 'meta box','metabox','email','metabox email' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Meta Box : Email', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'metaboxEmail',
			[
				'label' => esc_html__( 'Email Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'metaboxTextType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'static',
				'options' => [
					'static'  => esc_html__( 'Static', 'essential-classy-addons-for-elementor' ),
					'dynamic' => esc_html__( 'Dynamic', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'metaboxTextStatic',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'metaboxTextType' => 'static'
				]
			]
		);
		$this->add_control(
			'metaboxTextDynamic',
			[
				'label' => esc_html__( 'Text Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'metaboxTextType' => 'dynamic'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'metaEmailStyling',
            [
                'label' => esc_html__('Meta Email', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'metaEmailTypography',
				'selector' => '{{WRAPPER}} .eca-metabox-email',				
			]
		);
		$this->add_responsive_control(
			'metaEmailAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-metabox-email' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsmetaEmailStyle' );
		$this->start_controls_tab(
			'tabmetaEmailNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaEmailColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-metabox-email' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabmetaEmailHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaEmailColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-metabox-email:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('RWMB_VER') ) {
			if(!empty($settings['metaboxEmail'])){
				echo '<a class="eca-metabox-email" href="mailto:';
					echo rwmb_meta($settings['metaboxEmail']);
				echo '">';
					$metaboxTextType = !empty($settings['metaboxTextType']) ? $settings['metaboxTextType'] : 'static';
					$metaboxTextStatic = !empty($settings['metaboxTextStatic']) ? $settings['metaboxTextStatic'] : '';
					$metaboxTextDynamic = !empty($settings['metaboxTextDynamic']) ? $settings['metaboxTextDynamic'] : '';
					
					if(!empty($metaboxTextType) && $metaboxTextType=='static' && !empty($metaboxTextStatic)){
						echo $metaboxTextStatic;
					}else if(!empty($metaboxTextType) && $metaboxTextType=='dynamic' && !empty($metaboxTextDynamic)){
						echo rwmb_meta($metaboxTextDynamic);
					}else if((!empty($metaboxTextType) && $metaboxTextType=='static') || (!empty($metaboxTextType) && $metaboxTextType=='dynamic') || (!empty($metaboxTextDynamic) || !empty($metaboxTextStatic))){
						echo rwmb_meta($settings['metaboxEmail']);
					}					
				echo '</a>';
			}
		}		
	}
}