<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Metabox_Text extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-metabox-text';
	}

    public function get_title() {
        return esc_html__('Meta Box : Text', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-metabox-icon';
    }

    public function get_categories() {
        return array('ecmetabox');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-meta-general' ];
    }
	
	public function get_keywords() {
		return [ 'meta box','metabox','text','metabox text' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Meta Box : Text', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'metaboxText',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'metaboxTextTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag('a'),
			]
		);
		$this->add_control(
			'metaboxTextLink',
			[
				'label' => esc_html__( 'URL Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'metaboxTextTag' => 'a'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'metaTextStyling',
            [
                'label' => esc_html__('Meta Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'metaTextTypography',
				'selector' => '{{WRAPPER}} .ec-metabox-text-wrapper .eca-metaboxtext',				
			]
		);
		$this->add_responsive_control(
			'metaTextAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-metabox-text-wrapper .eca-metaboxtext' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsmetaTextStyle' );
		$this->start_controls_tab(
			'tabmetaTextNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaTextColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-metabox-text-wrapper .eca-metaboxtext' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabmetaTextHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaTextColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-metabox-text-wrapper .eca-metaboxtext:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('RWMB_VER') ) {
			$metaboxText = !empty($settings['metaboxText']) ? $settings['metaboxText'] : '';
			if($metaboxText){
				echo '<div class="ec-metabox-text-wrapper">';				
					$metaboxTextTag= !empty($settings['metaboxTextTag']) ? $settings['metaboxTextTag'] : 'h1';
					if($metaboxTextTag=='a'){
						if(!empty($settings['metaboxTextLink'])){							
							echo '<'.\EcafeHelper::check_and_validate_html_tag($metaboxTextTag).' class="eca-metaboxtext" href=';
								echo rwmb_meta($settings['metaboxTextLink']);
							echo '>';
									echo rwmb_meta( $metaboxText );
							echo '</'.\EcafeHelper::check_and_validate_html_tag($metaboxTextTag).'>';
						}
					}else{
						echo '<'.\EcafeHelper::check_and_validate_html_tag($metaboxTextTag).' class="eca-metaboxtext">';
						echo rwmb_meta( $metaboxText );
						echo '</'.\EcafeHelper::check_and_validate_html_tag($metaboxTextTag).'>';
					}				
				echo '</div>';
			}
		}		
	}
}