<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Metabox_Textarea extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-metabox-textarea';
	}

    public function get_title() {
        return esc_html__('Meta Box : Text Area', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-metabox-icon';
    }

    public function get_categories() {
        return array('ecmetabox');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-meta-general' ];
    }
	
	public function get_keywords() {
		return [ 'meta box','metabox','textarea','text area','metabox text area','metabox textarea' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Meta Box : Text Area', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'metaboxTextarea',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'metaTextAreaStyling',
            [
                'label' => esc_html__('Acf Textarea', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'metaTextAreaTypography',
				'selector' => '{{WRAPPER}} .ec-metabox-textarea-wrapper,{{WRAPPER}} .ec-metabox-textarea-wrapper p',				
			]
		);
		$this->add_responsive_control(
			'metaTextAreaAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-metabox-textarea-wrapper,{{WRAPPER}} .ec-metabox-textarea-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabsmetaTextAreaStyle' );
		$this->start_controls_tab(
			'tabmetaTextAreaNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaTextAreaColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-metabox-textarea-wrapper,{{WRAPPER}} .ec-metabox-textarea-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabmetaTextAreaHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'metaTextAreaColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-metabox-textarea-wrapper:hover,{{WRAPPER}} .ec-metabox-textarea-wrapper:hover p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('RWMB_VER') ) {
			$metaboxTextarea = !empty($settings['metaboxTextarea']) ? $settings['metaboxTextarea'] : '';
			if($metaboxTextarea){
				echo '<div class="ec-metabox-textarea-wrapper">';
					echo rwmb_meta( $metaboxTextarea );
				echo '</div>';
			}
		}		
	}
}