<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Pods_Datetime extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-pods-date-time';
	}

    public function get_title() {
        return esc_html__('Pods : Date / Time', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-pods-icon';
    }

    public function get_categories() {
        return array('ecpods');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-pods-general' ];
    }
	
	public function get_keywords() {
		return [ 'pods', 'pods date time','date','time','date time' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Pods : Date / Time', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'podsDateTime',
			[
				'label' => esc_html__( 'Date Time Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Date Filed Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'podsDateFormate',
			[
				'label' => esc_html__( 'Date Format', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Format', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'podsDateTimeStyling',
            [
                'label' => esc_html__('Pods Date/Time', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'podsDateTimeTypography',
				'selector' => '{{WRAPPER}} .eca-pods-datetime',				
			]
		);
		$this->add_responsive_control(
			'podsDateTimeAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-pods-datetime' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabspodsDateTimeStyle' );
		$this->start_controls_tab(
			'tabpodsDateTimeNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'podsDateTimeColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-pods-datetime' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabpodsDateTimeHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'podsDateTimeColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-pods-datetime:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('PODS_VERSION') ) {
			$podsDateTime = !empty($settings['podsDateTime']) ? $settings['podsDateTime'] : '';
			
			if(!empty($podsDateTime)){
				echo '<div class="eca-pods-datetime">';
					$podsDateFormate = !empty($settings['podsDateFormate']) ? $settings['podsDateFormate'] : '';
					if(!empty($podsDateFormate)){
						$unixtimestamp = strtotime( pods_field_display( $podsDateTime ) );
						echo date_i18n( $podsDateFormate, $unixtimestamp );
					}else{
						echo pods_field_display( $podsDateTime );
					}
				echo '</div>';
			}
		}
	}
}