<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Pods_Plaintext extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-pods-plaintext';
	}

    public function get_title() {
        return esc_html__('Pods : Plain Text', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-pods-icon';
    }

    public function get_categories() {
        return array('ecpods');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-pods-general' ];
    }
	
	public function get_keywords() {
		return [ 'pods', 'pods plain text','plain text','plaintext','text' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Pods : Plain Text', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'podsPlainText',
			[
				'label' => esc_html__( 'Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Filed Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'podsPlainTextTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag('a'),
			]
		);
		$this->add_control(
			'podsPlainTextLink',
			[
				'label' => esc_html__( 'URL Field Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'podsPlainTextTag' => 'a'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'podsTextStyling',
            [
                'label' => esc_html__('Pods Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'podsTextTypography',
				'selector' => '{{WRAPPER}} .ec-pods-plaintext-wrapper .eca-podsplaintext',				
			]
		);
		$this->add_responsive_control(
			'podsTextAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-pods-plaintext-wrapper .eca-podsplaintext' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabspodsTextStyle' );
		$this->start_controls_tab(
			'tabpodsTextNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'podsTextColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-pods-plaintext-wrapper .eca-podsplaintext' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabpodsTextHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'podsTextColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-pods-plaintext-wrapper .eca-podsplaintext:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('PODS_VERSION') ) {
			$podsPlainText = !empty($settings['podsPlainText']) ? $settings['podsPlainText'] : '';
			if($podsPlainText){
				echo '<div class="ec-pods-plaintext-wrapper">';				
					$podsPlainTextTag= !empty($settings['podsPlainTextTag']) ? $settings['podsPlainTextTag'] : 'h1';
					if($podsPlainTextTag=='a'){
						if(!empty($settings['podsPlainTextLink'])){							
							echo '<'.\EcafeHelper::check_and_validate_html_tag($podsPlainTextTag).' class="eca-podsplaintext" href=';
								echo pods_field_display( $settings['podsPlainTextLink']);
							echo '>';
									echo pods_field_display( $podsPlainText );
							echo '</'.\EcafeHelper::check_and_validate_html_tag($podsPlainTextTag).'>';
						}
					}else{
						echo '<'.\EcafeHelper::check_and_validate_html_tag($podsPlainTextTag).' class="eca-podsplaintext">';
						echo pods_field_display( $podsPlainText );
						echo '</'.\EcafeHelper::check_and_validate_html_tag($podsPlainTextTag).'>';
					}				
				echo '</div>';
			}
		}
	}
}