<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Service_Lists extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-service-lists';
	}

    public function get_title() {
        return esc_html__('Service Lists', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-service-lists';
    }

    public function get_categories() {
        return array('essential');
    }
	
	
	public function get_keywords() {
		return [ 'service lists' ];
	}
	
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-service-lists' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-service-lists' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Service Lists', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'slTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Title' , 'essential-classy-addons-for-elementor' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'slTitleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'div',
				'options' => \EcafeHelper::getHtmlTag('a'),
			]
		);
		$this->add_control(
			'slTitleTagLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
				'condition' => [
					'slTitleTag' => 'a'
				]
			]
		);
		$this->add_control(
			'slContent',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'show_label' => false,
				'dynamic' => [
					'active'   => true,
				],
			]
		);
		$this->add_control(
			'slIconImage',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'icon'  => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
					'image' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'slIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-plus',
					'library' => 'solid',
				],
				'condition' => [
					'slIconImage' => 'icon',
				],
			]
		);
		$this->add_control(
			'slImage',
			[
				'label' => esc_html__( 'Image', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'slIconImage' => 'image',
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'slTitle',
			[
				'label' => esc_html__( 'List Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'List' , 'essential-classy-addons-for-elementor' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'slTitleLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'slItems',
			[
				'label' => '',
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'slTitle' => esc_html__( 'List #1', 'essential-classy-addons-for-elementor' ),						
					],
					[
						'slTitle' => esc_html__( 'List #2', 'essential-classy-addons-for-elementor' ),
					],
					[
						'slTitle' => esc_html__( 'List #3', 'essential-classy-addons-for-elementor' ),
					],
				],
				'title_field' => '{{{ slTitle }}}',
			]
		);
		$this->end_controls_section();
		
		/*icon image style start*/
		$this->start_controls_section(
            'sectionIconImageStyling',
            [
                'label' => esc_html__('Icon/Image', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'iiIconHeading',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
  			'iiIconSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsiiIconStyle' );
		$this->start_controls_tab(
			'tabiiIconN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iiIconColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabiiIconH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iiIconColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-ia-icon-image i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-ia-icon-image svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'iiIconBoxHeading',
			[
				'label' => esc_html__( 'Icon/Image Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
  			'iiIconWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'default' => [
					'unit' => 'px',
					'size' => 100,
				],
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image' => 'width: {{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'iiIconHeight',		
  			[		
  				'label' => esc_html__( 'Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],		
				],
				'default' => [
					'unit' => 'px',
					'size' => 100,
				],
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image' => 'height: {{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsiiboxStyle' );
		$this->start_controls_tab(
			'tabiiboxN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iiboxShadow',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iiboxBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iiboxBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image',
			]
		);
		$this->add_responsive_control(
			'iiboxBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-ia-icon-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);		
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabhiiboxH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iiboxShadowH',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-ia-icon-image',
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iiboxBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-ia-icon-image',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iiboxBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-ia-icon-image',
			]
		);
		$this->add_responsive_control(
			'iiboxBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-ia-icon-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);		
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon image style end*/
		
		/*title style start*/
		$this->start_controls_section(
            'sectionTitleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iitPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iitMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'iitTypography',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title',				
			]
		);
		$this->start_controls_tabs( 'tabsiitStyle' );
		$this->start_controls_tab(
			'tabiitN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iitColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iitBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iitBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title',
			]
		);
		$this->add_responsive_control(
			'iitBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iitShadow',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'iitTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-title',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabiitH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iitColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iitBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iitBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-title',
			]
		);
		$this->add_responsive_control(
			'iitBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iitShadowH',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'iitTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-title',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*title style end*/
		
		/*content style start*/
		$this->start_controls_section(
            'sectionContentStyling',
            [
                'label' => esc_html__('Content', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'iicPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iicMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'iicTypography',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents,
				{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents p',				
			]
		);
		$this->start_controls_tabs( 'tabsiicStyle' );
		$this->start_controls_tab(
			'tabiicN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iicColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iicBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iicBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents',
			]
		);
		$this->add_responsive_control(
			'iicBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iicShadow',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'iicTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-contents',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabiicH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iicColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-contents' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iicBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-contents',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iicBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-contents',
			]
		);
		$this->add_responsive_control(
			'iicBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-contents' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iicShadowH',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-contents',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'iicTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover .eca-service-lists-contents',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*content style end*/
		
		/*seprator style start*/
		$this->start_controls_section(
            'sectionSepratorStyling',
            [
                'label' => esc_html__('Seprator Line', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'sepColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-icon-image:after' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
  			'sepWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],
				'range' => [		
					'px' => [		
						'min' => 0,		
						'max' => 10,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-service-lists-wrapper .eca-service-lists-icon-image:after' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->end_controls_section();
		/*seprator style end*/
		
		/*listdots style start*/
		$this->start_controls_section(
            'sectionListDotsStyling',
            [
                'label' => esc_html__('List Dots', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );		
		$this->add_responsive_control(
  			'ListDotsLeft',		
  			[		
  				'label' => esc_html__( 'Left Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => -500,		
						'max' => 500,
					],
					'%' => [		
						'min' => -100,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:before' => 'left:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ListDotsWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:before' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ListDotsHeight',		
  			[		
  				'label' => esc_html__( 'Height', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 300,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:before' => 'height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsListDotsStyle' );
		$this->start_controls_tab(
			'tabListDotsN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_responsive_control(
			'ldBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'ldShadow',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:before',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabListDotsH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_responsive_control(
			'ldBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'ldShadowH',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover:before',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*listdots style end*/
		
		/*list style start*/
		$this->start_controls_section(
            'sectionListStyling',
            [
                'label' => esc_html__('List', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'listpadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'listGap',		
  			[		
  				'label' => esc_html__( 'Gap', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 100,
					],		
				],
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:not(:last-child)' => 'margin-bottom:{{SIZE}}{{UNIT}};',	
				],		
  			]		
  		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'listTypography',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list,
				{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list a',				
			]
		);
		$this->start_controls_tabs( 'tabsiilistStyle' );
		$this->start_controls_tab(
			'tabiilistN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iilistColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list,
				{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iilistBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iilistBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list',
			]
		);
		$this->add_responsive_control(
			'iilistBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iilistShadow',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'iilistTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list,
				{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list a',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabiilistH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iilistColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover,
				{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iilistBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iilistBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover',
			]
		);
		$this->add_responsive_control(
			'iilistBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iilistShadowH',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'iilistTextShadowH',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover,
				{{WRAPPER}} .eca-service-lists-wrapper li.eca-service-lists-list:hover a',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*list style end*/
		
		/*list box style start*/
		$this->start_controls_section(
            'sectionListBoxStyling',
            [
                'label' => esc_html__('List Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'ListBoxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper ul.eca-service-lists-lists' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->end_controls_section();
		/*list box style end*/
		
		/*box style start*/
		$this->start_controls_section(
            'sectionBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'boxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'boxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-service-lists-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsBoxtyle' );
		$this->start_controls_tab(
			'tabBoxNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper',
			]
		);
		$this->add_responsive_control(
			'boxBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowNorm',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabBoxHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-service-lists-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'boxBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-service-lists-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowHover',
				'selector' => '{{WRAPPER}} .eca-service-lists-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*box style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$slTitle = !empty($settings['slTitle']) ? $settings['slTitle'] : '';
		$slTitleTag = !empty($settings['slTitleTag']) ? $settings['slTitleTag'] : 'div';
		$slContent = !empty($settings['slContent']) ? '<div class="eca-service-lists-contents">'.$settings['slContent'].'</div>' : '';
		$slIconImage = !empty($settings['slIconImage']) ? $settings['slIconImage'] : 'icon';
		
		$sl_icon = '';
		if($slIconImage){
			if( !empty($settings['slIcon']) && $slIconImage=='icon'){
				ob_start();
				\Elementor\Icons_Manager::render_icon( $settings['slIcon'], [ 'aria-hidden' => 'true' ]);
				$icons_loop = ob_get_contents();
				ob_end_clean();
				
				if(!empty($icons_loop)){
					$sl_icon .= '<div class="eca-service-lists-icon-image"><span class="eca-ia-icon-image icon">'.$icons_loop.'</span></div>';
				}
			}

			if( !empty($settings['slImage']['id']) && $slIconImage=='image'){
				$image_id=$settings['slImage']['id'];
				$image_src=wp_get_attachment_image_src($image_id, 'full');
				
				$sl_icon .='<div class="eca-service-lists-icon-image"><img src="'.$image_src[0].'" class="eca-ia-icon-image image"></div>';
			}
		}

		$sl_title='';
		if(!empty($slTitle)){
			if($slTitleTag=='a' && !empty( $settings['slTitleTagLink']['url'] )){				
				$this->add_link_attributes( 'slTitleTagLink', $settings['slTitleTagLink'] );
				$this->add_render_attribute( 'slTitleTagLink', 'class', 'eca-service-lists-title' );
				
				$sl_title = '<'.\EcafeHelper::check_and_validate_html_tag($slTitleTag).' '.$this->get_render_attribute_string( "slTitleTagLink" ).'>'.esc_html($slTitle).'</'.\EcafeHelper::check_and_validate_html_tag($slTitleTag).'>';
			}else{
				$sl_title = '<'.\EcafeHelper::check_and_validate_html_tag($slTitleTag).' class="eca-service-lists-title">'.esc_html($slTitle).'</'.\EcafeHelper::check_and_validate_html_tag($slTitleTag).'>';
			}			
		}
		$output = '<div class="eca-service-lists-wrapper">';
			$output .= $sl_icon;
			$output .='<div class="eca-service-lists-content">';
				if($sl_title || $slContent){
					$output .= '<div class="eca-service-lists-title-desc">';
				}
					$output .= $sl_title;
					$output .= $slContent;
					
				if($sl_title || $slContent){
					$output .= '</div>';
				}
	
			if(!empty($settings['slItems'])){
				$output .= '<ul class="eca-service-lists-lists">';
				foreach($settings['slItems'] as $index => $item){
					
					if(!empty($item['slTitleLink']['url'])){
						$output .= '<li class="eca-service-lists-list"><a href="'.$item['slTitleLink']['url'].'" >'.$item['slTitle'].'</a></li>';
					}else{
						$output .= '<li class="eca-service-lists-list">'.$item['slTitle'].'</li>';
					}					
				}
				$output .= '</ul>';
			}
			$output .= '</div>';
		$output .= '</div>';
		echo wp_kses_normalize_entities($output);
	}
}