<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Social_Icons extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-social-icons';
	}

    public function get_title() {
        return esc_html__('Social Icons', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-social-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'social','icons' ];
	}
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-social-icons' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Social Icons', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'socIconLabel',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Label', 'essential-classy-addons-for-elementor' ),
			]
		);
		$repeater->add_control(
			'socIconType',
			[
				'label' => esc_html__( 'Type', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),
					'tel'  => esc_html__( 'Tel', 'essential-classy-addons-for-elementor' ),
					'mail'  => esc_html__( 'Mail', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$repeater->add_control(
			'socIconIcon',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fab fa-wordpress',
					'library' => 'fa-brands',
				],
				'recommended' => [
					'fa-brands' => [
						'android',
						'apple',
						'behance',
						'bitbucket',
						'codepen',
						'delicious',
						'deviantart',
						'digg',
						'dribbble',
						'elementor',
						'facebook',
						'flickr',
						'foursquare',
						'free-code-camp',
						'github',
						'gitlab',
						'globe',
						'houzz',
						'instagram',
						'jsfiddle',
						'linkedin',
						'medium',
						'meetup',
						'mix',
						'mixcloud',
						'odnoklassniki',
						'pinterest',
						'product-hunt',
						'reddit',
						'shopping-cart',
						'skype',
						'slideshare',
						'snapchat',
						'soundcloud',
						'spotify',
						'stack-overflow',
						'steam',
						'telegram',
						'thumb-tack',
						'tripadvisor',
						'tumblr',
						'twitch',
						'twitter',
						'viber',
						'vimeo',
						'vk',
						'weibo',
						'weixin',
						'whatsapp',
						'wordpress',
						'xing',
						'yelp',
						'youtube',
						'500px',
					],
				],
			]
		);
		$repeater->add_control(
			'socIconLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'essential-classy-addons-for-elementor' ),
				'show_external' => true,
				'default' => ['url' => '',],
				'dynamic' => ['active'=> true,],
				'condition' => [
					'socIconType' => 'default',
				],
			]
		);
		$repeater->add_control(
			'socIconTel',
			[
				'label' => __( 'Tel', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'condition' => [
					'socIconType' => 'tel',
				],
			]
		);
		$repeater->add_control(
			'socIconEmail',
			[
				'label' => esc_html__( 'Email', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Email', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'socIconType' => 'mail',
				],
			]
		);
		$repeater->add_control(
			'optionView',
			[
				'label' => esc_html__( 'View', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),
					'custom'  => esc_html__( 'Custom', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$repeater->start_controls_tabs( 'tabsSocIcon' );
		$repeater->start_controls_tab(
			'tabSocIconN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'optionView' => 'custom',
				],
			]
		);
		$repeater->add_control(
			'socIconNormColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li {{CURRENT_ITEM}}' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li {{CURRENT_ITEM}} svg' => 'fill: {{VALUE}};',
				],
				'condition' => [
					'optionView' => 'custom',
				],
			]
		);
		$repeater->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'socIconNormBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-social-icons .eca-social-lists li {{CURRENT_ITEM}}',
				'condition' => [
					'optionView' => 'custom',
				],
			]
		);			
		$repeater->end_controls_tab();
		$repeater->start_controls_tab(
			'tabSocIconHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'optionView' => 'custom',
				],
			]
		);
		$repeater->add_control(
			'socIconColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li {{CURRENT_ITEM}}:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li {{CURRENT_ITEM}}:hover svg' => 'fill: {{VALUE}};',
				],
				'condition' => [
					'optionView' => 'custom',
				],
			]
		);
		$repeater->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'socIconBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-social-icons .eca-social-lists li {{CURRENT_ITEM}}:hover',
				'condition' => [
					'optionView' => 'custom',
				],
			]
		);	
		$repeater->end_controls_tab();
		$repeater->end_controls_tabs();
		$this->add_control(
			'socIconList',
			[
				'label' => esc_html__( 'List', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),			
				'default' => [
					[
						'socIconIcon' => [
							'value' => 'fab fa-facebook',
							'library' => 'fa-brands',
						],
						'socIconLabel' => 'Facebook',
					],
					[
						'socIconIcon' => [
							'value' => 'fab fa-twitter',
							'library' => 'fa-brands',
						],
						'socIconLabel' => 'Twitter',
					],
					[
						'socIconIcon' => [
							'value' => 'fab fa-linkedin',
							'library' => 'fa-brands',
						],
						'socIconLabel' => 'Linkedin',
					],
				],
				'title_field' => '{{{ socIconLabel }}}',
			]
		);
		$this->add_responsive_control(
			'contentAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'space-around' => [
						'title' => esc_html__( 'Space Around', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
					'space-between' => [
						'title' => esc_html__( 'Space Between', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'separator' => 'before',
				'default' => 'flex-start',
				'selectors' => [
                    '{{WRAPPER}} .eca-social-icons .eca-social-lists' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->end_controls_section();
		
		/*style start*/
		$this->start_controls_section(
            'sectionStyling',
            [
                'label' => esc_html__('Social Icons', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'socialPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'socialMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'sIconSize',		
  			[		
  				'label' => esc_html__( 'Icon Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 200,
					],		
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a i:before' => 'font-size :{{SIZE}}px;',
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a svg' => 'width:{{SIZE}}px;height:{{SIZE}}px;',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsSocialtyle' );
		$this->start_controls_tab(
			'tabSocialN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'socialColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'socialBackgroundN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-social-icons .eca-social-lists li a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'socialBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-social-icons .eca-social-lists li a',
			]
		);
		$this->add_responsive_control(
			'socialBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'socialShadowN',
				'selector' => '{{WRAPPER}} .eca-social-icons .eca-social-lists li a',
			]
		);
		$this->add_control(
			'socialTransitionN',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'socialTransformN',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabSocialH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'socialColorh',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'socialBackgroundH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'socialBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover',
			]
		);
		$this->add_responsive_control(
			'socialBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'socialShadowH',
				'selector' => '{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover',
			]
		);
		$this->add_control(
			'socialTransitionH',
			[
				'label' => esc_html__( 'Transition css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'all .3s linear', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover' => 'transition:{{VALUE}};'
				],	
			]
		);
		$this->add_control(
			'socialTransformH',
			[
				'label' => esc_html__( 'Transform css', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'placeholder' => esc_html__( 'skew(-20deg)', 'essential-classy-addons-for-elementor' ),
				'selectors' => [
					'{{WRAPPER}} .eca-social-icons .eca-social-lists li a:hover' => 'transform: {{VALUE}};-ms-transform: {{VALUE}};-moz-transform: {{VALUE}};-webkit-transform: {{VALUE}};'
				],	
			]
		);		
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		
		$socIconIcon=$socialIconClass='';
		
		$output ='<div class="eca-social-icons">';
			$output .='<ul class="eca-social-lists">';
				foreach($settings["socIconList"] as $item) {				
					if(!empty($item['socIconIcon'])){
						ob_start();
						\Elementor\Icons_Manager::render_icon( $item['socIconIcon'] , [ 'aria-hidden' => 'true' ]);
						$socIconIcon = ob_get_contents();
						ob_end_clean();
						
						$socialIconClass = explode( ' ', $item['socIconIcon']['value'], 2 );
						$socialIconClass = str_replace( 'fa-', '', $socialIconClass[1] );						
					}				
					
					$socIconType=!empty($item["socIconType"]) ? $item["socIconType"] : 'default';
					$socIconLink=!empty($item["socIconLink"]["url"]) ? $item["socIconLink"]["url"] : '';
					$socIconTel=!empty($item["socIconTel"]) ? $item["socIconTel"] : '';
					$socIconEmail=!empty($item["socIconEmail"]) ? $item["socIconEmail"] : '';
					
					$socIconSrc=$socIconLinkTarget=$socIconLinkNoFollow='';
					if($socIconType=='default' && !empty($socIconLink)){							
						$socIconLinkTarget = $item['socIconLink']['is_external'] ? ' target="_blank"' : '';
						$socIconLinkNoFollow = $item['socIconLink']['nofollow'] ? ' rel="nofollow"' : '';
						$socIconSrc = $socIconLink;
					}else if($socIconType=='tel' && !empty($socIconTel)){
						$socIconSrc = 'tel:'.$socIconTel;
					}else if($socIconType=='mail'&& !empty($socIconEmail)){
						$socIconSrc = 'mailto:'.$socIconEmail;
					}
					
					$output .='<li class="eca-social-list">';
						$output .='<a class="elementor-repeater-item-'.$item['_id'].' eca-si-'.esc_attr($socialIconClass).'"
								href="'.esc_url($socIconSrc).'" '.esc_attr($socIconLinkTarget).esc_attr($socIconLinkNoFollow).'>
								'.$socIconIcon.'
								</a>';
					$output .='</li>';
				}
			$output .='</ul>';
		$output .='</div>';
		
		echo wp_kses_normalize_entities($output);
		
	}
}