<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Tabs extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-tabs';
	}

    public function get_title() {
        return esc_html__('Tabs', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-tabs-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'tabs','tours' ];
	}
	public function get_style_depends() {
		return [ 'font-awesome-5-all','ecafe-tabs' ];
    }
	
	public function get_script_depends() {
		return [ 'ecafe-tabs' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'tabType',
			[
				'label' => __( 'Position', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'horizontal',
				'options' => [
					'horizontal' => __( 'Horizontal', 'essential-classy-addons-for-elementor' ),
					'vertical' => __( 'Vertical', 'essential-classy-addons-for-elementor' ),
				],
			]
		);

		$this->add_control(
			'tabHorizontal',
			[
				'label' => __( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'' => [
						'title' => __( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'end' => [
						'title' => __( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-right',
					],
					'stretch' => [
						'title' => __( 'Justified', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'separator' => 'after',
				'condition' => [
					'tabType' => 'horizontal',
				],
			]
		);

		$this->add_control(
			'tabVertical',
			[
				'label' => __( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'' => [
						'title' => __( 'Top', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-v-align-top',
					],
					'center' => [
						'title' => __( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-v-align-middle',
					],
					'end' => [
						'title' => __( 'Bottom', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-v-align-bottom',
					],
					'stretch' => [
						'title' => __( 'Justified', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-v-align-stretch',
					],
				],
				'separator' => 'after',
				'condition' => [
					'tabType' => 'vertical',
				],
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'tabTitle',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'Tab Title' , 'essential-classy-addons-for-elementor' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'tabContentType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'content',
				'options' => [
					'content'  => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
					'page_template' => esc_html__( 'Page Template', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$repeater->add_control(
			'tabContent',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'show_label' => false,
				'dynamic' => [
					'active'   => true,
				],
				'condition'    => [
					'tabContentType' => [ 'content' ],
				],
			]
		);
		$repeater->add_control(
			'tabContentTemplate',
			[
				'label'       => esc_html__( 'Elementor Templates', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '0',
				'options'     => \EcafeHelper::getTemplates(),
				'label_block' => 'true',
				'condition'   => ['tabContentType' => "page_template"],
			]
		);
		
		$repeater->add_control(
			'backendVisible',[
				'label'   => esc_html__( 'Backend Visibility', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),	
				'description' => esc_html__( 'Note : Visible in the backend.', 'essential-classy-addons-for-elementor' ),
				'separator' => 'after',
				'condition'   => ['tabContentType' => "page_template"],
			]
		);
		$repeater->add_control(
			'tabIcon',
			[
				'label' => esc_html__( 'Icon Library', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => '',
					'library' => '',
				],
			]
		);
		$this->add_control(
			'tabsItems',
			[
				'label' => '',
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tabTitle' => esc_html__( 'Tab #1', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus suscipit, velit in venenatis dignissim, risus mi ullamcorper justo, ac porta ante leo tempus enim.', 'essential-classy-addons-for-elementor' ),
					],
					[
						'tabTitle' => esc_html__( 'Tab #2', 'essential-classy-addons-for-elementor' ),
						'tabContent' => esc_html__( 'I am item content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'essential-classy-addons-for-elementor' ),
					],
				],
				'title_field' => '{{{ tabTitle }}}',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'extras_section',
			[
				'label' => esc_html__( 'Extras', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'activeTab',
			[
				'label'       => esc_html__( 'Active Tab', 'essential-classy-addons-for-elementor' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => \EcafeHelper::getNumbers(1),
			]
		);
		$this->add_control(
			'tabOnHover',[
				'label'   => esc_html__( 'On Hover', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'inAccordion',[
				'label'   => esc_html__( 'In Mobile Accordion', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_control(
			'accTitleAlign',
			[
				'label' => __( 'Title Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tab-accordion-title' => 'text-align: {{VALUE}};',
				],
				'condition' => [
					'inAccordion' => 'yes',
				],
			]
		);
		$this->end_controls_section();
		
		/*style start*/
		/*title start*/
		$this->start_controls_section(
            'titleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'titlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'titleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'titleTypo',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title',				
			]
		);
		$this->start_controls_tabs( 'tabsTitletyle' );
		$this->start_controls_tab(
			'tabTitleNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title',
			]
		);
		$this->add_responsive_control(
			'titleBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowNorm',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabTitleHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover',
			]
		);
		$this->add_responsive_control(
			'titleBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowHover',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowHover',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabTitleActive',
			[
				'label' => esc_html__( 'Active', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorActive',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgActive',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderActive',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active',
			]
		);
		$this->add_responsive_control(
			'titleBrActive',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowActive',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowActive',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*title end*/
		
		/*icon start*/
		$this->start_controls_section(
            'iconStyling',
            [
                'label' => esc_html__('Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );		
		$this->add_responsive_control(
			'iconPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iconMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iconSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i' => 'font-size:{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon svg' => 'width:{{SIZE}}{{UNIT}};height:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsIcontyle' );
		$this->start_controls_tab(
			'tabIconNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowNorm',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title .eca-tab-icon i',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover .eca-tab-icon i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover .eca-tab-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover .eca-tab-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover .eca-tab-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover .eca-tab-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowHover',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title:hover .eca-tab-icon i',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconActive',
			[
				'label' => esc_html__( 'Active', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorActive',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active .eca-tab-icon i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active .eca-tab-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgActive',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active .eca-tab-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderActive',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active .eca-tab-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrActive',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active .eca-tab-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowActive',
				'selector' => '{{WRAPPER}} .eca-tabs-title-wrap .eca-tab-title.tab-active .eca-tab-icon i',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon end*/
		
		/*icon-title start*/
		$this->start_controls_section(
            'iconTitleStyling',
            [
                'label' => esc_html__('Icon & Title Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'iconTitlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iconTitleWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .tab-vertical .eca-tabs-title-wrap' => 'width:{{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'tabType' => 'vertical',
				],
  			]		
  		);
		$this->start_controls_tabs( 'tabsIconTitleStyle' );
		$this->start_controls_tab(
			'iconTitleContentNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconTitleBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconTitleBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap',
			]
		);
		$this->add_responsive_control(
			'iconTitleBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconTitleShadowNorm',
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabIconTitleHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconTitleBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconTitleBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap:hover',
			]
		);
		$this->add_responsive_control(
			'iconTitleBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconTitleShadowHover',
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper .eca-tabs-title-wrap:hover',
			]
		);
		$this->end_controls_tab();		
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon-title end*/
		
		/*content start*/
		$this->start_controls_section(
            'contentStyling',
            [
                'label' => esc_html__('Content', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'contentPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'contentMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'contentTypo',
				'selector' => '{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content,
				{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content p',				
			]
		);		
		$this->add_control(
			'contentColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content,
					{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'contentBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'contentBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content',
			]
		);
		$this->add_responsive_control(
			'contentBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'contentShadowNorm',
				'selector' => '{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'contentTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-content-wrap .eca-tab-content',
			]
		);
		$this->end_controls_section();
		/*content end*/
		
		/*mobile title start*/
		$this->start_controls_section(
            'titleMStyling',
            [
                'label' => esc_html__('Mobile Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'inAccordion' => 'yes',
				],
            ]
        );
		$this->add_responsive_control(
			'titleMPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'titleMMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'titleMTypo',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title',				
			]
		);
		$this->start_controls_tabs( 'tabsTitleMtyle' );
		$this->start_controls_tab(
			'tabTitleMNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorMNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgMNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderMNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title',
			]
		);
		$this->add_responsive_control(
			'titleBrMNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowMNorm',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowMNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title',
			]
		);
		$this->end_controls_tab();		
		$this->start_controls_tab(
			'tabTitleMActive',
			[
				'label' => esc_html__( 'Active', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'titleColorMActive',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBgMActive',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorderMActive',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active',
			]
		);
		$this->add_responsive_control(
			'titleBrMActive',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadowMActive',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadowMActive',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*title end*/
		
		/*icon start*/
		$this->start_controls_section(
            'iconMStyling',
            [
                'label' => esc_html__('Mobile Icon', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'inAccordion' => 'yes',
				],
            ]
        );		
		$this->add_responsive_control(
			'iconMPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'iconMMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'iconMSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i' => 'font-size:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsMIcontyle' );
		$this->start_controls_tab(
			'tabIconMNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorMNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgMNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderMNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrMNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowMNorm',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title .eca-tab-icon i',
			]
		);
		$this->end_controls_tab();		
		$this->start_controls_tab(
			'tabIconMActive',
			[
				'label' => esc_html__( 'Active', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'iconColorMActive',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active .eca-tab-icon i' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'iconBgMActive',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active .eca-tab-icon i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iconBorderMActive',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active .eca-tab-icon i',
			]
		);
		$this->add_responsive_control(
			'iconBrMActive',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active .eca-tab-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'iconShadowMActive',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tabs-content-wrap .eca-tab-title.tab-active .eca-tab-icon i',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*icon end*/
		
		/*content start*/
		$this->start_controls_section(
            'contentMStyling',
            [
                'label' => esc_html__('Mobile Content', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition'    => [
					'inAccordion' => 'yes',
				],
            ]
        );
		$this->add_responsive_control(
			'contentMPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tab-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'contentMMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'contentMTypo',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tab-content,
				{{WRAPPER}} .eca-mobile-accordion .eca-tab-content p',				
			]
		);		
		$this->add_control(
			'contentMColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tab-content,
					{{WRAPPER}} .eca-mobile-accordion .eca-tab-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'contentMBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-mobile-accordion .eca-tab-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'contentBorderMNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tab-content',
			]
		);
		$this->add_responsive_control(
			'contentBrMNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-mobile-accordion .eca-tab-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'contentShadowMNorm',
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tab-content',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'contentTextShadowMNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-mobile-accordion .eca-tab-content',
			]
		);
		$this->end_controls_section();
		/*content end*/
		
		/*box start*/
		$this->start_controls_section(
            'boxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'boxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-tabs-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabsBoxtyle' );
		$this->start_controls_tab(
			'tabBoxNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper',
			]
		);
		$this->add_responsive_control(
			'boxBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowNorm',
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabBoxHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-tabs-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'boxBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-tabs-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadowHover',
				'selector' => '{{WRAPPER}} .eca-tabs-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		/*box end*/
		/*style end*/
	}
	
	 protected function render() {
        $settings = $this->get_settings_for_display();
		$uid = uniqid('tab');
		$id_int = substr( $this->get_id_int(), 0, 3 );
		$EleTemplates = \Elementor\Plugin::instance()->templates_manager->get_source( 'local' )->get_items();
		
		$dataAttr  = [
			'data-id' => $uid,
			'type' => (isset($settings['tabOnHover']) && $settings['tabOnHover']=='yes') ? 'hover' : 'click',
			'accordion' => false,
		];
		
		$tabClasses = ($settings['tabType']=='vertical') ? 'tab-vertical' : 'tab-horizontal';
		$tabHorizontal = '';
		if(!empty($settings['tabHorizontal']) && $settings['tabType']=='horizontal'){
			$tabClasses .= ' align-flex-'.$settings['tabHorizontal'];
		}else if(!empty($settings['tabVertical']) && $settings['tabType']=='vertical'){
			$tabClasses .= ' align-flex-'.$settings['tabVertical'];
		}
		
		$accTitleAlign = '';
		if(!empty($settings['inAccordion']) && $settings['inAccordion']=='yes'){
			$dataAttr['accordion'] = true;
			$tabClasses .= ' eca-mobile-accordion';
			$accTitleAlign .= !empty($settings['accTitleAlign']) ? ' text-'.$settings['accTitleAlign'] : '';
		}
		
		$output = '<div class="eca-tabs-wrapper '.esc_attr($uid).' '.esc_attr($tabClasses).'" data-settings=\'' .json_encode($dataAttr) . '\'  role="tablist">';
			$output .= '<div class="eca-tabs-title-wrap" role="tablist">';
				if(!empty($settings['tabsItems'])){
					foreach($settings['tabsItems'] as $index => $item){
						$count = $index + 1;
						$tabs_title_key = $this->get_repeater_setting_key( 'eca_tabs_title', 'tabsItems', $index );
						$active_tab = ($count == $settings['activeTab']) ? ' tab-active' : '';
						
						$this->add_render_attribute( $tabs_title_key, [
							'id' => 'eca-tab-title-' . $id_int . $count,
							'class' => [ 'eca-tab-title', $active_tab ],
							'aria-selected' => 1 === $count ? 'true' : 'false',
							'data-tab' => $count,
							'tabindex' => 1 === $count ? '0' : '-1',
							'aria-controls' => 'eca-tab-content-' . $id_int . $count,
							'aria-expanded' => 'false',
							'role' => 'tab',
						] );
						
						$tab_icon = '';
						if( !empty($item['tabIcon']) ){
							ob_start();
							\Elementor\Icons_Manager::render_icon( $item['tabIcon'], [ 'aria-hidden' => 'true' ]);
							$icons_loop = ob_get_contents();
							ob_end_clean();
							
							if(!empty($icons_loop)){
								$tab_icon .= '<span class="eca-tab-icon">'.$icons_loop.'</span>';
							}
						}
						
						$output .= '<div '.$this->get_render_attribute_string( $tabs_title_key ).'>' . $tab_icon . wp_kses_post($item['tabTitle']) . '</div>';
					}
				}
			$output .= '</div>';
			$output .= '<div class="eca-tabs-content-wrap" role="tablist">';
				if(!empty($settings['tabsItems'])){
					foreach($settings['tabsItems'] as $index => $item){
						$count = $index + 1;
						$active_tab = ($count == $settings['activeTab']) ? ' tab-active' : '';
						
						if(!empty($settings['inAccordion']) && $settings['inAccordion']=='yes'){
							$tabs_title_accordion_key = $this->get_repeater_setting_key( 'eca_tabs_title_accordion', 'tabsItems', $count );
							$this->add_render_attribute( $tabs_title_accordion_key, [
								'class' => [ 'eca-tab-title', 'eca-tab-accordion-title', $active_tab, $accTitleAlign ],
								'aria-selected' => 1 === $count ? 'true' : 'false',
								'data-tab' => $count,
								'tabindex' => 1 === $count ? '0' : '-1',
								'aria-controls' => 'eca-tab-content-' . $id_int . $count,
								'aria-expanded' => 'false',
								'role' => 'tab',
							] );
							$tab_icon = '';
							if( !empty($item['tabIcon']) ){
								ob_start();
								\Elementor\Icons_Manager::render_icon( $item['tabIcon'], [ 'aria-hidden' => 'true' ]);
								$icons_loop = ob_get_contents();
								ob_end_clean();
								
								if(!empty($icons_loop)){
									$tab_icon .= '<span class="eca-tab-icon">'.$icons_loop.'</span>';
								}
							}
							$output .= '<div '.$this->get_render_attribute_string( $tabs_title_accordion_key ).'>'.$tab_icon.wp_kses_post($item['tabTitle']).'</div>';
						}
						
						$tabs_content_key = $this->get_repeater_setting_key( 'eca_tabs_content', 'tabsItems', $index );
						$this->add_render_attribute( $tabs_content_key, [
							'id' => 'eca-tab-content-' . $id_int . $count,
							'class' => [ 'eca-tab-content', $active_tab ],
							'data-tab' => $count,
							'aria-labelledby' => 'eca-tab-title-' . $id_int . $count,
							'tabindex' => '0',
							'role' => 'tabpanel',
						] );
						
						if( $item['tabContentType'] == 'content' && !empty($item['tabContent'])){
							$output .= '<div '.$this->get_render_attribute_string( $tabs_content_key ).'>'.$this->parse_text_editor( $item['tabContent'] ).'</div>';
						}
						
						if(\Elementor\Plugin::$instance->editor->is_edit_mode() && $item["tabContentType"]=='page_template' && !empty($item['tabContentTemplate'])){
							if(!empty($item["backendVisible"]) && $item["backendVisible"]=='yes'){
								$output .= '<div '.$this->get_render_attribute_string( $tabs_content_key ).'>'.\Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $item['tabContentTemplate'] ).'</div>';
							}else{
								$get_template_name = '';
								$get_template_id = $item['tabContentTemplate'];
									if( !empty($EleTemplates) && !empty($get_template_id)){
										foreach( $EleTemplates as $value ){
											if( $value["template_id"] == $get_template_id ){
												$get_template_name=$value["title"];
											}
										}
									}
									
									$output .= '<div class="eca-preview-notice"><div class="eca-preview-notice-heading">'.esc_html__('Selected Template :','essential-classy-addons-for-elementor').' <b>"'.esc_html($get_template_name).'"</b></div><div class="eca-preview-notice-desc"><b>'.esc_html__('Note :','essential-classy-addons-for-elementor').'</b> '.esc_html__('Visibility disable in the backend.','essential-classy-addons-for-elementor').'</div></div>';
							}
						}else if($item["tabContentType"]=='page_template' && !empty($item['tabContentTemplate'])){
							$output .= '<div '.$this->get_render_attribute_string( $tabs_content_key ).'>'.\Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $item['tabContentTemplate'] ).'</div>';
						}
					
					}
				}
			$output .= '</div>';
		$output .= '</div>';
		
		echo wp_kses_normalize_entities($output);
	}
}