<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Title extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-title';
	}

    public function get_title() {
        return esc_html__('Title', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-title-icon';
    }

    public function get_categories() {
        return array('essential');
    }
	
	public function get_keywords() {
		return [ 'title','advanced title' ];
	}
	public function get_style_depends() {
		return [ 'ecafe-title' ];
    }
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'Layout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Simple', 'essential-classy-addons-for-elementor' ),
					'advanced'  => esc_html__( 'Advanced', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'DStyle',
			[
				'label' => esc_html__( 'Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'ds1',
				'options' => [
					'ds1'  => esc_html__( 'Style 1', 'essential-classy-addons-for-elementor' ),
					'ds2'  => esc_html__( 'Style 2', 'essential-classy-addons-for-elementor' ),
					'ds3'  => esc_html__( 'Style 3', 'essential-classy-addons-for-elementor' ),
					'ds4'  => esc_html__( 'Style 4', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'Layout' => 'default'				
				]
			]
		);
		$this->add_control(
			'AStyle',
			[
				'label' => esc_html__( 'Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'as1',
				'options' => [
					'as1'  => esc_html__( 'Style 1', 'essential-classy-addons-for-elementor' ),
					'as2'  => esc_html__( 'Style 2', 'essential-classy-addons-for-elementor' ),
					'as3'  => esc_html__( 'Style 3', 'essential-classy-addons-for-elementor' ),
					'as4'  => esc_html__( 'Style 4', 'essential-classy-addons-for-elementor' ),
					'as5'  => esc_html__( 'Style 5', 'essential-classy-addons-for-elementor' ),
					'as6'  => esc_html__( 'Style 6', 'essential-classy-addons-for-elementor' ),
					'as7'  => esc_html__( 'Style 7', 'essential-classy-addons-for-elementor' ),
					'as8'  => esc_html__( 'Style 8', 'essential-classy-addons-for-elementor' ),
					'as9'  => esc_html__( 'Style 9', 'essential-classy-addons-for-elementor' ),
					'as10'  => esc_html__( 'Style 10', 'essential-classy-addons-for-elementor' ),
					'as11'  => esc_html__( 'Style 11', 'essential-classy-addons-for-elementor' ),
					'as12'  => esc_html__( 'Style 12', 'essential-classy-addons-for-elementor' ),
					'as13'  => esc_html__( 'Style 13', 'essential-classy-addons-for-elementor' ),
					'as14'  => esc_html__( 'Style 14', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'Layout' => 'advanced'				
				]
			]
		);
		$this->add_control(
			'Title',
			[
				'label' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Title', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Title', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'TitleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag('a'),
			]
		);
		$this->add_control(
			'TitleLink',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::URL,
				'dynamic' => ['active' => true,],				
				'placeholder' => esc_html__( '#', 'essential-classy-addons-for-elementor' ),
				'default' => [
					'url' => '#',
				],
				'condition' => [
					'TitleTag' => 'a'
				]
			]
		);
		$this->add_control(
			'SubTitle',
			[
				'label' => esc_html__( 'Sub Title', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => esc_html__( 'Sub Title', 'essential-classy-addons-for-elementor' ),
				'placeholder' => esc_html__( 'Enter Sub Title', 'essential-classy-addons-for-elementor' ),				
				'separator' => 'before',
			]
		);
		$this->add_control(
			'SubTitleTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h3',
				'options' => \EcafeHelper::getHtmlTag(),
			]
		);
		$this->add_responsive_control(
			'contentAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'separator' => 'before',
				'selectors' => [
                    '{{WRAPPER}} .eca-heading-wrapper .eca-heading-wrapper-inner' => 'align-items:{{VALUE}};',
                ],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'extras_section',
			[
				'label' => esc_html__( 'Extras', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
            'Overlay',
            [
				'label'   => esc_html__( 'Overlay Color Effect', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);
		$this->add_control(
			'OverlayColor1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.overlay:before' => 'background: {{VALUE}};',
				],
				'default' => '#8D0801',
				'condition' => [
					'Overlay' => 'yes',					
				]
			]
		);
		$this->add_control(
			'OverlayColor2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.overlay:after' => 'background: {{VALUE}};',
				],
				'default' => '#bf0603',
				'condition' => [
					'Overlay' => 'yes',					
				]
			]
		);		
		$this->end_controls_section();
		
		/*style start*/
		/*title start*/
		$this->start_controls_section(
            'titleStyling',
            [
                'label' => esc_html__('Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'titlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'titleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'titleTypography',
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-title',				
			]
		);
		$this->add_control(
			'titleColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'titleBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'titleBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-title',
			]
		);
		$this->add_responsive_control(
			'titleBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'titleTextShadow',
				'label' => __( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-title',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'titleShadow',
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-title',
			]
		);
		$this->end_controls_section();
		/*title end*/
		
		/*sub title start*/
		$this->start_controls_section(
            'subtitleStyling',
            [
                'label' => esc_html__('Sub Title', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'subtitlePadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'subtitleMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitleTypography',
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title',				
			]
		);
		$this->add_control(
			'subtitleColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'subtitleBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'subtitleBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title',
			]
		);
		$this->add_responsive_control(
			'subtitleBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'subtitleTextShadow',
				'label' => __( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'subtitleShadow',
				'selector' => '{{WRAPPER}} .eca-heading-wrapper .eca-heading-sub-title',
			]
		);
		$this->end_controls_section();
		/*sub title end*/
		
		/*extras start*/
		$this->start_controls_section(
            'extrasStyling',
            [
                'label' => esc_html__('Extras', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'Layout' => 'advanced'				
				]
            ]
        );
		$this->add_control(
			'as12Color',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as1 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as2 .eca-heading-sub-title:before,
					{{WRAPPER}} .eca-heading-wrapper.advanced.as1 .eca-heading-title:after,
					{{WRAPPER}} .eca-heading-wrapper.advanced.as2 .eca-heading-sub-title:after' => 'background: {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as1','as2'],
				]				
			]
		);
		$this->add_control(
			'as34Color',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as3 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as4 .eca-heading-sub-title:before' => 'background: {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as3','as4'],
				]				
			]
		);
		$this->add_control(
			'as56Color',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as5 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as6 .eca-heading-sub-title:before' => 'background: {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as5','as6'],
				]				
			]
		);
		$this->add_control(
			'as78Color1',
			[
				'label' => esc_html__( 'Color 1', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as7 .eca-heading-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as7 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as8 .eca-heading-sub-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as8 .eca-heading-sub-title:before' => 'background: {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as7','as8'],
				]				
			]
		);
		$this->add_control(
			'as78Color2',
			[
				'label' => esc_html__( 'Color 2', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as7 .eca-heading-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as8 .eca-heading-sub-title:after' => 'background: {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as7','as8'],
				]				
			]
		);
		$this->add_control(
			'as910Color',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as9 .eca-heading-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as9 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as10 .eca-heading-sub-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as10 .eca-heading-sub-title:before' => 'border-bottom: 1px solid {{VALUE}};border-top: 1px solid {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as9','as10'],
				]				
			]
		);
		$this->add_control(
			'as1112Color',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as11 .eca-heading-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as11 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as12 .eca-heading-sub-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as12 .eca-heading-sub-title:before' => 'border-bottom: 2px solid {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as11','as12'],
				]				
			]
		);
		$this->add_control(
			'as1314Color',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as13 .eca-heading-title:before, {{WRAPPER}} .eca-heading-wrapper.advanced.as14 .eca-heading-sub-title:before' => 'background: {{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as13','as14'],
				]				
			]
		);
		$this->add_control(
			'as1314IconColor',
			[
				'label' => esc_html__( 'Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper.advanced.as13 .eca-heading-title:after, {{WRAPPER}} .eca-heading-wrapper.advanced.as14 .eca-heading-sub-title:after' => 'color:{{VALUE}};',
				],
				'condition' => [
					'AStyle' => ['as13','as14'],
				]				
			]
		);
		$this->end_controls_section();
		/*extras end*/
		
		/*box start*/
		$this->start_controls_section(
            'boxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'boxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'boxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .eca-heading-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'boxBackground',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .eca-heading-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'boxBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .eca-heading-wrapper',
			]
		);
		$this->add_responsive_control(
			'boxBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .eca-heading-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'boxShadow',
				'selector' => '{{WRAPPER}} .eca-heading-wrapper',
			]
		);
		$this->end_controls_section();
		/*box end*/		
		/*style end*/
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		$Layout= !empty($settings['Layout']) ? $settings['Layout'] : 'default';
		$DStyle= !empty($settings['DStyle']) ? $settings['DStyle'] : 'ds1';
		$AStyle= !empty($settings['AStyle']) ? $settings['AStyle'] : 'as1';
		$Title= !empty($settings['Title']) ? $settings['Title'] : '';
		$TitleTag= !empty($settings['TitleTag']) ? $settings['TitleTag'] : 'h1';
		$SubTitle= !empty($settings['SubTitle']) ? $settings['SubTitle'] : '';
		$SubTitleTag= !empty($settings['SubTitleTag']) ? $settings['SubTitleTag'] : 'h3';
		
		$op=$OPTitle=$OPSubTitle=$Style=$Overlay='';
		if(!empty($Title)){
			if($TitleTag=='a' && !empty( $settings['TitleLink']['url'] )){				
				$this->add_link_attributes( 'titlelink', $settings['TitleLink'] );
				$this->add_render_attribute( 'titlelink', 'class', 'eca-heading-title' );
				
				$OPTitle = '<'.\EcafeHelper::check_and_validate_html_tag($TitleTag).' '.$this->get_render_attribute_string( "titlelink" ).'>'.esc_html($Title).'</'.\EcafeHelper::check_and_validate_html_tag($TitleTag).'>';
			}else{
				$OPTitle = '<'.\EcafeHelper::check_and_validate_html_tag($TitleTag).' class="eca-heading-title">'.esc_html($Title).'</'.\EcafeHelper::check_and_validate_html_tag($TitleTag).'>';
			}			
		}
		if(!empty($SubTitle)){
			$OPSubTitle = '<'.\EcafeHelper::check_and_validate_html_tag($SubTitleTag).' class="eca-heading-sub-title">'.esc_html($SubTitle).'</'.\EcafeHelper::check_and_validate_html_tag($SubTitleTag).'>';
		}
		
		if(!empty($settings['Overlay']) && $settings['Overlay']=='yes'){
			$Overlay = 'overlay';
		}
		if(!empty($Layout)){
			if($Layout=='default'){
				$Style=$DStyle;
			}else if($Layout=='advanced'){
				$Style=$AStyle;
			}
		}		
		
		$op .='<div class="eca-heading-wrapper '.esc_attr($Layout).' '.esc_attr($Style).' '.esc_attr($Overlay).'">';
			$op .='<div class="eca-heading-wrapper-inner">';
				if($Layout){
					if($Layout == 'default'){
						if(!empty($DStyle)){
							if($DStyle=='ds1' || $DStyle=='ds3'){
								$op .=$OPTitle;
								$op .=$OPSubTitle;
							}else if($DStyle=='ds2' || $DStyle=='ds4'){
								$op .=$OPSubTitle;
								$op .=$OPTitle;
							}					
						}
					}else if($Layout == 'advanced'){
						if(!empty($AStyle)){
							$op .=$OPTitle;
							$op .=$OPSubTitle;
						}
					}				
				}
			$op .='</div>';
		$op .='</div>';
		echo wp_kses_normalize_entities($op);
	}
}