<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Toolset_Date extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-toolset-date';
	}

    public function get_title() {
        return esc_html__('Toolset : Date', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-toolset-icon';
    }

    public function get_categories() {
        return array('ectoolset');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-toolset-general' ];
    }
	
	public function get_keywords() {
		return [ 'toolset', 'toolset date','date' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Toolset : Date', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'toolsetDate',
			[
				'label' => esc_html__( 'Date Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Date Slug Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'toolsetDateFormate',
			[
				'label' => esc_html__( 'Date Format', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Format', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'toolsetDateStyling',
            [
                'label' => esc_html__('Toolset Date', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'toolsetDateTypography',
				'selector' => '{{WRAPPER}} .eca-toolset-date',				
			]
		);
		$this->add_responsive_control(
			'toolsetDateAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-toolset-date' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabstoolsetDateStyle' );
		$this->start_controls_tab(
			'tabtoolsetDateNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetDateColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-toolset-date' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabtoolsetDateHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetDateColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-toolset-date:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('WPCF_VERSION') ) {
			$toolsetDate = !empty($settings['toolsetDate']) ? $settings['toolsetDate'] : '';
			
			if(!empty($toolsetDate)){
				echo '<div class="eca-toolset-date">';
					$toolsetDateFormate = !empty($settings['toolsetDateFormate']) ? $settings['toolsetDateFormate'] : '';
					if(!empty($toolsetDateFormate)){
						$unixtimestamp = strtotime( (types_render_field($toolsetDate)) );
						echo date_i18n( $toolsetDateFormate, $unixtimestamp );
					}else{
						echo (types_render_field($toolsetDate));
					}
				echo '</div>';
			}
		}
	}
}