<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Toolset_Singleline extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-toolset-single-line';
	}

    public function get_title() {
        return esc_html__('Toolset : Single Line', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-toolset-icon';
    }

    public function get_categories() {
        return array('ectoolset');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-toolset-general' ];
    }
	
	public function get_keywords() {
		return [ 'toolset', 'toolset singleline','singleline','single line','text' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Toolset : Single Line', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'toolsetSingleLine',
			[
				'label' => esc_html__( 'Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Slug Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'toolsetSingleLineTag',
			[
				'label' => esc_html__( 'Tag', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => \EcafeHelper::getHtmlTag('a'),
			]
		);
		$this->add_control(
			'toolsetSingleLineLink',
			[
				'label' => esc_html__( 'URL Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Filed Name', 'essential-classy-addons-for-elementor' ),
				'condition' => [
					'toolsetSingleLineTag' => 'a'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'toolsetSingleLineStyling',
            [
                'label' => esc_html__('Toolset Single Line', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'toolsetSingleLineTypography',
				'selector' => '{{WRAPPER}} .ec-toolset-singleline-wrapper .eca-toolset-singleline',				
			]
		);
		$this->add_responsive_control(
			'toolsetSingleLineAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-toolset-singleline-wrapper .eca-toolset-singleline' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabstoolsetSingleLineStyle' );
		$this->start_controls_tab(
			'tabtoolsetSingleLineNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetSingleLineColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-toolset-singleline-wrapper .eca-toolset-singleline' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabtoolsetSingleLineHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetSingleLineColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-toolset-singleline-wrapper .eca-toolset-singleline:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('WPCF_VERSION') ) {
			$toolsetSingleLine = !empty($settings['toolsetSingleLine']) ? $settings['toolsetSingleLine'] : '';
			if($toolsetSingleLine){
				echo '<div class="ec-toolset-singleline-wrapper">';				
					$toolsetSingleLineTag= !empty($settings['toolsetSingleLineTag']) ? $settings['toolsetSingleLineTag'] : 'h1';
					if($toolsetSingleLineTag=='a'){
						if(!empty($settings['toolsetSingleLineLink'])){							
							echo '<'.\EcafeHelper::check_and_validate_html_tag($toolsetSingleLineTag).' class="eca-toolset-singleline" href=';
								echo (types_render_field($settings['toolsetSingleLineLink'],array("raw"=>"true")));
							echo '>';
									echo (types_render_field($toolsetSingleLine));
							echo '</'.\EcafeHelper::check_and_validate_html_tag($toolsetSingleLineTag).'>';
						}
					}else{
						echo '<'.\EcafeHelper::check_and_validate_html_tag($toolsetSingleLineTag).' class="eca-toolset-singleline">';
						echo (types_render_field($toolsetSingleLine));
						echo '</'.\EcafeHelper::check_and_validate_html_tag($toolsetSingleLineTag).'>';
					}				
				echo '</div>';
			}
		}
	}
}