<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Toolset_Skype extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-toolset-skype';
	}

    public function get_title() {
        return esc_html__('Toolset : Skype', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-toolset-icon';
    }

    public function get_categories() {
        return array('ectoolset');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-toolset-general' ];
    }
	
	public function get_keywords() {
		return [ 'toolset', 'toolset skype','skype' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Toolset : Skype', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'toolsetSkype',
			[
				'label' => esc_html__( 'Skype Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Skype Slug Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'toolsetSkypeStyling',
            [
                'label' => esc_html__('Toolset Skype', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'toolsetSkypeAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-toolset-skype' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->add_responsive_control(
  			'toolsetSkypeSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .eca-toolset-skype img' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('WPCF_VERSION') ) {
			$toolsetSkype = !empty($settings['toolsetSkype']) ? $settings['toolsetSkype'] : '';
			echo '<div class="eca-toolset-skype">';
				echo (types_render_field($toolsetSkype));
			echo '</div>';
		}
	}
}