<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Toolset_Url extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-toolset-url';
	}

    public function get_title() {
        return esc_html__('Toolset : URL', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-toolset-icon';
    }

    public function get_categories() {
        return array('ectoolset');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-toolset-general' ];
    }
	
	public function get_keywords() {
		return [ 'toolset', 'toolset url','url','link' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Toolset : URL', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'toolsetUrl',
			[
				'label' => esc_html__( 'URL Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter URL Slug Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'toolsetTextType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'static',
				'options' => [
					'static'  => esc_html__( 'Static', 'essential-classy-addons-for-elementor' ),
					'dynamic' => esc_html__( 'Dynamic', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'toolsetTextStatic',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'toolsetTextType' => 'static'
				]
			]
		);
		$this->add_control(
			'toolsetTextDynamic',
			[
				'label' => esc_html__( 'Text Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Slug Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'toolsetTextType' => 'dynamic'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'toolsetUrlStyling',
            [
                'label' => esc_html__('Toolset URL', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'toolsetUrlTypography',
				'selector' => '{{WRAPPER}} .eca-toolset-url',				
			]
		);
		$this->add_responsive_control(
			'toolsetUrlAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-toolset-url' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabstoolsetUrlStyle' );
		$this->start_controls_tab(
			'tabtoolsetUrlNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetUrlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-toolset-url' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabtoolsetUrlHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetUrlColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-toolset-url:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('WPCF_VERSION') ) {
			if(!empty($settings['toolsetUrl'])){							
				echo '<a class="eca-toolset-url" href=';					
					echo (types_render_field($settings['toolsetUrl'],array("raw"=>"true")));
				echo '>';
					$toolsetTextType = !empty($settings['toolsetTextType']) ? $settings['toolsetTextType'] : 'static';
					$toolsetTextStatic = !empty($settings['toolsetTextStatic']) ? $settings['toolsetTextStatic'] : '';
					$toolsetTextDynamic = !empty($settings['toolsetTextDynamic']) ? $settings['toolsetTextDynamic'] : '';
					
					if(!empty($toolsetTextType) && $toolsetTextType=='static' && !empty($toolsetTextStatic)){
						echo $toolsetTextStatic;
					}else if(!empty($toolsetTextType) && $toolsetTextType=='dynamic' && !empty($toolsetTextDynamic)){
						echo (types_render_field($toolsetTextDynamic));
					}else if((!empty($toolsetTextType) && $toolsetTextType=='static') || (!empty($toolsetTextType) && $toolsetTextType=='dynamic') || (!empty($toolsetTextDynamic) || !empty($toolsetTextStatic))){
						echo (types_render_field($settings['toolsetUrl'],array("raw"=>"true")));
					}					
				echo '</a>';
			}
		}
	}
}