<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Toolset_Wysiwyg extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-toolset-wysiwyg';
	}

    public function get_title() {
        return esc_html__('Toolset : WYSIWYG', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-toolset-icon';
    }

    public function get_categories() {
        return array('ectoolset');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-toolset-general' ];
    }
	
	public function get_keywords() {
		return [ 'toolset', 'toolset wysiwyg','wysiwyg','visual editor' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Toolset : WYSIWYG', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'toolsetWsiwyg',
			[
				'label' => esc_html__( 'Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Slug Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'toolsetWysiwygStyling',
            [
                'label' => esc_html__('Toolset Wysiwyg', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'toolsetWysiwygTypography',
				'selector' => '{{WRAPPER}} .ec-toolset-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-toolset-wsiwyg-wrapper p',				
			]
		);
		$this->add_responsive_control(
			'toolsetWysiwygAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-toolset-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-toolset-wsiwyg-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabstoolsetWysiwygStyle' );
		$this->start_controls_tab(
			'tabtoolsetWysiwygNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetWysiwygColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-toolset-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-toolset-wsiwyg-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabtoolsetWysiwygHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'toolsetWysiwygColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-toolset-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-toolset-wsiwyg-wrapper:hover p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {

        $settings = $this->get_settings_for_display();
		if( defined('WPCF_VERSION') ) {
			$toolsetWsiwyg = !empty($settings['toolsetWsiwyg']) ? $settings['toolsetWsiwyg'] : '';
			if($toolsetWsiwyg){
				echo '<div class="ec-toolset-wsiwyg-wrapper">';
					echo (types_render_field($toolsetWsiwyg));
				echo '</div>';
			}
		}
	}
}