<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Wck_Phone extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-wck-phone';
	}

    public function get_title() {
        return esc_html__('WCK : Phone', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-wck-icon';
    }

    public function get_categories() {
        return array('ecwck');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-wck-general' ];
    }
	
	public function get_keywords() {
		return [ 'wck', 'wck phone','phone' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'WCK : Phone', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'wckGroupName',
			[
				'label' => esc_html__( 'Group Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Group Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'wckPhone',
			[
				'label' => esc_html__( 'Phone Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Phone Slug Name', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'wckTextType',
			[
				'label' => esc_html__( 'Source', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'static',
				'options' => [
					'static'  => esc_html__( 'Static', 'essential-classy-addons-for-elementor' ),
					'dynamic' => esc_html__( 'Dynamic', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'wckTextStatic',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'wckTextType' => 'static'
				]
			]
		);
		$this->add_control(
			'wckTextDynamic',
			[
				'label' => esc_html__( 'Text Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Slug Name', 'essential-classy-addons-for-elementor' ),
				 'condition' => [
					'wckTextType' => 'dynamic'
				]
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wckPhoneStyling',
            [
                'label' => esc_html__('Wck Phone', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wckPhoneTypography',
				'selector' => '{{WRAPPER}} .eca-wck-phone',				
			]
		);
		$this->add_responsive_control(
			'wckPhoneAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .eca-wck-phone' => 'justify-content:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabswckPhoneStyle' );
		$this->start_controls_tab(
			'tabwckPhoneNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wckPhoneColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-wck-phone' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwckPhoneHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wckPhoneColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .eca-wck-phone:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {
        $settings = $this->get_settings_for_display();
		if( defined('WCK_PLUGIN_VERSION') ) {
			$wckGroupName = !empty($settings['wckGroupName']) ? $settings['wckGroupName'] : '';
			if($wckGroupName){
				if(!empty($settings['wckPhone'])){							
					echo '<a class="eca-wck-phone" href=';					
					echo 'tel:';					
						echo get_cfc_field($wckGroupName, $settings['wckPhone']);
					echo '>';
						$wckTextType = !empty($settings['wckTextType']) ? $settings['wckTextType'] : 'static';
						$wckTextStatic = !empty($settings['wckTextStatic']) ? $settings['wckTextStatic'] : '';
						$wckTextDynamic = !empty($settings['wckTextDynamic']) ? $settings['wckTextDynamic'] : '';
						
						if(!empty($wckTextType) && $wckTextType=='static' && !empty($wckTextStatic)){
							echo $wckTextStatic;
						}else if(!empty($wckTextType) && $wckTextType=='dynamic' && !empty($wckTextDynamic)){
							echo get_cfc_field($wckGroupName, $wckTextDynamic);
						}else if((!empty($wckTextType) && $wckTextType=='static') || (!empty($wckTextType) && $wckTextType=='dynamic') || (!empty($wckTextDynamic) || !empty($wckTextStatic))){
							echo get_cfc_field($wckGroupName, $settings['wckPhone']);
						}					
					echo '</a>';
				}
			}
		}
	}
}