<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Wck_Textarea extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-wck-textarea';
	}

    public function get_title() {
        return esc_html__('WCK : Text Area', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-wck-icon';
    }

    public function get_categories() {
        return array('ecwck');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-wck-general' ];
    }
	
	public function get_keywords() {
		return [ 'wck', 'wck textarea','textarea','text area' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'WCK : Text Area', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'wckGroupName',
			[
				'label' => esc_html__( 'Group Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Group Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'wckTextarea',
			[
				'label' => esc_html__( 'Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Slug Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wckTextAreaStyling',
            [
                'label' => esc_html__('Wck Textarea', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wckTextAreaTypography',
				'selector' => '{{WRAPPER}} .ec-wck-textarea-wrapper,{{WRAPPER}} .ec-wck-textarea-wrapper p',				
			]
		);
		$this->add_responsive_control(
			'wckTextAreaAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-wck-textarea-wrapper,{{WRAPPER}} .ec-wck-textarea-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabswckTextAreaStyle' );
		$this->start_controls_tab(
			'tabwckTextAreaNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wckTextAreaColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-wck-textarea-wrapper,{{WRAPPER}} .ec-wck-textarea-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwckTextAreaHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wckTextAreaColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-wck-textarea-wrapper:hover,{{WRAPPER}} .ec-wck-textarea-wrapper:hover p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {
        $settings = $this->get_settings_for_display();
		if( defined('WCK_PLUGIN_VERSION') ) {
			$wckGroupName = !empty($settings['wckGroupName']) ? $settings['wckGroupName'] : '';
			if($wckGroupName){
				$wckTextarea = !empty($settings['wckTextarea']) ? $settings['wckTextarea'] : '';
				if($wckTextarea){
					echo '<div class="ec-wck-textarea-wrapper">';
						echo get_cfc_field($wckGroupName, $wckTextarea);
					echo '</div>';
				}
			}
		}
	}
}