<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Wck_Wysiwygeditor extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-wck-wysiwyg-editor';
	}

    public function get_title() {
        return esc_html__('WCK : Wysiwyg Editor', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-wck-icon';
    }

    public function get_categories() {
        return array('ecwck');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-wck-general' ];
    }
	
	public function get_keywords() {
		return [ 'wck', 'wck wysiwyg','wysiwyg','wysiwyg editor','visual editor' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'WCK : Wysiwyg Editor', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'wckGroupName',
			[
				'label' => esc_html__( 'Group Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Group Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->add_control(
			'wckWsiwyg',
			[
				'label' => esc_html__( 'Slug Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => ['active' => true,],
				'default' => '',
				'placeholder' => esc_html__( 'Enter Slug Name', 'essential-classy-addons-for-elementor' ),	
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wckWysiwygStyling',
            [
                'label' => esc_html__('Wck Wysiwyg', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wckWysiwygTypography',
				'selector' => '{{WRAPPER}} .ec-wck-wsiwyg-wrapper,{{WRAPPER}} .ec-wck-wsiwyg-wrapper p',				
			]
		);
		$this->add_responsive_control(
			'wckWysiwygAlign',
			[
				'label' => esc_html__( 'Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justify', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .ec-wck-wsiwyg-wrapper,{{WRAPPER}} .ec-wck-wsiwyg-wrapper p' => 'text-align:{{VALUE}};',
                ],
			]
		);
		$this->start_controls_tabs( 'tabswckWysiwygStyle' );
		$this->start_controls_tab(
			'tabwckWysiwygNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wckWysiwygColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-wck-wsiwyg-wrapper,{{WRAPPER}} .ec-wck-wsiwyg-wrapper p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwckWysiwygHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wckWysiwygColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-wck-wsiwyg-wrapper:hover,{{WRAPPER}} .ec-wck-wsiwyg-wrapper:hover p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	 protected function render() {
        $settings = $this->get_settings_for_display();
		if( defined('WCK_PLUGIN_VERSION') ) {
			$wckGroupName = !empty($settings['wckGroupName']) ? $settings['wckGroupName'] : '';
			if($wckGroupName){
				$wckWsiwyg = !empty($settings['wckWsiwyg']) ? $settings['wckWsiwyg'] : '';
				if($wckWsiwyg){
					echo '<div class="ec-wck-wsiwyg-wrapper">';
						echo get_cfc_field($wckGroupName, $wckWsiwyg);
					echo '</div>';
				}
			}			
		}
	}
}