<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Woocommerce_Checkout extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-woocommerce-checkout';
	}

    public function get_title() {
        return esc_html__('Woocommerce Checkout', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-checkout-icon';
    }

    public function get_categories() {
        return array('ecwoocommerce');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-woocommerce-checkout' ];
    }
	
	public function get_keywords() {
		return [ 'woocommerce checkout','woocommerce','checkout' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Woocommerce Checkout', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
            'chkFullWidth',
            [
				'label'   => esc_html__( 'Full Width', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col2-set > div' => 'width: 100%',
				],
			]
		);
		$this->end_controls_section();
		
		/*style*/
		$this->start_controls_section(
            'rctStyling',
            [
                'label' => esc_html__('Returning customer Toggle', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'rctiheading',
			[
				'label' => esc_html__( 'Icon Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
  			'rctiSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info:before' => 'font-size:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'rctioffset',		
  			[		
  				'label' => esc_html__( 'Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => -300,		
						'max' => 300,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info:before' => 'left:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'rctiColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rctlheading',
			[
				'label' => esc_html__( 'Anchor/Link Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rctlTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info .showlogin',				
			]
		);
		$this->add_control(
			'rctlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info .showlogin' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rctlColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info .showlogin:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rctcheading',
			[
				'label' => esc_html__( 'Common Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'rctcPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'rctcMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_control(
			'rctcColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rctcBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rctcBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info',
			]
		);
		$this->add_responsive_control(
			'rctcBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rctcShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-login-toggle .woocommerce-info',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'rcformStyling',
            [
                'label' => esc_html__('Returning customer Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'rcfInfoheading',
			[
				'label' => esc_html__( 'Information', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rcfITypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login',				
			]
		);
		$this->add_control(
			'rcfIColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfLabelheading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rcfLTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row',				
			]
		);
		$this->add_control(
			'rcfLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfLRColor',
			[
				'label' => esc_html__( 'Required Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfInputheading',
			[
				'label' => esc_html__( 'Input Filed', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'rcfIPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rcfIFTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text',				
			]
		);
		$this->add_control(
			'rcfIPColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabsrcfIstyle' );
		$this->start_controls_tab(
			'tabrcfINorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'rcfIColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rcfIBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rcfIBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text',
			]
		);
		$this->add_responsive_control(
			'rcfIBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rcfIShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'rcfITextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabrcfIFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'rcfIColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rcfIBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rcfIBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text:focus',
			]
		);
		$this->add_responsive_control(
			'rcfIBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rcfIShadowF',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'rcfITextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .input-text:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'rcfInputPassheading',
			[
				'label' => esc_html__( 'Show Password Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
  			'rcfipiSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .show-password-input::after' => 'font-size:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'rcfipiSColor',
			[
				'label' => esc_html__( 'Show', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .show-password-input::after' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfipiHColor',
			[
				'label' => esc_html__( 'Hide', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .show-password-input.display-password::after' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfrmheading',
			[
				'label' => esc_html__( 'Remember Me', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rcfrmTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__rememberme',				
			]
		);
		$this->add_control(
			'rcfrmColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__rememberme' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfLoginBheading',
			[
				'label' => esc_html__( 'Login Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'rcflbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'rcflbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'rcflbWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsrcflbStyle' );
		$this->start_controls_tab(
			'tabrcflbNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'rcflbColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rcflbBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rcflbBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit',
			]
		);
		$this->add_responsive_control(
			'rcflbBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rcflbShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabrcflbHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'rcflbColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rcflbBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rcflbBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit:hover',
			]
		);
		$this->add_responsive_control(
			'rcflbBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rcflbShadowHover',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .form-row .woocommerce-form-login__submit:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'rcfLPheading',
			[
				'label' => esc_html__( 'Lost Password', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rcfLPTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .lost_password a',				
			]
		);
		$this->add_control(
			'rcfLPColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .lost_password a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfLPColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login .lost_password a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'rcfBoxheading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'rcfbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'rcfbMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);		
		$this->start_controls_tabs( 'tabsrcfbStyle' );
		$this->start_controls_tab(
			'tabrcfbNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rcfbBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rcfbBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login',
			]
		);
		$this->add_responsive_control(
			'rcfbBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rcfbShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabrcfbHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'rcfbBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'rcfbBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login:hover',
			]
		);
		$this->add_responsive_control(
			'rcfbBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'rcfbShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper form.woocommerce-form.woocommerce-form-login:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'couponTStyling',
            [
                'label' => esc_html__('Coupon Toggle', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'ctheading',
			[
				'label' => esc_html__( 'Icon Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
  			'ctiSize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 1000,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info:before' => 'font-size:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'ctioffset',		
  			[		
  				'label' => esc_html__( 'Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => -300,		
						'max' => 300,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info:before' => 'left:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'ctiColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ctlheading',
			[
				'label' => esc_html__( 'Anchor/Link Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ctlTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info .showcoupon',				
			]
		);
		$this->add_control(
			'ctlColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info .showcoupon' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ctlColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info .showcoupon:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'ctcheading',
			[
				'label' => esc_html__( 'Common Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'ctcPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'ctcMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_control(
			'ctcColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'ctcBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'ctcBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info',
			]
		);
		$this->add_responsive_control(
			'ctcBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'ctcShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon-toggle .woocommerce-info',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'couponFormStyling',
            [
                'label' => esc_html__('Coupon Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'cfInfoheading',
			[
				'label' => esc_html__( 'Information', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfITypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon',				
			]
		);
		$this->add_control(
			'cfIColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'cfInputheading',
			[
				'label' => esc_html__( 'Input Filed', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cfIPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cfIFTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text',				
			]
		);
		$this->add_control(
			'cfIPColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabscfIstyle' );
		$this->start_controls_tab(
			'tabcfINorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cfIColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cfIBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cfIBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text',
			]
		);
		$this->add_responsive_control(
			'cfIBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cfIShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'cfITextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcfIFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cfIColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cfIBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cfIBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text:focus',
			]
		);
		$this->add_responsive_control(
			'cfIBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cfIShadowF',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'cfITextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .input-text:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'cfABheading',
			[
				'label' => esc_html__( 'Apply Coupon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'acPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'acMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'acWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabsacStyle' );
		$this->start_controls_tab(
			'tabacNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'acBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button',
			]
		);
		$this->add_responsive_control(
			'acBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'acShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabacHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'acColorHover',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'acBgHover',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acBorderHover',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button:hover',
			]
		);
		$this->add_responsive_control(
			'acBrHover',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'acShadowHover',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon .form-row .button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'cpnBoxheading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cpnBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'cpnBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);		
		$this->start_controls_tabs( 'tabscpnBStyle' );
		$this->start_controls_tab(
			'tabcpnBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cpnBBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cpnBBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon',
			]
		);
		$this->add_responsive_control(
			'cpnBBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cpnBShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcpnBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cpnBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cpnBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon:hover',
			]
		);
		$this->add_responsive_control(
			'cpnBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cpnBShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-form-coupon:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'billingFormStyling',
            [
                'label' => esc_html__('Billing Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'chkbfHheading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cbfhTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields h3',				
			]
		);
		$this->add_control(
			'cbfhColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkbfLabelheading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cbflPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'cbflMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cbflTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label',				
			]
		);
		$this->add_control(
			'cbflColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbflBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbflBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label',
			]
		);
		$this->add_responsive_control(
			'cbflBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbflShadow',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'cbflTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label',
			]
		);
		$this->add_control(
			'cbflrColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkbfInputFieldheading',
			[
				'label' => esc_html__( 'Input Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cbfifPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cbfifTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered',				
			]
		);
		$this->add_control(
			'cbfifColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabscbfifstyle' );
		$this->start_controls_tab(
			'tabcbfifNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cbfifColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbfifBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbfifBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->add_responsive_control(
			'cbfifBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbfifShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'cbfifTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcbfifFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'cbfifColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbfifBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbfifBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->add_responsive_control(
			'cbfifBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbfifShadowF',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'cbfifTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'chkbfCAheading',
			[
				'label' => esc_html__( 'Create Account', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cbfcaPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cbfcaTypography',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields',				
			]
		);
		$this->add_control(
			'cbfcaColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbfcaBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbfcaBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields',
			]
		);
		$this->add_responsive_control(
			'cbfcaBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbfcaShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-account-fields',
			]
		);
		$this->add_control(
			'chkbfValidationdheading',
			[
				'label' => esc_html__( 'Validation', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'validColor',
			[
				'label' => esc_html__( 'Valid Border Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce form .form-row.woocommerce-validated .select2-container,{{WRAPPER}} .ec-checkout-wrapper .woocommerce form .form-row.woocommerce-validated input.input-text,{{WRAPPER}} .ec-checkout-wrapper  .woocommerce form .form-row.woocommerce-validated select' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'invalidColor',
			[
				'label' => esc_html__( 'Invalid Border Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce form .form-row.woocommerce-invalid .select2-container,{{WRAPPER}} .ec-checkout-wrapper .woocommerce form .form-row.woocommerce-invalid input.input-text,{{WRAPPER}} .ec-checkout-wrapper .woocommerce form .form-row.woocommerce-invalid select' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkbfFormdheading',
			[
				'label' => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cbffPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'cbffMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);		
		$this->start_controls_tabs( 'tabscbffStyle' );
		$this->start_controls_tab(
			'tabcbffNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbffBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbffBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1',
			]
		);
		$this->add_responsive_control(
			'cbffBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbffShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcbffHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbffBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbffBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1:hover',
			]
		);
		$this->add_responsive_control(
			'cbffBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbffShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-1:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'shippingFormStyling',
            [
                'label' => esc_html__('Shipping Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'chksfHheading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'csfhTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields h3',				
			]
		);
		$this->add_control(
			'csfhColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chksfLabelheading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'csflPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'csflMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'csflTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label',				
			]
		);
		$this->add_control(
			'csflColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'csflBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'csflBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label',
			]
		);
		$this->add_responsive_control(
			'csflBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'csflShadow',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'csflTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label',
			]
		);
		$this->add_control(
			'csflrColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chksfInputFieldheading',
			[
				'label' => esc_html__( 'Input Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'csfifPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'csfifTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered',				
			]
		);
		$this->add_control(
			'csfifColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabscsfifstyle' );
		$this->start_controls_tab(
			'tabcsfifNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'csfifColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'csfifBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'csfifBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->add_responsive_control(
			'csfifBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'csfifShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'csfifTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcsfifFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'csfifColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'csfifBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'csfifBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->add_responsive_control(
			'csfifBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'csfifShadowF',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'csfifTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields input:focus,
				{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-shipping-fields .select2-container .select2-selection__rendered:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();				
		$this->add_control(
			'chksfFormdheading',
			[
				'label' => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'cbsfPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'cbsfMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);		
		$this->start_controls_tabs( 'tabscbsfStyle' );
		$this->start_controls_tab(
			'tabcbsfNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbsfBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbsfBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2',
			]
		);
		$this->add_responsive_control(
			'cbsfBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbsfShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcbsfHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'cbsfBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'cbsfBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2:hover',
			]
		);
		$this->add_responsive_control(
			'cbsfBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'cbsfShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'orderNotesStyling',
            [
                'label' => esc_html__('Order Notes', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'ontaPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ontaTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea',				
			]
		);
		$this->add_control(
			'ontaPColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabsontastyle' );
		$this->start_controls_tab(
			'tabontaNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ontaColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'ontaBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'ontaBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea',
			]
		);
		$this->add_responsive_control(
			'ontaBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'ontaShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'ontaTextShadowNorm',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabontaFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'ontaColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'ontaBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'ontaBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea:focus',
			]
		);
		$this->add_responsive_control(
			'ontaBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'ontaShadowF',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'ontaTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .col-2 .woocommerce-additional-fields textarea:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'yourOrdersStyling',
            [
                'label' => esc_html__('Your Orders', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'yoHeadingheading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'yohTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout #order_review_heading',				
			]
		);
		$this->add_control(
			'yohColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout #order_review_heading' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'yoHeadNameheading',
			[
				'label' => esc_html__( 'Table Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'yohnTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-checkout-review-order',				
			]
		);
		$this->add_control(
			'yohnColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-checkout-review-order' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'yoTotalNameheading',
			[
				'label' => esc_html__( 'Total Name', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'yotnColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-checkout-review-order .order-total th' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'yoTotalValueheading',
			[
				'label' => esc_html__( 'Total Value', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'yotvColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-checkout-review-order .order-total td' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'yoBorderheading',
			[
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'yobdbR',
            [
				'label'   => esc_html__( 'Remove Default Border', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'yoBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-review-order .woocommerce-checkout-review-order-table th,{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-review-order .woocommerce-checkout-review-order-table td',
				'condition'    => [
					'yobdbR' => 'yes',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'paymentStyling',
            [
                'label' => esc_html__('Payment', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'payTypo',
				'selector' => '.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper #payment ul.payment_methods li',				
			]
		);
		$this->add_control(
			'payColor',
			[
				'label' => esc_html__( 'Payment Type Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper #payment ul.payment_methods li' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'payBoxheading',
			[
				'label' => esc_html__( 'Payment Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'payDescColor',
			[
				'label' => esc_html__( 'Description Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper #payment div.payment_box' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'payDescBgColor',
			[
				'label' => esc_html__( 'Background Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper #payment div.payment_box' => 'background: {{VALUE}};',
					'.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper #payment div.payment_box::before' => 'border-bottom:1em solid {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wcplheading',
			[
				'label' => esc_html__( 'Payment Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wcplTypo',
				'selector' => '.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment label,
				{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment .payment_method_paypal .about_paypal',
			]
		);
		$this->add_control(
			'wcplColor',
			[
				'label' => esc_html__( 'Label Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'.woocommerce-checkout {{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment label,
				{{WRAPPER}} .ec-checkout-wrapper .payment_method_paypal .about_paypal' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'privacyPolicyStyling',
            [
                'label' => esc_html__('Privacy Policy', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'ppTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-terms-and-conditions-wrapper .woocommerce-privacy-policy-text',				
			]
		);
		$this->add_control(
			'ppColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-terms-and-conditions-wrapper .woocommerce-privacy-policy-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'pplColor',
			[
				'label' => esc_html__( 'Link Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-terms-and-conditions-wrapper .woocommerce-privacy-policy-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'placeOrderStyling',
            [
                'label' => esc_html__('Place Order Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'pobPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'pobTypography',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order',				
			]
		);
		$this->start_controls_tabs( 'tabspobStyle' );
		$this->start_controls_tab(
			'tabpobNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pobColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pobBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pobBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order',
			]
		);
		$this->add_responsive_control(
			'pobBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'pobShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabpobHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'pobColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'pobbBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pobBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order:hover',
			]
		);
		$this->add_responsive_control(
			'pobBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'pobShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .form-row.place-order button#place_order:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'paymentFormStyling',
            [
                'label' => esc_html__('Payment Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'payfPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'payfMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabspayfStyle' );
		$this->start_controls_tab(
			'tabpayfNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'payfBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'payfBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment',
			]
		);
		$this->add_responsive_control(
			'payfBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'payfShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabpayfHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'payfBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'payfBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment:hover',
			]
		);
		$this->add_responsive_control(
			'payfBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'payfShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-checkout-payment:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'chkemStyling',
            [
                'label' => esc_html__('Error Message', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkemTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error',				
			]
		);
		$this->add_control(
			'chkemColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error,
					{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error::before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'chkemBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'chkemBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error',
			]
		);
		$this->add_responsive_control(
			'chkemBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'chkemShadow',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'chkemTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-error',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'chkFormStyling',
            [
                'label' => esc_html__('Checkout Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'chkfPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'chkfMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabschkfStyle' );
		$this->start_controls_tab(
			'tabchkfNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'chkfBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'chkfBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper',
			]
		);
		$this->add_responsive_control(
			'chkfBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'chkfShadowNorm',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabchkfHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'chkfBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'chkfBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'chkfBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'chkfShadowH',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'chkORStyling',
            [
                'label' => esc_html__('Order received', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'chkORGheading',
			[
				'label' => esc_html__( 'General Style', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkORGTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order',				
			]
		);
		$this->add_control(
			'chkORGColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkORGLColor',
			[
				'label' => esc_html__( 'Link Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkORTheading',
			[
				'label' => esc_html__( 'Order Received', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkORTTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order .woocommerce-thankyou-order-received',				
			]
		);
		$this->add_control(
			'chkORTColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order .woocommerce-thankyou-order-received' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkOVTheading',
			[
				'label' => esc_html__( 'Order Overview', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkORVTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order-overview.woocommerce-thankyou-order-details',				
			]
		);
		$this->add_control(
			'chkORVColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order-overview.woocommerce-thankyou-order-details' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'chkORVBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order-overview.woocommerce-thankyou-order-details li',
			]
		);
		$this->add_control(
			'chkORMheading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkORMTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order .woocommerce-order-details__title,
				{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order .addresses .woocommerce-column__title',				
			]
		);
		$this->add_control(
			'chkORMColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order .woocommerce-order-details__title,
				{{WRAPPER}} .ec-checkout-wrapper .woocommerce-order .addresses .woocommerce-column__title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'chkORBheading',
			[
				'label' => esc_html__( 'Billing', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'chkORBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkORBTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address',				
			]
		);
		$this->add_control(
			'chkORBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'chkORBBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'chkORBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address',
			]
		);
		$this->add_responsive_control(
			'chkORBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'chkORBShadow',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--billing-address address',
			]
		);
		$this->add_control(
			'chkORSheading',
			[
				'label' => esc_html__( 'Shipping', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'chkORSPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'chkORSTypo',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address',				
			]
		);
		$this->add_control(
			'chkORSColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'chkORSBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'chkORSBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address',
			]
		);
		$this->add_responsive_control(
			'chkORSBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'chkORSShadow',
				'selector' => '{{WRAPPER}} .ec-checkout-wrapper .woocommerce-column--shipping-address address',
			]
		);
		$this->end_controls_section();
	}
	
	
	private function ecchkoutshortcode() {
		$settings = $this->get_settings();		
		$this->add_render_attribute( 'ecchkoutshortcode', 'woocommerce_checkout' );		
		$ecchkoutshortcode[] = sprintf( '[%s]', $this->get_render_attribute_string( 'ecchkoutshortcode' ) );
		return implode("", $ecchkoutshortcode);
	}
	
	protected function render() {
        $settings = $this->get_settings_for_display();
		if ( class_exists('woocommerce') ) {			
			
			$yobdbcls='';
			if(isset($settings['yobdbR']) && $settings['yobdbR']=='yes'){
				$yobdbcls=' brddsb';
			}
			$output ='<div class="ec-checkout-wrapper '.esc_attr($yobdbcls).'">';				
				$output .= do_shortcode($this->ecchkoutshortcode());
			$output .= '</div>';		
			echo $output;
		}
	}
}