<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Woocommerce_ordertrack extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-woocommerce-ordertrack';
	}

    public function get_title() {
        return esc_html__('Woocommerce Ordertrack', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-ordertrack-icon';
    }

    public function get_categories() {
        return array('ecwoocommerce');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-woocommerce-ordertrack' ];
    }
	
	public function get_keywords() {
		return [ 'woocommerce ordertrack','Woocommerce','ordertrack','order track' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Woocommerce Ordertrack', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'wotLayout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),
					'ecwotcolumn'  => esc_html__( 'Column', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->end_controls_section();
		
		/*style*/
		$this->start_controls_section(
            'wotFormStyling',
            [
                'label' => esc_html__('Order Track Form', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'wotFIHeading',
			[
				'label' => esc_html__( 'Information', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotFITypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order',				
			]
		);
		$this->add_control(
			'wotFIColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order' => 'color: {{VALUE}}',
				],				
			]
		);
		$this->add_control(
			'wotFLaHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotFLaPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wotFLaMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotFLaTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label',				
			]
		);
		$this->add_control(
			'wotFLaColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFLaBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFLaBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label',
			]
		);
		$this->add_responsive_control(
			'wotFLaBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFLaShadow',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wotFLaTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order label',
			]
		);
		$this->add_control(
			'wotFFHeading',
			[
				'label' => esc_html__( 'Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotFFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotFFTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input',				
			]
		);
		$this->add_control(
			'wotFFPColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabswotFFstyle' );
		$this->start_controls_tab(
			'tabwotFFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wotFFColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input',
			]
		);
		$this->add_responsive_control(
			'wotFFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFFShadowN',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wotFFTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwotFFFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wotFFColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFFBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFFBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input:focus',
			]
		);
		$this->add_responsive_control(
			'wotFFBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFFShadowF',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wotFFTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wotFBHeading',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotFBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotFBTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button',				
			]
		);
		$this->start_controls_tabs( 'tabswotFBStyle' );
		$this->start_controls_tab(
			'tabwotFBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wotFBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFBBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFBBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button',
			]
		);
		$this->add_responsive_control(
			'wotFBBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFBShadowN',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwotFBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wotFBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button:hover',
			]
		);
		$this->add_responsive_control(
			'wotFBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFBShadowH',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order .form-row button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wotFBoHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotFBoPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wotFBoMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);		
		$this->start_controls_tabs( 'tabswotFBoStyle' );
		$this->start_controls_tab(
			'tabwotFBoNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFBoBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFBoBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order',
			]
		);
		$this->add_responsive_control(
			'wotFBoBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFBoShadowN',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwotFBoH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotFBoBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotFBoBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order:hover',
			]
		);
		$this->add_responsive_control(
			'wotFBoBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotFBoShadowH',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper form.woocommerce-form-track-order:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wotInfoStyling',
            [
                'label' => esc_html__('Order track Info', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotITypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .order-info',				
			]
		);
		$this->add_control(
			'wotIColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .order-info' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotIHColor',
			[
				'label' => esc_html__( 'Highlight Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .order-info mark' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotIHBColor',
			[
				'label' => esc_html__( 'Highlight Background', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .order-info mark' => 'background: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wotODStyling',
            [
                'label' => esc_html__('Order Details', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'wotODHHeading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotODHTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .woocommerce-order-details__title',				
			]
		);
		$this->add_control(
			'wotODHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .woocommerce-order-details__title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTLHeading',
			[
				'label' => esc_html__( 'Head', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotODTLTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details thead th',				
			]
		);
		$this->add_control(
			'wotODTLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details thead th' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTVHeading',
			[
				'label' => esc_html__( 'Body', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotODTVTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tbody td',				
			]
		);
		$this->add_control(
			'wotODTVColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tbody td' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODLiVHeading',
			[
				'label' => esc_html__( 'Link', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotODLiVTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tbody td a',				
			]
		);
		$this->add_control(
			'wotODLiVColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tbody td a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODLiVHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tbody td a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTFHeading',
			[
				'label' => esc_html__( 'Footer', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotODTFTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot th,{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot td',				
			]
		);
		$this->add_control(
			'wotODTFColor',
			[
				'label' => esc_html__( 'Head Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot th' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTFVColor',
			[
				'label' => esc_html__( 'Value Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot td' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTFLHeading',
			[
				'label' => esc_html__( 'Totals', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotODTFLTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot tr:last-child th,{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot tr:last-child td',				
			]
		);
		$this->add_control(
			'wotODTFLColor',
			[
				'label' => esc_html__( 'Head Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot tr:last-child th' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTFLDColor',
			[
				'label' => esc_html__( 'Value Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order_details tfoot tr:last-child td' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotODTableVHeading',
			[
				'label' => esc_html__( 'Table', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'yobdbR',
            [
				'label'   => esc_html__( 'Remove Default Border', 'essential-classy-addons-for-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'yoBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper.brddsb .woocommerce .order_details th,
				{{WRAPPER}} .ec-order-track-wrapper.brddsb .woocommerce .order_details td',
				'condition'    => [
					'yobdbR' => 'yes',
				],
			]
		);
		$this->add_control(
			'wotODBoxVHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotODBoxVPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wotODBoxVMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswotODBoxVStyle' );
		$this->start_controls_tab(
			'tabwotODBoxVNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotODBoxVBGN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotODBoxVBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details',
			]
		);
		$this->add_responsive_control(
			'wotODBoxVBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotODBoxVShadowN',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwotODBoxVHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotODBoxVBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotODBoxVBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details:hover',
			]
		);
		$this->add_responsive_control(
			'wotODBoxVBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotODBoxVShadowH',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wotOAStyling',
            [
                'label' => esc_html__('Order Again Button', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'wotOAPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotOATypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a',				
			]
		);
		$this->start_controls_tabs( 'tabswotOAStyle' );
		$this->start_controls_tab(
			'tabwotOANorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wotOAColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotOABgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotOABorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a',
			]
		);
		$this->add_responsive_control(
			'wotOABrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotOAShadowN',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwotOAHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wotOAColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotOABgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotOABorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a:hover',
			]
		);
		$this->add_responsive_control(
			'wotOABrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotOAShadowH',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-order-details .order-again a:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wotBStyling',
            [
                'label' => esc_html__('Billing', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'wotBHHeading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotBHTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 .woocommerce-column__title',				
			]
		);
		$this->add_control(
			'wotBHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 .woocommerce-column__title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotBCHeading',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotBCPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotBCTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address',				
			]
		);
		$this->add_control(
			'wotBCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address',
			]
		);
		$this->add_responsive_control(
			'wmaRLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRLShadow',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-1 address',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wotSStyling',
            [
                'label' => esc_html__('Shipping', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'wotSHHeading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotSHTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 .woocommerce-column__title',				
			]
		);
		$this->add_control(
			'wotSHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 .woocommerce-column__title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wotSCHeading',
			[
				'label' => esc_html__( 'Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wotSCPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wotSCTypo',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address',				
			]
		);
		$this->add_control(
			'wotSCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaSLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaSLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address',
			]
		);
		$this->add_responsive_control(
			'wmaSLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaSLShadow',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper .woocommerce-customer-details .col-2 address',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wotBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'wotBoxPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wotBoxMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-order-track-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswotBoxStyle' );
		$this->start_controls_tab(
			'tabwotBoxNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotBoxBGN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotBoxBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper',
			]
		);
		$this->add_responsive_control(
			'wotBoxBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotBoxShadowN',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwotBoxHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wotBoxBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-order-track-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wotBoxBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'wotBoxBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-order-track-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wotBoxShadowH',
				'selector' => '{{WRAPPER}} .ec-order-track-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	private function ecotshortcode() {
		$settings = $this->get_settings();		
		$this->add_render_attribute( 'ecotshortcode', 'woocommerce_order_tracking' );		
		$ecotshortcode[] = sprintf( '[%s]', $this->get_render_attribute_string( 'ecotshortcode' ) );
		return implode("", $ecotshortcode);
	}
	
	protected function render() {
        $settings = $this->get_settings_for_display();
		if ( class_exists('woocommerce') ) {
			$yobdbcls='';
			if(isset($settings['yobdbR']) && $settings['yobdbR']=='yes'){
				$yobdbcls=' brddsb';
			}
			$output ='<div class="ec-order-track-wrapper '.esc_attr($settings['wotLayout']).' '.esc_attr($yobdbcls).'">';
				$output .= do_shortcode($this->ecotshortcode());
			$output .= '</div>';		
			echo $output;
		}
	}
}