<?php
namespace EcafeAddons\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;

use EcafeAddons\EcafeElementLoad;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Ecafe_Woocommerce_Myaccount extends Widget_Base {
		
	public function get_name() {
		return 'ecafe-woocommerce-myaccount';
	}

    public function get_title() {
        return esc_html__('Woocommerce MyAccount', 'essential-classy-addons-for-elementor');
    }

    public function get_icon() {
        return 'ecafe-ele-back-icon ecafe-myaccount-icon';
    }

    public function get_categories() {
        return array('ecwoocommerce');
    }
	
	public function get_style_depends() {
		return [ 'ecafe-woocommerce-myaccount' ];
    }
	
	public function get_keywords() {
		return [ 'woocommerce myaccount','my account','myaccount','woocommerce' ];
	}
	
    protected function register_controls() {
		
		$this->start_controls_section(
			'contentSection',
			[
				'label' => esc_html__( 'Woocommerce MyAccount', 'essential-classy-addons-for-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'wmaLayout',
			[
				'label' => esc_html__( 'Layout', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'eclvertical',
				'options' => [
					'eclvertical'  => esc_html__( 'Vertical', 'essential-classy-addons-for-elementor' ),
					'eclhorizontal'  => esc_html__( 'Horizontal', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'wmaPreview',
			[
				'label' => esc_html__( 'Preview', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'wmaPreviewSel',
			[
				'label' => esc_html__( 'Select', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => esc_html__( 'Dashboard', 'essential-classy-addons-for-elementor' ),
					'orders'  => esc_html__( 'Orders', 'essential-classy-addons-for-elementor' ),
					'downloads'  => esc_html__( 'Downloads', 'essential-classy-addons-for-elementor' ),
					'edit-address'  => esc_html__( 'Addresses', 'essential-classy-addons-for-elementor' ),
					'edit-account'  => esc_html__( 'Account Details', 'essential-classy-addons-for-elementor' ),
					'payment-methods'  => esc_html__( 'Payment Methods', 'essential-classy-addons-for-elementor' ),
				],
			]
		);
		$this->add_control(
			'wmaPreviewSelMode',
			[
				'label' => esc_html__( 'Addresses', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'adddef',
				'options' => [
					'adddef'  => esc_html__( 'Default', 'essential-classy-addons-for-elementor' ),
					'addform'  => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				],
				'condition' => [
					'wmaPreviewSel' => 'edit-address',
				],
			]
		);
		$this->add_control(
			'wmaLRForm',[
				'label'   => esc_html__( 'Login & Register Form Preview', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->add_control(
			'wmaLPForm',[
				'label'   => esc_html__( 'Lost Password Form Preview', 'essential-classy-addons-for-elementor' ),
				'type'    =>  Controls_Manager::SWITCHER,
				'default' => 'no',
				'label_on' => esc_html__( 'Enable', 'essential-classy-addons-for-elementor' ),
				'label_off' => esc_html__( 'Disable', 'essential-classy-addons-for-elementor' ),				
			]
		);
		$this->end_controls_section();
		
		/*style*/
		$this->start_controls_section(
            'wmaNLStyling',
            [
                'label' => esc_html__('Navigation List', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'wmaNLPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaNLMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaNLTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a',				
			]
		);
		$this->start_controls_tabs( 'tabswmaNLStyle' );
		$this->start_controls_tab(
			'tabwmaNLNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaNLColorNorm',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaNLBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaNLBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a',
			]
		);
		$this->add_responsive_control(
			'wmaNLBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaNLShadowNorm',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaNLH',
			[
				'label' => esc_html__( 'Hover/Active', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaNLColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a:hover,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li.is-active a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaNLBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a:hover,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li.is-active a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaNLBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a:hover,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li.is-active a',
			]
		);
		$this->add_responsive_control(
			'wmaNLBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a:hover,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li.is-active a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaNLShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li a:hover,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation ul li.is-active a',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaNBStyling',
            [
                'label' => esc_html__('Navigation Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'wmaNBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaNBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaNBBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaNBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation',
			]
		);
		$this->add_responsive_control(
			'wmaNBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaNBShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce .woocommerce-MyAccount-navigation',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaCTStyling',
            [
                'label' => esc_html__('Content Text', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaCTTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content',				
			]
		);
		$this->add_control(
			'wmaCTColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaCTLColor',
			[
				'label' => esc_html__( 'Link Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaCTLHColor',
			[
				'label' => esc_html__( 'Link Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaCBStyling',
            [
                'label' => esc_html__('Content Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_responsive_control(
			'wmaCBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaCBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaCBBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaCBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content',
			]
		);
		$this->add_responsive_control(
			'wmaCBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaCBShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmainfoStyling',
            [
                'label' => esc_html__('Info/Message', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaiBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-info',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaiBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-info',
			]
		);
		$this->add_responsive_control(
			'wmaiBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaiShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-info',				
			]
		);
		$this->add_control(
			'wmaiMTHeading',
			[
				'label' => esc_html__( 'Message Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaiMTTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message',
			]
		);
		$this->add_control(
			'wmaiMTColor',
			[
				'label' => esc_html__( 'Text Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaiMIHeading',
			[
				'label' => esc_html__( 'Icon Options', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
            'wmaiMISize',
            [
                'type' => Controls_Manager::SLIDER,
				'label' => esc_html__('Icon Size', 'essential-classy-addons-for-elementor'),
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 200,
						'step' => 1,
					],
				],				
				'render_type' => 'ui',
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message::before,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message::before' => 'font-size: {{SIZE}}{{UNIT}}',
				],
				'condition'		=> [
					'cart_icon' => 'icon_default',
				],
            ]
        );
		$this->add_control(
			'wmaiMIColor',
			[
				'label' => esc_html__( 'Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message::before,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message::before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaiMBHeading',
			[
				'label' => esc_html__( 'Button Options', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaiMBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%'],
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaiMBTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button',				
			]
		);
		$this->start_controls_tabs( 'tabswmaiMB' );
		$this->start_controls_tab(
			'wmaiMBN',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'wmaiMBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button' => 'color: {{VALUE}}',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wmaiMBBg',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaiMBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button',
			]
		);
		$this->add_responsive_control(
			'wmaiMBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'wmaiMBShadow',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button',
				'separator' => 'before',
			]
		);	
		$this->end_controls_tab();
		$this->start_controls_tab(
			'wmaiMBH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),					
			]
		);
		$this->add_control(
			'wmaiMBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button:hover,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button:hover' => 'color: {{VALUE}}',
				],
				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wmaiMBBgH',
				'label' => esc_html__( 'Background', 'essential-classy-addons-for-elementor' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button:hover,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaiMBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button:hover,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button:hover',
			]
		);
		$this->add_responsive_control(
			'wmaiMBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button:hover,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'wmaiMBShadowH',
				'label' => esc_html__( 'Box Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-message .woocommerce-Button:hover,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Message .woocommerce-Button:hover',
				'separator' => 'before',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaOrderStyling',
            [
                'label' => esc_html__('Order', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'wmaOPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaOBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaOBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders',
			]
		);
		$this->add_responsive_control(
			'wmaOBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaOShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders',
			]
		);
		$this->add_control(
			'wmaOHCheading',
			[
				'label' => esc_html__( 'Head Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaOHCBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders th',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaOHCTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders th',				
			]
		);
		$this->add_control(
			'wmaOHCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders th' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaOBCheading',
			[
				'label' => esc_html__( 'Body Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaOBCTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td',				
			]
		);
		$this->add_control(
			'wmaOBCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaOINheading',
			[
				'label' => esc_html__( 'Order Invoice No', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaOINTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td a',				
			]
		);
		$this->add_control(
			'wmaOINColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaOINColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaOVBheading',
			[
				'label' => esc_html__( 'Order View Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'wmaOVBTextAlign',
			[
				'label' => esc_html__( 'Text Alignment', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'essential-classy-addons-for-elementor' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view' => 'text-align: {{VALUE}};',
				],
				'default' => 'center',
				'label_block' => false,				
			]
		);
		$this->add_responsive_control(
			'wmaOVBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaOVBMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'wmaOVBWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 400,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabswmaOVBStyle' );
		$this->start_controls_tab(
			'tabwmaOVBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaOVBColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaOVBBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaOVBBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view',
			]
		);
		$this->add_responsive_control(
			'wmaOVBBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaOVBShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaOVBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaOVBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaOVBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaOVBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view:hover',
			]
		);
		$this->add_responsive_control(
			'wmaOVBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaOVBShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .my_account_orders td .view:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaDownloadStyling',
            [
                'label' => esc_html__('Downloads', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'wmaODPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaODBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaODBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads',
			]
		);
		$this->add_responsive_control(
			'wmaODBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaODShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads',
			]
		);
		$this->add_control(
			'wmaODHCheading',
			[
				'label' => esc_html__( 'Head Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaODHCBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads td,{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads th',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaODHCTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads th',				
			]
		);
		$this->add_control(
			'wmaODHCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads th' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaODBCheading',
			[
				'label' => esc_html__( 'Body Content', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaODBCTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads td',				
			]
		);
		$this->add_control(
			'wmaODBCColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads td' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaODPNheading',
			[
				'label' => esc_html__( 'Product', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaODPNTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads .download-product a',				
			]
		);
		$this->add_control(
			'wmaODPNColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads .download-product a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaODPNColorH',
			[
				'label' => esc_html__( 'Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .woocommerce-table--order-downloads .download-product a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaODFBheading',
			[
				'label' => esc_html__( 'Download Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);		
		$this->add_responsive_control(
			'wmaODFBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
  			'wmaODFBWidth',		
  			[		
  				'label' => esc_html__( 'Width', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 400,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file' => 'width:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->start_controls_tabs( 'tabswmaODFBStyle' );
		$this->start_controls_tab(
			'tabwmaODFBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaODFBColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaODFBBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaODFBBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file',
			]
		);
		$this->add_responsive_control(
			'wmaODFBBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaODFBShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaODFBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaODFBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaODFBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaODFBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file:hover',
			]
		);
		$this->add_responsive_control(
			'wmaODFBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaODFBShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-order-downloads .download-file .woocommerce-MyAccount-downloads-file:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaAddressesStyling',
            [
                'label' => esc_html__('Addresses', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'wmaAPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaABg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaABorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address',
			]
		);
		$this->add_responsive_control(
			'wmaABr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaAShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address',
			]
		);
		$this->add_control(
			'wmaAHheading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaAHTypo',
				'selector' => '{{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address h3',				
			]
		);
		$this->add_control(
			'wmaAHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaASTheading',
			[
				'label' => esc_html__( 'Sub Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaASTTypo',
				'selector' => '{{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address address',				
			]
		);
		$this->add_control(
			'wmaASTColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address address' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaAEBheading',
			[
				'label' => esc_html__( 'Edit Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaAEBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaAEBTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a',				
			]
		);
		$this->start_controls_tabs( 'tabswmaAEBStyle' );
		$this->start_controls_tab(
			'tabwmaAEBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaAEBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaAEBBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaAEBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a',
			]
		);
		$this->add_responsive_control(
			'wmaAEBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaAEBShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaAEBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaAEBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaAEBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaAEBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a:hover',
			]
		);
		$this->add_responsive_control(
			'wmaAEBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaAEBShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-Addresses .woocommerce-Address a:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaBSStyling',
            [
                'label' => esc_html__('Billing & Shipping', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaBSHheading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaBSHTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content h3',				
			]
		);
		$this->add_control(
			'wmaBSHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaBSLabelheading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaBSLPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaBSLMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaBSLTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label',				
			]
		);
		$this->add_control(
			'wmaBSLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label',
			]
		);
		$this->add_responsive_control(
			'wmaBSLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSLShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaBSLTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label',
			]
		);
		$this->add_control(
			'wmaBSLRColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaBSIFdheading',
			[
				'label' => esc_html__( 'Input Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaBSIFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaBSIFTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered',				
			]
		);
		$this->add_control(
			'wmaBSIFColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabswmaBSIFstyle' );
		$this->start_controls_tab(
			'tabwmaBSIFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaBSIFColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
					{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSIFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSIFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered',
			]
		);
		$this->add_responsive_control(
			'wmaBSIFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSIFShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaBSIFTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .select2-selection--single .select2-selection__rendered',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabcwmaBSIFFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaBSIFColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSIFBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSIFBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input:focus',
			]
		);
		$this->add_responsive_control(
			'wmaBSIFBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSIFShadowF',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaBSIFTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wmaBSSAVEFormdheading',
			[
				'label' => esc_html__( 'SAVE Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaBSSPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaBSSTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button',				
			]
		);
		$this->start_controls_tabs( 'tabswmaBSSStyle' );
		$this->start_controls_tab(
			'tabwmaBSSNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaBSSColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSSBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSSBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button',
			]
		);
		$this->add_responsive_control(
			'wmaBSSBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSSShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaBSSHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaBSSColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSSBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSSBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button:hover',
			]
		);
		$this->add_responsive_control(
			'wmaBSSBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSSShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .woocommerce-address-fields .button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wmaBSFormdheading',
			[
				'label' => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaBSFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaBSFMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);		
		$this->start_controls_tabs( 'tabswmaBSFStyle' );
		$this->start_controls_tab(
			'tabwmaBSFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form',
			]
		);
		$this->add_responsive_control(
			'wmaBSFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSFShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaBSFH',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBSFBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBSFBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form:hover',
			]
		);
		$this->add_responsive_control(
			'wmaBSFBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaBSFShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content form:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaAccountStyling',
            [
                'label' => esc_html__('Account', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaALheading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_responsive_control(
			'wmaALPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaALMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaALTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label',				
			]
		);
		$this->add_control(
			'wmaALColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaALBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaALBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label',
			]
		);
		$this->add_responsive_control(
			'wmaALBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaALShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaALTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label',
			]
		);
		$this->add_control(
			'wmaALRColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaAIFheading',
			[
				'label' => esc_html__( 'Input Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaAIFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaAIFTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input',				
			]
		);
		$this->add_control(
			'wmaAIFPColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabswmaAIFstyle' );
		$this->start_controls_tab(
			'tabwmaAIFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaAIFColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaAIFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaAIFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input',
			]
		);
		$this->add_responsive_control(
			'wmaAIFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaAIFShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaAIFTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaAIFFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaAIFColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaAIFBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-checkout-wrapper .checkout .woocommerce-billing-fields input:focus,
				{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaAIFBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input:focus',
			]
		);
		$this->add_responsive_control(
			'wmaAIFBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaAIFShadowF',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaAIFTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'SaveBtnheading',
			[
				'label' => esc_html__( 'Save Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'masbPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'masbTypography',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button',				
			]
		);
		$this->start_controls_tabs( 'tabsmasbStyle' );
		$this->start_controls_tab(
			'tabmasbNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'masbColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'masbBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'masbBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button',
			]
		);
		$this->add_responsive_control(
			'masbBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'masbShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabmasbHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'masbColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'masbBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'masbBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button:hover',
			]
		);
		$this->add_responsive_control(
			'masbBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'masbShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-MyAccount-content .edit-account .woocommerce-Button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaPaymentStyling',
            [
                'label' => esc_html__('Payment', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaPLheading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaPLTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment ul.payment_methods li label',				
			]
		);
		$this->add_control(
			'wmaPLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment ul.payment_methods li label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaPLIheading',
			[
				'label' => esc_html__( 'Link/Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaPLITypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment div.payment_box p,
				{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment div.payment_box p a',				
			]
		);
		$this->add_control(
			'wmaPLIColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment div.payment_box p,
				{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment div.payment_box p a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaPFSheading',
			[
				'label' => esc_html__( 'Fieldset', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaPFSTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment div.payment_box .wc-credit-card-form label',				
			]
		);
		$this->add_control(
			'wmaPFSColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper #add_payment_method #payment div.payment_box .wc-credit-card-form label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaLoginStyling',
            [
                'label' => esc_html__('Login', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaLHHeading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLHTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 h2',				
			]
		);
		$this->add_control(
			'wmaLHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLLHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLLPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaLLMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLLTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label',				
			]
		);
		$this->add_control(
			'wmaLLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label',
			]
		);
		$this->add_responsive_control(
			'wmaLLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLLShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaLLTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label',
			]
		);
		$this->add_control(
			'wmaLLrColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLFHeading',
			[
				'label' => esc_html__( 'Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaLFMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLFTypo',
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input',				
			]
		);
		$this->add_control(
			'wmaLFColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabswmaLFstyle' );
		$this->start_controls_tab(
			'tabwmaLFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLFColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} div#customer_login .u-column1 .login input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input',
			]
		);
		$this->add_responsive_control(
			'wmaLFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLFShadowN',
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaLFTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLFFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLFColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLFBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} div#customer_login .u-column1 .login input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLFBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input:focus',
			]
		);
		$this->add_responsive_control(
			'wmaLFBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} div#customer_login .u-column1 .login input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLFShadowF',
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaLFTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column1 .login input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'wmaLBHeading',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLBTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit',				
			]
		);
		$this->start_controls_tabs( 'tabswmaLBStyle' );
		$this->start_controls_tab(
			'tabwmaLBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLBBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLBBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit',
			]
		);
		$this->add_responsive_control(
			'wmaLBBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLBShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit:hover',
			]
		);
		$this->add_responsive_control(
			'wmaLBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLBShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__submit:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'wmaLRHeading',
			[
				'label' => esc_html__( 'Remember Me', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLRTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__rememberme',				
			]
		);
		$this->add_control(
			'wmaLRColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .woocommerce-form-login__rememberme' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLLPHeading',
			[
				'label' => esc_html__( 'Lost Password', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLLPTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .lost_password a',				
			]
		);
		$this->add_control(
			'wmaLLPColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login .lost_password a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLFoHeading',
			[
				'label' => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLFoPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaLFoMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswmaLFoStyle' );
		$this->start_controls_tab(
			'tabwmaLFoNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLFoBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLFoBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login',
			]
		);
		$this->add_responsive_control(
			'wmaLFoBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLFoShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLFoHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLFoBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLFoBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login:hover',
			]
		);
		$this->add_responsive_control(
			'wmaLFoBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLFoShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column1 .login:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wmaLBoHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLBoPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .u-column1' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaLBoMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .u-column1' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswmaLBoStyle' );
		$this->start_controls_tab(
			'tabwmaLBoNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'paywmaLBoN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .u-column1',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLBoBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .u-column1',
			]
		);
		$this->add_responsive_control(
			'wmaLBoBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .u-column1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLBoShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .u-column1',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLBoHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLBoBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .u-column1:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLBoBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .u-column1:hover',
			]
		);
		$this->add_responsive_control(
			'wmaLBoBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .u-column1:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLBoShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .u-column1:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaLPStyling',
            [
                'label' => esc_html__('Lost Password', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaLPDHeading',
			[
				'label' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLPDTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password',				
			]
		);
		$this->add_control(
			'wmaLPDColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLPLHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLPLPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaLPLMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLPLTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label',				
			]
		);
		$this->add_control(
			'wmaLPLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label',
			]
		);
		$this->add_responsive_control(
			'wmaLPLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPLShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaLPLTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label',
			]
		);
		$this->add_control(
			'wmaLPLrColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLPFHeading',
			[
				'label' => esc_html__( 'Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLPFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLPFTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input',				
			]
		);
		$this->add_control(
			'wmaLPFColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabswmaLPFstyle' );
		$this->start_controls_tab(
			'tabwmaLPFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLPFColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input',
			]
		);
		$this->add_responsive_control(
			'wmaLPFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPFShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaLPFTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLPFFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLPFColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPFBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPFBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input:focus',
			]
		);
		$this->add_responsive_control(
			'wmaLPFBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPFShadowF',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaLPFTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wmaLPBHeading',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLPBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLPBTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button',				
			]
		);
		$this->start_controls_tabs( 'tabswmaLPBStyle' );
		$this->start_controls_tab(
			'tabwmaLPBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLPBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPBBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPBBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button',
			]
		);
		$this->add_responsive_control(
			'wmaLPBBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPBShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLPBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaLPBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button:hover',
			]
		);
		$this->add_responsive_control(
			'wmaLPBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPBShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password .button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wmaLPFOHeading',
			[
				'label' => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaLPFOPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaLPFOMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswmaLPFOStyle' );
		$this->start_controls_tab(
			'tabwmaLPFONorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPFOBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPFOBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password',
			]
		);
		$this->add_responsive_control(
			'wmaLPFOBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPFOShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaLPFOHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaLPFOBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaLPFOBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password:hover',
			]
		);
		$this->add_responsive_control(
			'wmaLPFOBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaLPFOShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .lost_reset_password:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaRegisterStyling',
            [
                'label' => esc_html__('Register', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaRHHeading',
			[
				'label' => esc_html__( 'Heading', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaRHTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 h2',				
			]
		);
		$this->add_control(
			'wmaRHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaRLHeading',
			[
				'label' => esc_html__( 'Label', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaRLPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaRLMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaRLTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label',				
			]
		);
		$this->add_control(
			'wmaRLColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRLBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRLBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label',
			]
		);
		$this->add_responsive_control(
			'wmaRLBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRLShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaRLTextShadow',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label',
			]
		);
		$this->add_control(
			'wmaRLrColor',
			[
				'label' => esc_html__( 'Required Icon Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register label .required' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaRFHeading',
			[
				'label' => esc_html__( 'Field', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaRFPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaRFMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaRFTypo',
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input',				
			]
		);
		$this->add_control(
			'wmaRFColor',
			[
				'label' => esc_html__( 'Placeholder Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input::placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->start_controls_tabs( 'tabswmaRFstyle' );
		$this->start_controls_tab(
			'tabwmaRFNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaRFColorN',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRFBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} div#customer_login .u-column2 .register input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRFBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input',
			]
		);
		$this->add_responsive_control(
			'wmaRFBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRFShadowN',
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaRFTextShadowN',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaRFFocus',
			[
				'label' => esc_html__( 'Focus', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaRFColorF',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input:focus' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRFBgF',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} div#customer_login .u-column2 .register input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRFBorderF',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input:focus',
			]
		);
		$this->add_responsive_control(
			'wmaRFBrF',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} div#customer_login .u-column2 .register input:focus' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRFShadowF',
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input:focus',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'wmaRFTextShadowF',
				'label'      => esc_html__( 'Text Shadow', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register input:focus',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'wmaLRDHeading',
			[
				'label' => esc_html__( 'Description', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLRDTypo',
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register',				
			]
		);
		$this->add_control(
			'wmaLRDColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLRPPHeading',
			[
				'label' => esc_html__( 'Privacy Policy', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaLRPPTypo',
				'selector' => '{{WRAPPER}} div#customer_login .u-column2 .register .woocommerce-privacy-policy-text',				
			]
		);
		$this->add_control(
			'wmaLRPPColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register .woocommerce-privacy-policy-text' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLRPPAColor',
			[
				'label' => esc_html__( 'Link Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register .woocommerce-privacy-policy-text a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaLRPPAHColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div#customer_login .u-column2 .register .woocommerce-privacy-policy-text a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaRBHeading',
			[
				'label' => esc_html__( 'Button', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaRBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaRBTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button',				
			]
		);
		$this->start_controls_tabs( 'tabswmaRBStyle' );
		$this->start_controls_tab(
			'tabwmaRBNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaRBColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRBBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRBBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button',
			]
		);
		$this->add_responsive_control(
			'wwmaRBBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRBShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaRBHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_control(
			'wmaRBColorH',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRBBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRBBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button:hover',
			]
		);
		$this->add_responsive_control(
			'wmaRBBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRBShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register .woocommerce-Button:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'wmaRFOHeading',
			[
				'label' => esc_html__( 'Form', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaRFOPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaRFOMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswmaRFOStyle' );
		$this->start_controls_tab(
			'tabwmaRFONorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRFOBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRFOBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register',
			]
		);
		$this->add_responsive_control(
			'wmaRFOBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRFOShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaRFOHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRFOBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRFOBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register:hover',
			]
		);
		$this->add_responsive_control(
			'wmaRFOBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRFOShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2 .register:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->add_control(
			'wmaRBoHeading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaRBoPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaRBoMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswmaRBoStyle' );
		$this->start_controls_tab(
			'tabwmaRBoNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRBoBgN',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRBoBorderN',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2',
			]
		);
		$this->add_responsive_control(
			'wmaRBoBrN',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRBoShadowN',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaRBoHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaRBoBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaRBoBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2:hover',
			]
		);
		$this->add_responsive_control(
			'wmaRBoBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaRBoShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper div#customer_login .u-column2:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaEMStyling',
            [
                'label' => esc_html__('Eroor Message', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_control(
			'wmaEMIheading',
			[
				'label' => esc_html__( 'Icon', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,				
			]
		);		
		$this->add_responsive_control(
  			'wmaEMISize',		
  			[		
  				'label' => esc_html__( 'Size', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => 1,		
						'max' => 500,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error:before' => 'font-size:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_responsive_control(
  			'wmaEMIoffset',		
  			[		
  				'label' => esc_html__( 'Offset', 'essential-classy-addons-for-elementor' ),		
  				'type' => Controls_Manager::SLIDER,		
				'size_units' => [ 'px','%'],		
				'range' => [		
					'px' => [		
						'min' => -300,		
						'max' => 300,
					],
					'%' => [		
						'min' => 1,		
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [		
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error:before' => 'margin-left:{{SIZE}}{{UNIT}};',
				],		
  			]		
  		);
		$this->add_control(
			'wmaEMIColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaEMTheading',
			[
				'label' => esc_html__( 'Text', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'wmaEMTTypo',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error li',				
			]
		);
		$this->add_control(
			'wmaEMTColor',
			[
				'label' => esc_html__( 'Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error li' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaEMTLColor',
			[
				'label' => esc_html__( 'Link Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error li a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaEMTLHColor',
			[
				'label' => esc_html__( 'Link Hover Color', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error li a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'wmaEMBheading',
			[
				'label' => esc_html__( 'Box', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'wmaEMBPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaEMBBg',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaEMBBorder',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error',
			]
		);
		$this->add_responsive_control(
			'wmaEMBBr',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaEMBShadow',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper .woocommerce-notices-wrapper .woocommerce-error',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
            'wmaBoxStyling',
            [
                'label' => esc_html__('Box', 'essential-classy-addons-for-elementor'),
                'tab' => Controls_Manager::TAB_STYLE,				
            ]
        );
		$this->add_responsive_control(
			'wmaPadding',
			[
				'label' => esc_html__( 'Padding', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->add_responsive_control(
			'wmaMargin',
			[
				'label' => esc_html__( 'Margin', 'essential-classy-addons-for-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px','%', 'em'],				
				'selectors' => [
					'{{WRAPPER}} .ec-myaccount-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],				
			]
		);
		$this->start_controls_tabs( 'tabswmaStyle' );
		$this->start_controls_tab(
			'tabwmaNorm',
			[
				'label' => esc_html__( 'Normal', 'essential-classy-addons-for-elementor' ),
			]
		);		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBgNorm',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBorderNorm',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper',
			]
		);
		$this->add_responsive_control(
			'wmaBrNorm',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaShadowNorm',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper',
			]
		);
		$this->end_controls_tab();
		$this->start_controls_tab(
			'tabwmaHover',
			[
				'label' => esc_html__( 'Hover', 'essential-classy-addons-for-elementor' ),
			]
		);		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'      => 'wmaBgH',
				'types'     => [ 'classic', 'gradient' ],
				'selector'  => '{{WRAPPER}} .ec-myaccount-wrapper:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wmaBorderH',
				'label' => esc_html__( 'Border', 'essential-classy-addons-for-elementor' ),
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper:hover',
			]
		);
		$this->add_responsive_control(
			'wmaBrH',
			[
				'label'      => esc_html__( 'Border Radius', 'essential-classy-addons-for-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .ec-myaccount-wrapper:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',				
				],	
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'wmaShadowH',
				'selector' => '{{WRAPPER}} .ec-myaccount-wrapper:hover',
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	
	
	protected function render() {
        $settings = $this->get_settings_for_display();
		if ( class_exists('woocommerce') ) {
			if ( \Elementor\Plugin::$instance->editor->is_edit_mode() && ! empty( $settings['wmaPreviewSel'] ) ) {
				global $wp;
				if($settings['wmaPreviewSel']=='edit-address' && (!empty($settings['wmaPreviewSelMode']) && $settings['wmaPreviewSelMode']=='addform')){
					$wp->query_vars[ $settings['wmaPreviewSel'] ] = 1;
				}else{
					$wp->query_vars[ $settings['wmaPreviewSel'] ] = '';
				}				
			}
			
			$wmaLayout= !empty($settings['wmaLayout']) ? $settings['wmaLayout'] : 'eclvertical';
			
			if ( \Elementor\Plugin::$instance->editor->is_edit_mode() &&  (isset( $settings['wmaLRForm'] ) && $settings['wmaLRForm']=='yes') ) {
				echo '<div class="ec-myaccount-wrapper '.$wmaLayout.'">';
				echo '<div class="woocommerce">';
					include_once dirname( WC_PLUGIN_FILE ) . '/templates/myaccount/form-login.php';
				echo '</div>';
				echo '</div>';
			}
			
			if ( \Elementor\Plugin::$instance->editor->is_edit_mode() &&  (isset( $settings['wmaLPForm'] ) && $settings['wmaLPForm']=='yes') ) {
				echo '<div class="ec-myaccount-wrapper '.$wmaLayout.'">';
				echo '<div class="woocommerce">';					
					include_once dirname( WC_PLUGIN_FILE ) . '/templates/myaccount/form-lost-password.php';
				echo '</div>';
				echo '</div>';
			}
			
			$output ='<div class="ec-myaccount-wrapper '.$wmaLayout.'">';				
				$output .= do_shortcode('[woocommerce_my_account]');				
			$output .= '</div>';
			
			echo $output;
				
		}
		
	}
}